diff --git a/changelog b/changelog
index d486296..cdd0688 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20080131 tpd src/input/Makefile add ei.input for Ei regression test
+20080131 tpd src/input/ei.input regression test function Ei
+20080131 tpd src/algebra/special.spad add special function Ei
 20080127 tpd src/doc/Makefile add refcard
 20080127 tpd src/doc/refcard added
 20080125 tpd --patch-55 (January 2008) release
diff --git a/src/algebra/special.spad.pamphlet b/src/algebra/special.spad.pamphlet
index 6b173ae..aab10e4 100644
--- a/src/algebra/special.spad.pamphlet
+++ b/src/algebra/special.spad.pamphlet
@@ -49,6 +49,36 @@ DoubleFloatSpecialFunctions(): Exports == Impl where
         En: (PI,R) -> OPR
          ++ En(n,x) is the nth Exponential Integral Function
 
+        Ei: (OPR) -> OPR
+         ++ Ei is the Exponential Integral function
+         ++ This is computed using a 6 part piecewise approximation.
+         ++ DoubleFloat can only preserve about 16 digits but the
+         ++ Chebyshev approximation used can give 30 digits.
+
+        Ei1: (OPR) -> OPR
+         ++ Ei1 is the first approximation of Ei where the result is
+         ++ x*%e^-x*Ei(x) from -infinity to -10 (preserves digits)
+
+        Ei2: (OPR) -> OPR
+         ++ Ei2 is the first approximation of Ei where the result is
+         ++ x*%e^-x*Ei(x) from -10 to -4 (preserves digits)
+
+        Ei3: (OPR) -> OPR
+         ++ Ei3 is the first approximation of Ei where the result is
+         ++ (Ei(x)-log |x| - gamma)/x from -4 to 4 (preserves digits)
+
+        Ei4: (OPR) -> OPR
+         ++ Ei4 is the first approximation of Ei where the result is
+         ++ x*%e^-x*Ei(x) from 4 to 12 (preserves digits)
+
+        Ei5: (OPR) -> OPR
+         ++ Ei5 is the first approximation of Ei where the result is
+         ++ x*%e^-x*Ei(x) from 12 to 32 (preserves digits)
+
+        Ei6: (OPR) -> OPR
+         ++ Ei6 is the first approximation of Ei where the result is
+         ++ x*%e^-x*Ei(x) from 32 to infinity (preserves digits)
+
         Beta: (R, R) -> R
          ++ Beta(x, y) is the Euler beta function, \spad{B(x,y)}, defined by
          ++   \spad{Beta(x,y) = integrate(t^(x-1)*(1-t)^(y-1), t=0..1)}.
@@ -171,6 +201,7 @@ DoubleFloatSpecialFunctions(): Exports == Impl where
 
 @
 \section{The Exponential Integral}
+\subsection{The E1 function}
 (Quoted from Segletes\cite{2}):
 
 A number of useful integrals exist for which no exact solutions have
@@ -313,7 +344,7 @@ e.g.}, transformation of variables), the fits are all piecewise over
 the domain of the integral.
 
 Cody and Thatcher \cite{7} performed what is perhaps the definitive
-work, with the use of Chebyshev approximations to the exponential 
+work, with the use of Chebyshev\cite{18,19} approximations to the exponential 
 integral $E_1$. Like others, they fit the integral over a piecewise
 series of subdomains (three in their case) and provide the fitting
 parameters necessary to evaluate the function to various required
@@ -504,6 +535,1514 @@ The formula is 5.1.14 in Abramowitz and Stegun, 1965, p229\cite{4}.
           w:R:=1/(n-1)*(exp(-x)-x*v)
           w::OPR
 
+@
+\section{The Ei Function}
+This function is based on Kin L. Lee's work\cite{8}. See also \cite{21}.
+\subsection{Abstract}
+The exponential integral Ei(x) is evaluated via Chebyshev series
+expansion of its associated functions to achieve high relative
+accuracy throughout the entire real line. The Chebyshev coefficients
+for these functions are given to 30 significant digits. Clenshaw's\cite{20}
+method is modified to furnish an efficient procedure for the accurate
+solution of linear systems having near-triangular coefficient
+matrices.
+\subsection{Introduction}
+The evaulation of the exponential integral
+\begin{equation}
+Ei(x)=\int_{-\infty}^{X}{\frac{e^u}{u}}\ du=-E_1(-x), x \ne 0
+\end{equation}
+is usually based on the value of its associated functions, for
+example, $xe^{-x}Ei(x)$. High accuracy tabulations of integral (1) by
+means of Taylor series techniques are given by Harris \cite{9} and
+Miller and Hurst \cite{10}. The evaluation of $Ei(x)$ for
+$-4 \le x \le \infty$ by means of Chebyshev series is provided by
+Clenshaw \cite{11} to have the absolute accuracy of 20 decimal
+places. The evaluation of the same integral (1) by rational
+approximation of its associated functions is furnished by Cody and
+Thacher \cite{12,13} for $-\infty < x < \infty$, and has the relative
+accuracy of 17 significant figures.
+
+The approximation of Cody and Thacher from the point of view of
+efficient function evaluation are preferable to those of
+Clenshaw. However, the accuracy of the latter's procedure, unlike
+those of the former, is not limited by the accuracy or the
+availability of a master function, which is a means of explicitly
+evaluating the function in question.
+
+In this paper $Ei(x)$ (or equivalently $-E_1(-x)$) for the entire real
+line is evaluted via Chebyshev series expansion of its associated
+functions that are accurate to 30 significant figures by a
+modification of Clenshaw's procedure. To verify the accuracy of the
+several Chebyshev series, values of the associated functions were
+checked against those computed by Taylor series and those of Murnaghan
+and Wrench \cite{14} (see Remarks on Convergence and Accuracy).
+
+Although for most purposes fewer than 30 figures of accuracy are
+required, such high accuracy is desirable for the following
+reasons. In order to further reduce the number of arithmetical
+operations in the evaluation of a function, the Chebyshev series in
+question can either be converted into a rational function or
+rearranged into an ordinary polynomial. Since several figures may be
+lost in either of these procedures, it is necessary to provide the
+Chebyshev series with a sufficient number of figures to achieve the
+desired accuracy. Furthermore, general function approximation
+routines, such as those used for minimax rational function
+approximations, require the explicit evaluation of the function to be
+approximated. To take account of the errors commited by these
+routines, the function values must have an accuracy higher than the
+approximation to be determined. Consequently, high-precision results
+are useful as a master function for finding approximations for (or
+involving) $Ei(x)$ (e.g. \cite{12,13}) where prescribed accuracy is
+less than 30 figures.
+
+\subsection{Discussion}
+
+It is proposed here to provide for the evaluation of $Ei(x)$ by
+obtaining Chebyshev coefficients for the associated functions given by
+table 1.
+
+\noindent
+{\bf Table 1}: Associated Functions of $Ei(x)$ and their ranges of Chebyshev
+Series Expansions
+
+\begin{tabular}{clc}
+& Associated function & Range of expansion\\
+Ei1 & $xe^{-x}Ei(x)$ & $-\infty < x \le -10$\\
+Ei2 & $xe^{-x}Ei(x)$ & $-10 \le x \le -4$\\
+Ei3 & $\frac{Ei(x)-log\vert x\vert - \gamma}{x}$ & $-4 \le x \le d42$\\
+Ei4 & $xe^{-x}Ei(x)$ & $4 \le x \le 12$\\
+Ei5 & $xe^{-x}Ei(x)$ & $12 \le x \le 32$\\
+Ei6 & $xe^{-x}Ei(x)$ & $32 \le x < \infty$\\
+\end{tabular}\\
+\hbox{\hskip 2cm}($\gamma$ = 0.5772156649... is Euler's constant.)
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei(y:OPR):OPR ==
+          infinite? y => 1
+          x:R:=retract(y)
+          x < -10.0::R => 
+            ei:R:=retract(Ei1(y))
+            (ei/(x*exp(-x)))::OPR
+          x <  -4.0::R =>
+            ei:R:=retract(Ei2(y))
+            (ei/(x*exp(-x)))::OPR
+          x <   4.0::R => 
+            ei3:R:=retract(Ei3(y))
+            gamma:R:=0.577215664901532860606512090082::R
+            (ei3*x+log(abs(x))+gamma)::OPR
+          x <  12.0::R => 
+            ei:R:=retract(Ei4(y))
+            (ei/(x*exp(-x)))::OPR
+          x <  32.0::R => 
+            ei:R:=retract(Ei5(y))
+            (ei/(x*exp(-x)))::OPR
+          ei:R:=retract(Ei6(y))
+          (ei/(x*exp(-x)))::OPR
+
+@
+Note that the functions $[Ei(x)-log\vert x\vert - \gamma]/x$ and
+$xe^{-x}Ei(x)$ have the limiting values of unity at the origin and at
+infinity, respectively, and that the range of the associated function
+values is close to unity (see table 4). This makes for the evaluation
+of the associated functions over the indicated ranges in table 1 (and
+thus $Ei(x)$ over the entire real line) with high relative accuracy by
+means of the Chebyshev series. The reason for this will become
+apparent later.
+
+Some remarks about the choice of the intervals of expansion for the
+serveral Chebyshev series are in order here. The partition of the real
+line indicated by table 1 is chosen to allow for the approximation of
+the associated functions with a maximum error of $0.5\times 10^{-30}$
+by polynomials of degress $< 50$. The real line has also been
+partitioned with the objective of providing the interval about zero
+with the lowest degree of polynomial approximation of the six
+intervals. This should compensate for the computation of 
+$log\vert x\vert$ required in the evaluation of $Ei(x)$ over that
+interval. The ranges $-\infty < x \le -4$ and $4 \le x < \infty$ are
+partitioned into 2 and 3 intervals, respectively, to provide
+approximations to $xe^{-x}Ei(x)$ by polynomials of about the same
+degree. 
+
+\subsection{Expansions in Chebyshev Series}
+
+Let $\phi(t)$ be a differentiable function defined on [-1,1]. To
+facilitate discussion, denote its Chebyshev series and that of its
+derivative by 
+\begin{equation}
+\phi(t)=\sum_{k=0}^{\infty}\ ^{'}{A_k^{(0)}T_k(t)}\quad
+\phi^{'}(t)=\sum_{k=0}^{\infty}\ ^{'}{A_k^{(1)}T_k(t)}
+\end{equation}
+where $T_k(t)$ are Chebyshev polynomials defined by
+\begin{equation}
+T_k(t)=cos(k\ \arccos\ t),\quad -1 \le t \le 1
+\end{equation}
+(A prime over a summation sign indicates that the first term is to be
+halved.) 
+
+If $\phi(t)$ and $\phi^{'}(t)$ are continuous, the Chebyshev
+coefficients $A_k^{(0)}$ and $A_k^{(1)}$ can be obtained analytically
+(if possible) or by numerical quadrature. However, since each function
+in table 1 satisfies a linear differential equation with polynomial
+coefficients, the Chebyshev coefficients can be more readily evaluated
+by the method of Clenshaw \cite{16}.
+
+There are several variations of Clenshaw's procedure (see,
+e.g. \cite{17}), but for high-precision computation, where multiple
+precision arithmetic is employed, we find his original procedure
+easiest to implement. However, straightforward application of it may
+result in a loss of accuracy if the trial solutions selected are not
+sufficiently independent. How the difficulty is overcome will be
+pointed out subsequently.
+
+\subsection{The function $xe^{-x}Ei(x)$ on the Finite Interval}
+
+We consider first the Chebyshev series expansion of
+\begin{equation}
+f(x)=xe^{-x}Ei(x),\quad (a \le x \le b)
+\end{equation}
+with $x\ne 0$. One can easily verify that after the change of
+variables
+\begin{equation}
+x=[(b-a)T + a + b]/2,\quad(-1 \le t \le 1)
+\end{equation}
+the function
+\begin{equation}
+\phi(t)=f\left[\frac{(b-a)t + a + b}{2}\right]=f(x)
+\end{equation}
+satisfies the differential equation
+\begin{equation}
+2(pt+q)\phi^{'}(t)+p(pt+q-2)\phi(t)=p(pt+q)
+\end{equation}
+with\footnote{The value of $Ei(a)$ may be evaluated by means of the
+Taylor series. In this report $Ei(a)$ is computed by first finding the
+Chebyshev series approximation to $[Ei(x)-log\vert x\vert-\gamma]/x$
+to get $Ei(a)$. The quantities $e^a$ and $\log\vert a\vert$ for
+integral values of $a$ may be found in existing tables}
+\begin{equation}
+\phi(-1)=ae^{-a}Ei(a)
+\end{equation}
+where $p=b-a$ and $q=b+a$. Replacing $\phi(t)$ and $\phi^{'}(t)$ in
+equations 7 by their Chebyshev series, we obtain
+\begin{equation}
+\sum_{k=0}^{\infty}\ ^{'}{(-1)^kA_k^{(0)}}=\phi(-1)
+\end{equation}
+\begin{equation}
+2\sum_{k=0}^{\infty}\ {'}{A_k^{(1)}(pt+q)T_k(t)}+
+p\sum_{k=0}^{\infty}\ {'}{A_k^{(0)}(pt+q-2)T_k(t)}=
+p(pt+q)
+\end{equation}
+It can be demonstrated that if $B_k$ are the Chebyshev coefficients of
+a function $\Psi(t)$, then $C_k$, the Chebyshev coefficients of
+$t^r\Psi(t)$ for positive integers r, are given by \cite{16}
+\begin{equation}
+C_k=2^{-r}\sum_{i=0}^r\binom{r}{i}B_{\vert k-r+2i\vert}
+\end{equation}
+Consequently, the left member of equation 15 can be rearranged into a
+single series involving $T_k(t)$. The comparison of the coefficients
+of $T_k(t)$ that yields the infinite system of equations
+\begin{equation}
+\left.
+\begin{array}{c}
+\displaystyle\sum_{k=0}^{\infty}\ ^{'}{(-1)^kA_k^{(0)}} = \phi(-1)\\
+\\
+2pA_{\vert k-1\vert}^{(1)}+
+4qA_k^{(1)}+
+2pA_{k+1}^{(1)}+
+p^2A_{\vert k-1\vert}^{(0)}+
+2p(q-2)A_k^{(0)}+
+p^2A_{k+1}^{(0)}\\
+\\
+=\left\{
+\begin{array}{rcl}
+4pq & , & k=0\\
+2p^2 & , & k=1\\
+0 & , & k=2,3,\ldots
+\end{array}
+\right.
+\end{array}
+\right\}
+\end{equation}
+The relation \cite{16}
+\begin{equation}
+2kA_k^{(0)}=A_{k-1}^{(1)}-A_{k+1}^{(1)}
+\end{equation}
+can be used to reduce equation 18 to a system of equations involving
+only $A_k^{(0)}$. Thus, replacing $k$ of equations 18 by $k+2$ and
+subtracting the resulting equation from equations 18, we have, by
+means of equation 19, the system of equations
+\begin{equation}
+\left.
+\begin{array}{c}
+\displaystyle\sum_{k=0}^{\infty}\ ^{'}{(-1)^kA_k^{(0)}} = \phi(-1)\\
+\\
+2p(q-2)A_0+(8q+p^2)A_1+2p(6-q)A_2-p^2A_3=4pq\\
+\\
+p^2A_{k-1}+2p(2k+q-2)A_k+8q(k+1)A_{k+1}+2p(2k-q+6)A_{k+2}-p^2A_{k+3}\\
+\\
+=\left\{
+\begin{array}{rcl}
+2p^2 & , & k=1\\
+0 & , & k=2,3,\ldots
+\end{array}
+\right.
+\end{array}
+\right\}
+\end{equation}
+The superscript of $A_k^{(0)}$ is dropped for simplicity. In order to
+solve the infinite system 20, Clenshaw \cite{11} essentially
+considered the required solution as the limiting solution of the
+sequence of truncated systems consisting of the first $M+1$ equations
+of the same system, that is, the solution of the system
+\begin{equation}
+\sum_{k=0}^M\ ^{'}{(-1)^kA_k}=\phi(-1)
+\end{equation}
+\begin{equation}
+2p(q-2)A_0+(8q+p^2)A_1+2p(q-6)A_2-p^2A_3=4pq
+\end{equation}
+\begin{equation}
+\left.
+\begin{array}{c}
+p^2A_{k-1}+2p(2k+q-2)A_k+8q(k+1)A_{k+1}+2p(2k-q+6)A_{k+2}-p^2A_{k+3}\\
+\\
+=\left\{
+\begin{array}{rcl}
+2p^2 & , & k=1\\
+0 & , & k=2,3,\ldots,M-3
+\end{array}
+\right.\\
+\\
+p^2A_{M-3}+2p(2M+q-6)A_{M-2}+8q(M-1)A_{M-1}+2p(2M+4-q)A_M=0\\
+\\
+p^2A_{M-2}+2p(2M+q-4)A_{M-1}+8qMA_M=0
+\end{array}
+\right\}
+\end{equation}
+where $A_k$ is assumed to vanish for $K \ge M+1$. To solve system
+(21,22,23) consider first the subsystem 23 consisting of $M-2$
+equations in $M$ unknowns. Here use is made of the fact that the
+subsystem 23 is satisfied by
+\begin{equation}
+A_k=c_1\alpha_k+c_2\beta_k+\gamma_k\quad(k=0,1,2,\ldots)
+\end{equation}
+for arbitrary constants $c_1$ and $c_2$, where $\gamma_k$ is a
+particular solution of 23 and where $\alpha_k$ and $\beta_k$ are two
+independent solutions of the homogeneous equations (23 with $2p^2$
+deleted) of the same subsystem. Hence, if $\alpha_k$, $\beta_k$, and
+$\gamma_k$ are available, the solution of system (21,22,23) reduces to
+the determinant of $c_1$ and $c_2$ from equations 21 and 22.
+
+To solve equations (21,22,23), we note that
+\begin{equation}
+\gamma_0=2,\quad \gamma_k=0,\quad {\textrm for\ }k=1(1)M
+\end{equation}
+is obviously a particular solution of equation 23. The two independent
+solutions $\gamma_k$ and $\beta_k$ of the homogeneous equations of the
+same subsystem can be generated in turn by backward recurrence if we
+set
+\begin{equation}
+\left.
+\begin{array}{l}
+\hbox{\hskip 4cm}\alpha_{M-1}=0,\quad\alpha_M=1\\
+\textrm{and}\\
+\hbox{\hskip 4cm}\beta_{M-1}=1,\quad\beta_M=0\\
+\end{array}
+\right\}
+\end{equation}
+or choose any $\alpha{M-1}$, $\alpha_M$, and $\beta_{M-1}$, $\beta_M$
+for which $\alpha_{M-1}\beta_M-\alpha_M\beta_{M-1}\ne 0$. The
+arbitrary constants $c_1$ and $c_2$ are determined, and consequently
+the solution of equations (21,22,23) if equation 24 is substituted
+into equation 21 and 22 and the resulting equations
+\begin{equation}
+c_1R(\alpha)+c_2R(\beta)=\phi(-1)-1
+\end{equation}
+\begin{equation}
+c_1S(\alpha)+c_2S(\beta)=8p
+\end{equation}
+are solved as two equations in two unknowns. The terms $R(\alpha)$ and
+$S(\alpha)$ are equal, respectively, to the left members of equations
+21 and 22 corresponding to solution $\alpha_k$. (The identical
+designation holds for $R(\beta)$ and $S(\beta)$.)
+
+The quantities $\alpha_k$ and $\beta_k$ are known as trial solutions
+in reference \cite{12}. Clenshaw has pointed out that if $\alpha_k$
+and $\beta_k$ are not sufficiently independent, loss of significance
+will occur in the formation of the linear combination 24, with
+consequent loss of accuracy. Clenshaw suggested the Gauss-Seidel
+iteration procedure to improve the accuracy of the solution. However,
+this requires the application of an additional computing procedure and
+may prove to be extremely slow. A simpler procedure which does not
+alter the basic computing scheme given above is proposed here. The
+loss of accuracy can effectively be regained if we first generate a
+third trial solution $\delta_k$ (k=0,1,$\ldots$,M), where
+$\delta_{M-1}$ and $\delta_M$ are equal to 
+$c_1\alpha_{M-1}+c_2\beta_{M-1}$ and 
+$c_1\alpha_M+c_2\beta_M$, respectively, and where $\delta_k$
+(k=M-2,M-3,$\ldots$,0) is determined using backward recurrence as
+before by means of equation 23. Then either $\alpha_k$ or $\beta_k$ is
+replaced by $\delta_k$ and a new set of $c_1$ and $c_2$ is determined
+by equations 27 and 28. Such a procedure can be repeated until the
+required accuracy is reached. However, only one application of it was
+necessary in the computation of the coefficients of this report.
+
+As an example, consider the case for $4 \le x \le 12$ with $M=15$. The
+right member of equation 27 and of equation 28 assume, respectively,
+the values of $0.43820800$ and $64$. The trial solutions $\alpha_k$
+and $\beta_k$ generated with $\alpha_{14}=8$, $\alpha_{15}=9$ and
+$\beta_{14}=7$, $\beta_{15}=8$ are certainly independent, since 
+$\alpha_{14}\beta_{15}-\alpha_{15}\beta_{14}=1\ne 0$. A check of table
+2 shows that equations 27 and 28 have, respectively, the residuals of 
+$-0.137\times 10^-4$ and $-0.976\times 10^{-3}$. The same table also
+shows that $c_1\alpha_k$ is opposite in sign but nearly equal in
+magnitude to $c_2\beta_k$. Cancellations in the formation of the
+linear combination 24 causes a loss of significance of 2 to 6 figures
+in the computed $A_k$. In the second iteration, where a new set of
+$\beta_k$ is generated replacing $\beta_{14}$ and $\beta_{15}$,
+respectively, by $c_1\alpha_{14}+c_2\beta_{14}$ and 
+$c_1\alpha_{15}+c_2\beta_{15}$ of the first iteration, the new 
+$c_1\alpha_k$ and $c_2\beta_k$ differed from 2 to 5 orders of
+magnitude. Consequently, no cancellation of significant figures in the
+computation of $A_k$ occurred. Notice that equations 27 and 28 are now
+satisfied exactly. Further note that the new $c_1$ and $c_2$ are near
+zero and unity, respectively, for the reason that if equations 21, 22,
+and 23 are satisfied by equation 24 exactly in the first iteration,
+the new $c_1$ and $c_2$ should have the precise values zero and 1,
+respectively. The results of the third iteration show that the $A_k$
+of the second iteration are already accurate to eight decimal places,
+since the $A_k$ in the two iterations differ in less that 
+$0.5\times 10^{-8}$. Notice that for the third iteration, equations
+27 and 28 are also satisfied exactly and that $c_1=1$ and $c_2=0$
+(relative to 8 places of accuracy).
+
+\noindent
+{\bf Table 2}: Computation of Chebyshev Coefficients for $xe^{-x}Ei(x)$
+
+\hrule
+First iteration: $\alpha_{14}=8$, $\alpha_{15}=9$; $\beta_{14}=7$, 
+$\beta_{15}=8$
+\hrule
+\begin{tabular}{|r|r|r|r|}
+k & $c_1\alpha_k\hbox{\hskip 1cm}$ & $c_2\beta_k\hbox{\hskip 1cm}$ & 
+$A_k\hbox{\hskip 1cm}$\\
+&&&\\
+ 0 &  0.71690285E 03 & -0.71644773E 03 &  0.24551200E 01\\
+ 1 & -0.33302683E 03 &  0.33286440E 03 & -0.16243000E 00\\
+ 2 &  0.13469341E 03 & -0.13464845E 03 &  0.44960000E-01\\
+ 3 & -0.43211869E 02 &  0.43205127E 02 & -0.67420000E-02\\
+ 4 &  0.99929173E 01 & -0.99942238E 01 & -0.13065000E-02\\
+ 5 & -0.11670764E 01 &  0.11684574E 01 &  0.13810000E-02\\
+ 6 & -0.25552137E 00 &  0.25493635E 00 & -0.58502000E-02\\
+ 7 &  0.20617247E 00 & -0.20599754E 00 &  0.17493000E-03\\
+ 8 & -0.75797238E-01 &  0.75756767E-01 & -0.40471000E-04\\
+ 9 &  0.20550680E-01 & -0.20543463E-01 &  0.72170000E-05\\
+10 & -0.45192333E-02 &  0.45183721E-02 & -0.86120000E-06\\
+11 &  0.82656562E-03 & -0.82656589E-03 & -0.27000000E-09\\
+12 & -0.12333571E-03 &  0.12337366E-03 &  0.37950000E-07\\
+13 &  0.13300910E-04 & -0.13315328E-04 & -0.14418000E-07\\
+14 & -0.29699001E-06 &  0.30091136E-06 &  0.39213500E-08\\
+15 & -0.33941716E-06 &  0.33852528E-06 & -0.89188000E-09\\
+\end{tabular}\\
+\hbox{\hskip 3.0cm}$c_1=0.37613920E-07$\\
+\hbox{\hskip 3.0cm}$c_2=-0.42427144E-07$\\
+\hbox{\hskip 1.0cm}$c_1R(\alpha)+c_2R(\beta)-0.43820800E\ 00=-0.13700000E-04$\\
+\hbox{\hskip 1.0cm}$c_1S(\alpha)+c_2S(\beta)-0.64000000E\ 00=-0.97600000E-03$
+
+\hrule
+Second iteration: $\alpha_{14}=8$, $\alpha_{15}=9$; \\
+$\beta_{14}=0.39213500E-08$, $\beta_{15}=-0.89188000E-09$
+\hrule
+\begin{tabular}{|r|r|r|r|}
+k & $c_1\alpha_k\hbox{\hskip 1cm}$ & $c_2\beta_k\hbox{\hskip 1cm}$ & 
+$A_k\hbox{\hskip 1cm}$\\
+&&&\\
+ 0 &  0.36701576E-05 &  0.45512986E 00 &  0.24551335E 01\\
+ 1 & -0.17051695E-05 & -0.16243666E 00 & -0.16243837E 00\\
+ 2 &  0.68976566E-06 &  0.44956834E-01 &  0.44957523E-01\\
+ 3 & -0.22132756E-06 & -0.67413538E-02 & -0.67415751E-02\\
+ 4 &  0.51197561E-07 & -0.13067496E-02 & -0.13066984E-02\\
+ 5 & -0.59856744E-08 &  0.13810895E-02 &  0.13810835E-02\\
+ 6 & -0.13059663E-08 & -0.58502164E-03 & -0.58502294E-03\\
+ 7 &  0.10552667E-08 &  0.17492889E-03 &  0.17492994E-03\\
+ 8 & -0.38808033E-09 & -0.40472426E-04 & -0.40472814E-04\\
+ 9 &  0.10523831E-09 &  0.72169965E-05 &  0.72171017E-05\\
+10 & -0.23146333E-10 & -0.86125438E-06 & -0.86127752E-06\\
+11 &  0.42342615E-11 & -0.25542252E-09 & -0.25118825E-09\\
+12 & -0.63200810E-12 &  0.37946968E-07 &  0.37946336E-07\\
+13 &  0.68210630E-13 & -0.14417584E-07 & -0.14417516E-07\\
+14 & -0.15414832E-14 &  0.39212981E-08 &  0.39212965E-08\\
+15 & -0.17341686E-14 & -0.89186818E-09 & -0.89186991E-09\\
+\end{tabular}\\
+\hbox{\hskip 3.0cm}$c_1=-0.19268540E-15$\\
+\hbox{\hskip 3.0cm}$c_2=0.99998675E\ 00$\\
+\hbox{\hskip 1.0cm}$c_1R(\alpha)+c_2R(\beta)-0.43820800E\ 00=0.0$\\
+\hbox{\hskip 1.0cm}$c_1S(\alpha)+c_2S(\beta)-0.64000000E\ 00=0.0$
+
+\noindent
+{\bf Table 2}: Computation of Chebyshev Coefficients for
+$xe^{-x}Ei(x)$ - Concluded\\
+\hbox{\hskip 0.5cm}$[4 \le x \le 12 with M=15; \gamma_0=2, \gamma_k=0
+\textrm{for\ }k=1(1)15]$
+
+\hrule
+Third iteration: $\alpha_{14}=8$, $\alpha_{15}=9$;\\ 
+\hbox{\hskip 0.5cm}$\beta_{14}=0.39212965E-08$, $\beta_{15}=-0.89186991E-09$
+\hrule
+\begin{tabular}{|r|r|r|r|}
+k & $c_1\alpha_k\hbox{\hskip 1cm}$ & $c_2\beta_k\hbox{\hskip 1cm}$ & 
+$A_k\hbox{\hskip 1cm}$\\
+&&&\\
+ 0 & -0.23083059E-07 &  0.45513355E 00 &  0.24551335E 01\\
+ 1 &  0.10724479E-07 & -0.16243838E 00 & -0.16243837E 00\\
+ 2 & -0.43382065E-08 &  0.44957526E-01 &  0.44957522E-01\\
+ 3 &  0.13920157E-08 & -0.67415759E-02 & -0.67415745E-02\\
+ 4 & -0.32200152E-09 & -0.13066983E-02 & -0.13066986E-02\\
+ 5 &  0.37646251E-10 &  0.13810835E-02 &  0.13810836E-02\\
+ 6 &  0.82137336E-11 & -0.58502297E-03 & -0.58502296E-03\\
+ 7 & -0.66369857E-11 &  0.17492995E-03 &  0.17492994E-03\\
+ 8 &  0.24407892E-11 & -0.40472817E-04 & -0.40472814E-04\\
+ 9 & -0.66188494E-12 &  0.72171023E-05 &  0.72171017E-05\\
+10 &  0.14557636E-12 & -0.86127766E-06 & -0.86127751E-06\\
+11 & -0.26630930E-13 & -0.25116620E-09 & -0.25119283E-09\\
+12 &  0.39749465E-14 &  0.37946334E-07 &  0.37946337E-07\\
+13 & -0.42900337E-15 & -0.14417516E-07 & -0.14417516E-07\\
+14 &  0.96949915E-17 &  0.39212966E-08 &  0.39212966E-08\\
+15 &  0.10906865E-16 & -0.89186992E-09 & -0.89186990E-09\\
+\end{tabular}\\
+\hbox{\hskip 3.0cm}$c_1=0.12118739E-17$\\
+\hbox{\hskip 3.0cm}$c_2=0.10000000E\ 01$\\
+\hbox{\hskip 1.0cm}$c_1R(\alpha)+c_2R(\beta)-0.43820800E\ 00=0.0$\\
+\hbox{\hskip 1.0cm}$c_1S(\alpha)+c_2S(\beta)-0.64000000E\ 00=0.0$\\
+\hrule
+
+It is worth noting that the coefficient matrix of system (21,22,23)
+yields an upper triangular matrix of order $M-1$ after the deletion of
+the first two rows and the last two columns. Consequently, the
+procedure of this section is applicable to any linear system having
+this property. As a matter of fact, the same procedure can be
+generalized to solve linear systems having coefficient matrices of
+order N, the deletion of whose first $r$ ($r < N$) rows and last $r$
+columns yields upper triangular matrices of order $N-r$.
+
+\subsection{The Function $(1/x)[Ei(x)-log\vert x\vert-\gamma]$}
+
+Let
+\begin{equation}
+f(x)=(1/x)[Ei(x)-log\vert x\vert-\gamma],\quad g(x)=e^x,\quad
+\vert x\vert \le b
+\end{equation}
+These functions, with the change of variable $x=bt$, simultaneously
+satisfy the differential equations
+\begin{equation}
+bt^2\phi^{'}(t)+bt\phi(t)-\psi(t)=-1
+\end{equation}
+\begin{equation}
+\psi^{'}(t)-b\psi(t)=0,\quad -1 \le t \le 1
+\end{equation}
+Conversely,\footnote{The general solution of the differential
+equations has the form
+$$
+\phi(t)=(c_1/t)+[Ei(bt)-log\vert bt\vert-\gamma]/bt
+$$
+$$
+\psi(t)=c_2e^{bt}
+$$
+where the first and second terms of $\phi(t)$ are, respectively, the
+complementary solution and a particular integral of equation 30. The
+requirement that $\phi(t)$ is bounded makes the constant $c_1=0$. The
+fact that $\psi(0)=1$ is implicit in equation 30.} any solution of
+equations 30 and 31 is equal to the functions given by equations 29
+for the change of variable $x=bt$. Therefore, boundary conditions need
+not be imposed for the solution of the differential equations.
+
+A procedure similar to that of the previous section gives the coupled
+infinite recurrence relations
+\begin{equation}
+bA_1+bA_3-B_0+B_2=-2
+\end{equation}
+\begin{equation}
+\left.
+\begin{array}{c}
+kbA_{k-1}+2(k+1)bA_{k+1}+(k+2)bA_{k+3}-2B_k+2B_{k+2}=0\\
+\\
+bB_{k-1}-2kB_k-bB_{k+1}=0,\quad k=1,2,\ldots
+\end{array}
+\right\}
+\end{equation}
+where $A_k$ and $B_k$ are the Chebyshev coefficients of $\phi(t)$ and
+$\psi(t)$, respectively.
+
+Consider first the subsystem 33. If $A_k=\alpha_k$ and $B_k=\beta_k$
+are a simultaneous solution of the system, which is homogeneous, then
+\begin{equation}
+\left.
+\begin{array}{l}
+\hbox{\hskip 4cm}A_k=c\alpha_k\\
+\textrm{and}\\
+\hbox{\hskip 4cm}B_k=c\beta_k\\
+\end{array}
+\right\}
+\end{equation}
+are also a solution for an arbitrary constant $c$. Thus based on
+considerations analogous to the solution of equations 21, 22, and 23,
+one can initiate an approximate solution of equations 32 and 33 by
+setting 
+\begin{equation}
+\left.
+\begin{array}{l}
+\alpha_M=0,\quad\alpha_k=0\quad\textrm{for }k \ge M+1\\
+\\
+\beta_M=1,\quad\beta_k=0\quad\textrm{for }k \ge M+1
+\end{array}
+\right\}
+\end{equation}
+and then determining $\alpha_k$ and $\beta_k$ ($k=M-1, M-2, \ldots,
+0$) by backward recurrence by means of equation 33. The arbitrary
+constant $c$ is determined by substituting 34 into 32.
+
+\subsection{The Function $xe^{-x}Ei(x)$ on the Infinite Interval}
+Let
+\begin{equation}
+f(x)=xe^{-x}Ei(x),\quad -\infty < x \le b < 0,\quad or 0 < b \le x < \infty
+\end{equation}
+By making the change of variables,
+\begin{equation}
+x=2b/(t+1)
+\end{equation}
+we can easily demonstrate that
+\begin{equation}
+f(x)=f[2b/(t+1)]=\phi(t)
+\end{equation}
+satisfies the differential equation
+\begin{equation}
+(t+1)^2\phi^{'}(t)+(t+1-2b)\phi(t)=-2b
+\end{equation}
+with
+\begin{equation}
+\phi(1)=be^{-b}Ei(b)
+\end{equation}
+An infinite system of equations involving the Chebyshev coefficients
+$A_k$ of $\phi(t)$ is deducible from equations 39 and 40 by the same
+procedure as applied to equations 13 and 14 to obtain the infinite
+system 20; it is given as follows.
+\begin{equation}
+\sum_{k=0}^\infty\ ^{'}A_k=\phi(1)=be^{-b}Ei(b)
+\end{equation}
+\begin{equation}
+(1-2b)A_0+3A_1+(3+2b)A_2+A_3=-4b
+\end{equation}
+\begin{equation}
+\begin{array}{l}
+kA_{k-1}+2[(2k+1)-2b]A_k+6(k+1)A_{k+1}+2(2k+3+2b)A_{k+2}\\
+\hbox{\hskip 4.0cm}+(k+2)A_{k+3}=0,\quad k=1,2,\ldots
+\end{array}
+\end{equation}
+As in the case of equations 21, 22 and 23, the solution of 41, 42 and
+43 can be assumed to be
+\begin{equation}
+A_k=c_1\alpha_k+c_2\beta_k
+\end{equation}
+with $A_k$ vanishing for a $k \ge M$. Thus, we can set, say
+\begin{equation}
+\left.
+\begin{array}{ccc}
+\alpha_{M-1}=0 & , & \alpha_M=1\\
+\beta_{M-1}=1  & , & \beta_M=0
+\end{array}
+\right\}
+\end{equation}
+and determine the trial solutions $\alpha_k$ and $\beta_k$ 
+(k=M-1,M-2,$\ldots$,0) by means of equation 43 by backward
+recurrence. The required solution of equations 41,42,adn 43 is then
+determined by substituting equation 44 in equations 41 and 42 and
+solving the resulting equations for $c_1$ and $c_2$.
+
+Loss of accuracy in the computation of $A_k$ can also occur here, as
+in the solution of equations 21, 22 and 23, if the trial solutions are
+not sufficiently independent. The process used to improve the accuracy
+of $A_k$ of the system 21, 22 and 23 can also be applied here.
+
+For efficiency in computation, it is worth noting that for $b < 0$
+($-\infty < x \le b < 0$) the boundary condition 40 is not required
+for the solution of equation 39 and 40. This follows from the fact
+that any solution\footnote{The general solution of the differential
+equation 39. Since equation 39 has no bounded complementary solution
+for $-\infty < x \le b < 0$, every solution of it is equal to the
+particular integral $xe^{-x}Ei(x)$. On the other hand, a solution of
+equation 39 for $0 < x \le b < \infty$ would, in general, involve the
+complementary function. Hence, boundary condition 40 is required to
+guarantee that the solution of equation 39 is equal to
+$xe^{-x}Ei(x)$.} of the differential equation 39 is equal to 
+$xe^{-x}Ei(x)$ ($x=2b/(t+1)$). Hence the $A_k$ of $xe^{-x}Ei(x)$ for 
+$-\infty < x \le b < 0$ can be obtained without the use of equation
+39 and can be assumed to have the form
+\begin{equation}
+A_k = c\alpha_k,\quad(k=0,1,\ldots,M)
+\end{equation}
+The M+1 values of $\alpha_k$ can be generated by setting $\alpha_M=1$
+and computing $\alpha_k$ (k=0,1,$\ldots$,M-1) by means of equation
+43 by backward recurrence. The substitution of equation 46 into 42
+then enables one to determine $c$ from the resulting equation.
+
+\subsection{Remarks on Convergence and Accuracy}
+
+The Chebyshev coefficients of table 3 were computed on the IBM 7094
+with 50-digit normalized floating-point arithmetic. In order to assure
+that the sequence of approximate solutions (see Discusion) converged
+to the limiting solution of the differential equation in question, a
+trial M was incremented by 4 until the approximate Chebyshev
+coefficients showed no change greter than or equal to 
+$0.5\times 10^{-35}$. Hence the maximum error is bounded by
+\begin{equation}
+0.5(M+1)\times 10^{-35}+\sum_{M+1}^\infty{\vert A_k\vert}
+\end{equation}
+where the first term is the maximum error of the M+1 approximate
+Chebyshev coefficients, and the sum is the maximum error of the
+truncated Chebyshev series of M+1 terms. If the Chebyshev series is
+rapidly convergent, the maximum error of the approximate Chebyshev
+series should be of the order of $10^{-30}$. The coefficients of table
+3 have been rounded to 30 digits, and higher terms for $k > N$ giving
+the maximum residual
+\begin{equation}
+\sum_{k=N+1}^M{\vert A_k\vert} < 0.5\times 10^{-30}
+\end{equation}
+have been dropped. This should allow for evaluation of the relevant
+function that is accurate to 30 decimal places. Since the range of
+values of each function is bounded between 2/5 and 5, the evaluated
+function should be good to 30 significant digits. Taylor series
+evaluation also checks with that of the function values of table 4
+(computed with 30-digit floating-point arithmetic using the
+coefficients of table 3) for at least 28-1/2 significant
+digits. Evaluation of Ei(x) using the coefficients of table 3 also
+checked with Murnaghan and Wrench \cite{14} for 28-1/2 significant
+figures. 
+
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients}
+(a)
+$$
+xe^{-x}Ei(x)=\sum_{k-0}^{40}\ {'}{A_kT_k(t)},\ \ t=(-20/x)-1,\ \ 
+(-\infty < x \le -10)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 &  0.1912173225 8605534539 1519326510E 01\\
+ 1 & -0.4208355052 8684843755 0974986680E-01\\
+ 2 &  0.1722819627 2843267833 7118157835E-02\\
+ 3 & -0.9915782173 4445636455 9842322973E-04\\
+ 4 &  0.7176093168 0227750526 5590665592E-05\\
+ 5 & -0.6152733145 0951269682 7956791331E-06\\
+ 6 &  0.6024857106 5627583129 3999701610E-07\\
+ 7 & -0.6573848845 2883048229 5894189637E-08\\
+ 8 &  0.7853167541 8323998199 4810079871E-09\\
+ 9 & -0.1013730288 0038789855 4202774257E-09\\
+10 &  0.1399770413 2267686027 7823488623E-10\\
+11 & -0.2051008376 7838189961 8962318711E-11\\
+12 &  0.3168388726 0024778181 4907985818E-12\\
+13 & -0.5132760082 8391806541 5984751899E-13\\
+14 &  0.8680933040 7665493418 7433687383E-14\\
+15 & -0.1527015040 9030849719 8572355351E-14\\
+16 &  0.2784686251 6493573965 0105251453E-15\\
+17 & -0.5249890437 4217669680 8472933696E-16\\
+18 &  0.1020717991 2485612924 7455787226E-16\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+19 & -0.2042264679 8997184130 8462421876E-17\\
+20 &  0.4197064172 7264847440 8827228562E-18\\
+21 & -0.8844508176 1728105081 6483737536E-19\\
+22 &  0.1908272629 5947174199 5060168262E-19\\
+23 & -0.4209746222 9351995033 6450865676E-20\\
+24 &  0.9483904058 1983732764 1500214512E-21\\
+25 & -0.2179467860 1366743199 4032574014E-21\\
+26 &  0.5103936869 0714509499 3452562741E-22\\
+27 & -0.1216883113 3344150908 9746779693E-22\\
+28 &  0.2951289166 4478751929 4773757144E-23\\
+29 & -0.7275353763 7728468971 4438950920E-24\\
+30 &  0.1821639048 6230739612 1667115976E-24\\
+31 & -0.4629629963 1633171661 2753482064E-25\\
+32 &  0.1193539790 9715779152 3052371292E-25\\
+33 & -0.3119493285 2201424493 1062147473E-26\\
+34 &  0.8261419734 5334664228 4170028518E-27\\
+35 & -0.2215803373 6609829830 2591177697E-27\\
+36 &  0.6016031671 6542638904 5303124429E-28\\
+37 & -0.1652725098 3821265964 9744302314E-28\\
+38 &  0.4592230358 7730270279 5636377166E-29\\
+39 & -0.1290062767 2132638473 7453212670E-29\\
+40 &  0.3662718481 0320025908 1177078922E-30\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei1(y:OPR):OPR ==
+          infinite? y => 1
+          x:R:=retract(y)
+          t:R:=acos((-20.0::R/x)-1.0::R)::R
+          t01:=    0.191217322586055345391519326510E1::R*cos(0.0::R)/2.0::R
+          t02:=t01-0.420835505286848437550974986680E-01::R*cos(t::R)::R
+          t03:=t02+0.172281962728432678337118157835E-02::R*cos( 2.0::R*t)
+          t04:=t03-0.991578217344456364559842322973E-04::R*cos( 3.0::R*t)
+          t05:=t04+0.717609316802277505265590665592E-05::R*cos( 4.0::R*t)
+          t06:=t05-0.615273314509512696827956791331E-06::R*cos( 5.0::R*t)
+          t07:=t06+0.602485710656275831293999701610E-07::R*cos( 6.0::R*t)
+          t08:=t07-0.657384884528830482295894189637E-08::R*cos( 7.0::R*t)
+          t09:=t08+0.785316754183239981994810079871E-09::R*cos( 8.0::R*t)
+          t10:=t09-0.101373028800387898554202774257E-09::R*cos( 9.0::R*t)
+          t11:=t10+0.139977041322676860277823488623E-10::R*cos(10.0::R*t)
+          t12:=t11-0.205100837678381899618962318711E-11::R*cos(11.0::R*t)
+          t13:=t12+0.316838872600247781814907985818E-12::R*cos(12.0::R*t)
+          t14:=t13-0.513276008283918065415984751899E-13::R*cos(13.0::R*t)
+          t15:=t14+0.868093304076654934187433687383E-14::R*cos(14.0::R*t)
+          t16:=t15-0.152701504090308497198572355351E-14::R*cos(15.0::R*t)
+          t17:=t16+0.278468625164935739650105251453E-15::R*cos(16.0::R*t)
+          t18:=t17-0.524989043742176696808472933696E-16::R*cos(17.0::R*t)
+          t19:=t18+0.102071799124856129247455787226E-16::R*cos(18.0::R*t)
+          t20:=t19-0.204226467989971841308462421876E-17::R*cos(19.0::R*t)
+          t21:=t20+0.419706417272648474408827228562E-18::R*cos(20.0::R*t)
+          t22:=t21-0.884450817617281050816483737536E-19::R*cos(21.0::R*t)
+          t23:=t22+0.190827262959471741995060168262E-19::R*cos(22.0::R*t)
+          t24:=t23-0.420974622293519950336450865676E-20::R*cos(23.0::R*t)
+          t25:=t24+0.948390405819837327641500214512E-21::R*cos(24.0::R*t)
+          t26:=t25-0.217946786013667431994032574014E-21::R*cos(25.0::R*t)
+          t27:=t26+0.510393686907145094993452562741E-22::R*cos(26.0::R*t)
+          t28:=t27-0.121688311333441509089746779693E-22::R*cos(27.0::R*t)
+          t29:=t28+0.295128916644787519294773757144E-23::R*cos(28.0::R*t)
+          t30:=t29-0.727535376377284689714438950920E-24::R*cos(29.0::R*t)
+          t31:=t30+0.182163904862307396121667115976E-24::R*cos(30.0::R*t)
+          t32:=t31-0.462962996316331716612753482064E-25::R*cos(31.0::R*t)
+          t33:=t32+0.119353979097157791523052371292E-25::R*cos(32.0::R*t)
+          t34:=t33-0.311949328522014244931062147473E-26::R*cos(33.0::R*t)
+          t35:=t34+0.826141973453346642284170028518E-27::R*cos(34.0::R*t)
+          t36:=t35-0.221580337366098298302591177697E-27::R*cos(35.0::R*t)
+          t37:=t36+0.601603167165426389045303124429E-28::R*cos(36.0::R*t)
+          t38:=t37-0.165272509838212659649744302314E-28::R*cos(37.0::R*t)
+          t39:=t38+0.459223035877302702795636377166E-29::R*cos(38.0::R*t)
+          t40:=t39-0.129006276721326384737453212670E-29::R*cos(39.0::R*t)
+          t41:=t40+0.366271848103200259081177078922E-30::R*cos(40.0::R*t)
+          t41::OPR
+
+@
+
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients - Continued}
+(b)
+$$
+xe^{-x}Ei(x)=\sum_{k-0}^{40}\ {'}{A_kT_k(t)},\ \ t=(x+7)/3,\ \ 
+(-10 \le x \le -4)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 &  0.1757556496 0612937384 8762834691E 011\\
+ 1 & -0.4358541517 7361661170 5001867964E-01\\
+ 2 & -0.7979507139 5584254013 3217027492E-02\\
+ 3 & -0.1484372327 3037121385 0970210001E-02\\
+ 4 & -0.2800301984 3775145748 6203954948E-03\\
+ 5 & -0.5348648512 8657932303 9177361553E-04\\
+ 6 & -0.1032867243 5735548661 0233266460E-04\\
+ 7 & -0.2014083313 0055368773 2226198639E-05\\
+ 8 & -0.3961758434 2738664582 2338443500E-06\\
+ 9 & -0.7853872767 0966316306 7607656069E-07\\
+10 & -0.1567925981 0074698262 4616270279E-07\\
+11 & -0.3150055939 3763998825 0007372851E-08\\
+12 & -0.6365096822 5242037304 0380263972E-09\\
+13 & -0.1292888113 2805631835 6593121259E-09\\
+14 & -0.2638690999 6592557613 2149942808E-10\\
+15 & -0.5408958287 0450687349 1922207896E-11\\
+16 & -0.1113222784 6010898999 7676692708E-11\\
+17 & -0.2299624726 0744624618 4338864145E-12\\
+18 & -0.4766682389 4951902622 3913482091E-13\\
+19 & -0.9911756747 3352709450 6246643371E-14\\
+20 & -0.2067103580 4957072400 0900805021E-14\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+21 & -0.4322776783 3833850564 5764394579E-15\\
+22 & -0.9063014799 6650172551 4905603356E-16\\
+23 & -0.1904669979 5816613974 4015963342E-16\\
+24 & -0.4011792326 3502786634 6744227520E-17\\
+25 & -0.8467772130 0168322313 4166334685E-18\\
+26 & -0.1790842733 6586966555 5826492204E-18\\
+27 & -0.3794490638 1714782440 1106175166E-19\\
+28 & -0.8053999236 7982798526 0999654058E-20\\
+29 & -0.1712339011 2362012974 3228671244E-20\\
+30 & -0.3646274058 7749686208 6576562816E-21\\
+31 & -0.7775969638 8939479435 3098157647E-22\\
+32 & -0.1660628498 4484020566 2531950966E-22\\
+33 & -0.3551178625 7882509300 5927145352E-23\\
+34 & -0.7603722685 9413580929 5734653294E-24\\
+35 & -0.1630074137 2584900288 9638374755E-24\\
+36 & -0.3498575202 7286322350 7538497255E-25\\
+37 & -0.7517179627 8900988246 0645145143E-26\\
+38 & -0.1616877440 0527227629 8777317918E-26\\
+39 & -0.3481270085 7247569174 8202271565E-27\\
+40 & -0.7502707775 5024654701 0642233720E-28\\
+41 & -0.1618454364 4959102680 7612330206E-28\\
+42 & -0.3494366771 7051616674 9482836452E-29\\
+43 & -0.7551036906 1261678585 6037026797E-30\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei2(y:OPR):OPR ==
+          x:R:=retract(y)
+          t:R:=acos((x+7.0::R)/3.0::R)::R
+          t01:=    0.175755649606129373848762834691E1::R*cos(0.0::R)/2.0::R
+          t02:=t01-0.435854151773616611705001867964E-01::R*cos(t)
+          t03:=t02-0.797950713955842540133217027492E-02::R*cos( 2.0::R*t)
+          t04:=t03-0.148437232730371213850970210001E-02::R*cos( 3.0::R*t)
+          t05:=t04-0.280030198437751457486203954948E-03::R*cos( 4.0::R*t)
+          t06:=t05-0.534864851286579323039177361553E-04::R*cos( 5.0::R*t)
+          t07:=t06-0.103286724357355486610233266460E-04::R*cos( 6.0::R*t)
+          t08:=t07-0.201408331300553687732226198639E-05::R*cos( 7.0::R*t)
+          t09:=t08-0.396175843427386645822338443500E-06::R*cos( 8.0::R*t)
+          t10:=t09-0.785387276709663163067607656069E-07::R*cos( 9.0::R*t)
+          t11:=t10-0.156792598100746982624616270279E-07::R*cos(10.0::R*t)
+          t12:=t11-0.315005593937639988250007372851E-08::R*cos(11.0::R*t)
+          t13:=t12-0.636509682252420373040380263972E-09::R*cos(12.0::R*t)
+          t14:=t13-0.129288811328056318356593121259E-09::R*cos(13.0::R*t)
+          t15:=t14-0.263869099965925576132149942808E-10::R*cos(14.0::R*t)
+          t16:=t15-0.540895828704506873491922207896E-11::R*cos(15.0::R*t)
+          t17:=t16-0.111322278460108989997676692708E-11::R*cos(16.0::R*t)
+          t18:=t17-0.229962472607446246184338864145E-12::R*cos(17.0::R*t)
+          t19:=t18-0.476668238949519026223913482091E-13::R*cos(18.0::R*t)
+          t20:=t19-0.991175674733527094506246643371E-14::R*cos(19.0::R*t)
+          t21:=t20-0.206710358049570724000900805021E-14::R*cos(20.0::R*t)
+          t22:=t21-0.432277678338338505645764394579E-15::R*cos(21.0::R*t)
+          t23:=t22-0.906301479966501725514905603356E-16::R*cos(22.0::R*t)
+          t24:=t23-0.190466997958166139744015963342E-16::R*cos(23.0::R*t)
+          t25:=t24-0.401179232635027866346744227520E-17::R*cos(24.0::R*t)
+          t26:=t25-0.846777213001683223134166334685E-18::R*cos(25.0::R*t)
+          t27:=t26-0.179084273365869665555826492204E-18::R*cos(26.0::R*t)
+          t28:=t27-0.379449063817147824401106175166E-19::R*cos(27.0::R*t)
+          t29:=t28-0.805399923679827985260999654058E-20::R*cos(28.0::R*t)
+          t30:=t29-0.171233901123620129743228671244E-20::R*cos(29.0::R*t)
+          t31:=t30-0.364627405877496862086576562816E-21::R*cos(30.0::R*t)
+          t32:=t31-0.777596963889394794353098157647E-22::R*cos(31.0::R*t)
+          t33:=t32-0.166062849844840205662531950966E-22::R*cos(32.0::R*t)
+          t34:=t33-0.355117862578825093005927145352E-23::R*cos(33.0::R*t)
+          t35:=t34-0.760372268594135809295734653294E-24::R*cos(34.0::R*t)
+          t36:=t35-0.163007413725849002889638374755E-24::R*cos(35.0::R*t)
+          t37:=t36-0.349857520272863223507538497255E-25::R*cos(36.0::R*t)
+          t38:=t37-0.751717962789009882460645145143E-26::R*cos(37.0::R*t)
+          t39:=t38-0.161687744005272276298777317918E-26::R*cos(38.0::R*t)
+          t40:=t39-0.348127008572475691748202271565E-27::R*cos(39.0::R*t)
+          t41:=t40-0.750270777550246547010642233720E-28::R*cos(40.0::R*t)
+          t42:=t41-0.161845436449591026807612330206E-28::R*cos(41.0::R*t)
+          t43:=t42-0.349436677170516166749482836452E-29::R*cos(42.0::R*t)
+          t44:=t43-0.755103690612616785856037026797E-30::R*cos(43.0::R*t)
+          t44::OPR
+
+@
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients - Continued}
+(c)
+$$
+[Ei-log\vert x\vert-\gamma]/x=
+\sum_{k-0}^{33}\ {'}{A_kT_k(t)},\ \ t=x/4,\ \ 
+(-4 \le x \le 4)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 & 0.3293700103 7673912939 3905231421E 01\\
+ 1 & 0.1679835052 3713029156 5505796064E 01\\
+ 2 & 0.7220436105 6787543524 0299679644E 00\\
+ 3 & 0.2600312360 5480956171 3740181192E 00\\
+ 4 & 0.8010494308 1737502239 4742889237E-01\\
+ 5 & 0.2151403663 9763337548 0552483005E-01\\
+ 6 & 0.5116207789 9303312062 1968910894E-02\\
+ 7 & 0.1090932861 0073913560 5066199014E-02\\
+ 8 & 0.2107415320 2393891631 8348675226E-03\\
+ 9 & 0.3719904516 6518885709 5940815956E-04\\
+10 & 0.6043491637 1238787570 4767032866E-05\\
+11 & 0.9092954273 9626095264 9596541772E-06\\
+12 & 0.1273805160 6592647886 5567184969E-06\\
+13 & 0.1669185748 4109890739 0896143814E-07\\
+14 & 0.2054417026 4010479254 7612484551E-08\\
+15 & 0.2383584444 4668176591 4052321417E-09\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+16 & 0.2615386378 8854429666 9068664148E-10\\
+17 & 0.2721858622 8541670644 6550268995E-11\\
+18 & 0.2693750031 9835792992 5326427442E-12\\
+19 & 0.2541220946 7072635546 7884089307E-13\\
+20 & 0.2290130406 8650370941 8510620516E-14\\
+21 & 0.1975465739 0746229940 1057650412E-15\\
+22 & 0.1634024551 9289317406 8635419984E-16\\
+23 & 0.1298235437 0796376099 1961293204E-17\\
+24 & 0.9922587925 0737105964 4632581302E-19\\
+25 & 0.7306252806 7221032944 7230880087E-20\\
+26 & 0.5189676834 6043451272 0780080019E-21\\
+27 & 0.3560409454 0997068112 8043162227E-22\\
+28 & 0.2361979432 5793864237 0187203948E-23\\
+29 & 0.1516837767 7214529754 9624516819E-24\\
+30 & 0.9439089722 2448744292 5310405245E-26\\
+31 & 0.5697227559 5036921198 9581737831E-27\\
+32 & 0.3338333627 7954330315 6597939562E-28\\
+33 & 0.1900626012 8161914852 6680482237E-29\\
+\end{tabular}
+
+\noindent
+($\gamma$=0.5772156649\ 0153286060\ 6512090082\ E\ 00)
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei3(y:OPR):OPR ==
+          x:R:=retract(y)
+          x = 0.0::R => 1
+          t:R:=acos(x/4.0::R)::R
+          t01:=    0.329370010376739129393905231421E1::R*cos(0.0::R)/2.0::R
+          t02:=t01+0.167983505237130291565505796064E1::R*cos(t)
+          t03:=t02+0.722043610567875435240299679644E0::R*cos( 2.0::R*t)
+          t04:=t03+0.260031236054809561713740181192E0::R*cos( 3.0::R*t)
+          t05:=t04+0.801049430817375022394742889237E-01::R*cos( 4.0::R*t)
+          t06:=t05+0.215140366397633375480552483005E-01::R*cos( 5.0::R*t)
+          t07:=t06+0.511620778993033120621968910894E-02::R*cos( 6.0::R*t)
+          t08:=t07+0.109093286100739135605066199014E-02::R*cos( 7.0::R*t)
+          t09:=t08+0.210741532023938916318348675226E-03::R*cos( 8.0::R*t)
+          t10:=t09+0.371990451665188857095940815956E-04::R*cos( 9.0::R*t)
+          t11:=t10+0.604349163712387875704767032866E-05::R*cos(10.0::R*t)
+          t12:=t11+0.909295427396260952649596541772E-06::R*cos(11.0::R*t)
+          t13:=t12+0.127380516065926478865567184969E-06::R*cos(12.0::R*t)
+          t14:=t13+0.166918574841098907390896143814E-07::R*cos(13.0::R*t)
+          t15:=t14+0.205441702640104792547612484551E-08::R*cos(14.0::R*t)
+          t16:=t15+0.238358444446681765914052321417E-09::R*cos(15.0::R*t)
+          t17:=t16+0.261538637888544296669068664148E-10::R*cos(16.0::R*t)
+          t18:=t17+0.272185862285416706446550268995E-11::R*cos(17.0::R*t)
+          t19:=t18+0.269375003198357929925326427442E-12::R*cos(18.0::R*t)
+          t20:=t19+0.254122094670726355467884089307E-13::R*cos(19.0::R*t)
+          t21:=t20+0.229013040686503709418510620516E-14::R*cos(20.0::R*t)
+          t22:=t21+0.197546573907462299401057650412E-15::R*cos(21.0::R*t)
+          t23:=t22+0.163402455192893174068635419984E-16::R*cos(22.0::R*t)
+          t24:=t23+0.129823543707963760991961293204E-17::R*cos(23.0::R*t)
+          t25:=t24+0.992258792507371059644632581302E-19::R*cos(24.0::R*t)
+          t26:=t25+0.730625280672210329447230880087E-20::R*cos(25.0::R*t)
+          t27:=t26+0.518967683460434512720780080019E-21::R*cos(26.0::R*t)
+          t28:=t27+0.356040945409970681128043162227E-22::R*cos(27.0::R*t)
+          t29:=t28+0.236197943257938642370187203948E-23::R*cos(28.0::R*t)
+          t30:=t29+0.151683776772145297549624516819E-24::R*cos(29.0::R*t)
+          t31:=t30+0.943908972224487442925310405245E-26::R*cos(30.0::R*t)
+          t32:=t31+0.569722755950369211989581737831E-27::R*cos(31.0::R*t)
+          t33:=t32+0.333833362779543303156597939562E-28::R*cos(32.0::R*t)
+          t34:=t33+0.190062601281619148526680482237E-29::R*cos(33.0::R*t)
+          t34::OPR
+
+@
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients - Continued}
+(d) 
+$$
+xe^{-x}Ei(x)=\sum_{k-0}^{49}\ {'}{A_kT_k(t)},\ \ t=(x-8)/4,\ \ 
+(4 \le x \le 12)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 &  0.2455133538 7812952867 3420457043E 01\\
+ 1 & -0.1624383791 3037652439 6002276856E 00\\
+ 2 &  0.4495753080 9357264148 0785417193E-01\\
+ 3 & -0.6741578679 9892299884 8718835050E-02\\
+ 4 & -0.1306697142 8032942805 1599341387E-02\\
+ 5 &  0.1381083146 0007257602 0202089820E-02\\
+ 6 & -0.5850228790 1596579868 7368242394E-03\\
+ 7 &  0.1749299341 0789197003 8740976432E-03\\
+ 8 & -0.4047281499 0529303552 2869333800E-04\\
+ 9 &  0.7217102412 1709975003 5752600049E-05\\
+10 & -0.8612776970 1986775241 4815450193E-06\\
+11 & -0.2514475296 5322559777 9084739054E-09 \\
+12 &  0.3794747138 2014951081 4074505574E-07\\
+13 & -0.1442117969 5211980616 0265640172E-07\\
+14 &  0.3935049295 9761013108 7190848042E-08\\
+15 & -0.9284689401 0633175304 7289210353E-09\\
+16 &  0.2031789568 0065461336 6090995698E-09\\
+17 & -0.4292498504 9923683142 7918026902E-10\\
+18 &  0.8992647177 7812393526 8001544182E-11\\
+19 & -0.1900869118 4121097524 2396635722E-11\\
+20 &  0.4092198912 2237383452 6121178338E-12\\
+21 & -0.8999253437 2931901982 5435824585E-13\\
+22 &  0.2019654670 8242638335 4948543451E-13\\
+23 & -0.4612930261 3830820719 4950531726E-14\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+24 &  0.1069023072 9386369566 8857256409E-14\\
+25 & -0.2507030070 5700729569 2572254042E-15\\
+26 &  0.5937322503 7915516070 6073763509E-16\\
+27 & -0.1417734582 4376625234 4732005648E-16\\
+28 &  0.3409203754 3608089342 6806402093E-17\\
+29 & -0.8248290269 5054937928 8702529656E-18\\
+30 &  0.2006369712 6214423139 8824095937E-18\\
+31 & -0.4903851667 9674222440 3498152027E-19\\
+32 &  0.1203734482 3483321716 6664609324E-19\\
+33 & -0.2966282447 1413682538 1453572575E-20\\
+34 &  0.7335512384 2880759924 2142328436E-21\\
+35 & -0.1819924142 9085112734 4263485604E-21\\
+36 &  0.4528629374 2957606021 7359526404E-22\\
+37 & -0.1129980043 7506096133 8906717853E-22\\
+38 &  0.2826681251 2901165692 3764408445E-23\\
+39 & -0.7087717977 1690496166 6732640699E-24\\
+40 &  0.1781104524 0187095153 4401530034E-24\\
+41 & -0.4485004076 6189635731 2006142358E-25\\
+42 &  0.1131540292 5754766224 5053090840E-25\\
+43 & -0.2859957899 7793216379 0414326136E-26\\
+44 &  0.7240775806 9226736175 8172726753E-27\\
+45 & -0.1836132234 1257789805 0666710105E-27\\
+46 &  0.4663128735 2273048658 2600122073E-28\\
+47 & -0.1185959588 9190288794 6724005478E-28\\
+48 &  0.3020290590 5567131073 1137614875E-29\\
+49 & -0.7701650548 1663660609 8827057102E-30\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei4(y:OPR):OPR ==
+          x:R:=retract(y)
+          t:R:=acos((x-8.0::R)/4.0::R)::R
+          t01:=    0.245513353878129528673420457043E1::R*cos(0.0::R)/2.0::R
+          t02:=t01-0.162438379130376524396002276856E0::R*cos(t)
+          t03:=t02+0.449575308093572641480785417193E-01::R*cos( 2.0::R*t)
+          t04:=t03-0.674157867998922998848718835050E-02::R*cos( 3.0::R*t)
+          t05:=t04-0.130669714280329428051599341387E-02::R*cos( 4.0::R*t)
+          t06:=t05+0.138108314600072576020202089820E-02::R*cos( 5.0::R*t)
+          t07:=t06-0.585022879015965798687368242394E-03::R*cos( 6.0::R*t)
+          t08:=t07+0.174929934107891970038740976432E-03::R*cos( 7.0::R*t)
+          t09:=t08-0.404728149905293035522869333800E-04::R*cos( 8.0::R*t)
+          t10:=t09+0.721710241217099750035752600049E-05::R*cos( 9.0::R*t)
+          t11:=t10-0.861277697019867752414815450193E-06::R*cos(10.0::R*t)
+          t12:=t11-0.251447529653225597779084739054E-09::R*cos(11.0::R*t)
+          t13:=t12+0.379474713820149510814074505574E-07::R*cos(12.0::R*t)
+          t14:=t13-0.144211796952119806160265640172E-07::R*cos(13.0::R*t)
+          t15:=t14+0.393504929597610131087190848042E-08::R*cos(14.0::R*t)
+          t16:=t15-0.928468940106331753047289210353E-09::R*cos(15.0::R*t)
+          t17:=t16+0.203178956800654613366090995698E-09::R*cos(16.0::R*t)
+          t18:=t17-0.429249850499236831427918026902E-10::R*cos(17.0::R*t)
+          t19:=t18+0.899264717778123935268001544182E-11::R*cos(18.0::R*t)
+          t20:=t19-0.190086911841210975242396635722E-11::R*cos(19.0::R*t)
+          t21:=t20+0.409219891222373834526121178338E-12::R*cos(20.0::R*t)
+          t22:=t21-0.899925343729319019825435824585E-13::R*cos(21.0::R*t)
+          t23:=t22+0.201965467082426383354948543451E-13::R*cos(22.0::R*t)
+          t24:=t23-0.461293026138308207194950531726E-14::R*cos(23.0::R*t)
+          t25:=t24+0.106902307293863695668857256409E-14::R*cos(24.0::R*t)
+          t26:=t25-0.250703007057007295692572254042E-15::R*cos(25.0::R*t)
+          t27:=t26+0.593732250379155160706073763509E-16::R*cos(26.0::R*t)
+          t28:=t27-0.141773458243766252344732005648E-16::R*cos(27.0::R*t)
+          t29:=t28+0.340920375436080893426806402093E-17::R*cos(28.0::R*t)
+          t30:=t29-0.824829026950549379288702529656E-18::R*cos(29.0::R*t)
+          t31:=t30+0.200636971262144231398824095937E-18::R*cos(30.0::R*t)
+          t32:=t31-0.490385166796742224403498152027E-19::R*cos(31.0::R*t)
+          t33:=t32+0.120373448234833217166664609324E-19::R*cos(32.0::R*t)
+          t34:=t33-0.296628244714136825381453572575E-20::R*cos(33.0::R*t)
+          t35:=t34+0.733551238428807599242142328436E-21::R*cos(34.0::R*t)
+          t36:=t35-0.181992414290851127344263485604E-21::R*cos(35.0::R*t)
+          t37:=t36+0.452862937429576060217359526404E-22::R*cos(36.0::R*t)
+          t38:=t37-0.112998004375060961338906717853E-22::R*cos(37.0::R*t)
+          t39:=t38+0.282668125129011656923764408445E-23::R*cos(38.0::R*t)
+          t40:=t39-0.708771797716904961666732640699E-24::R*cos(39.0::R*t)
+          t41:=t40+0.178110452401870951534401530034E-24::R*cos(40.0::R*t)
+          t42:=t41-0.448500407661896357312006142358E-25::R*cos(41.0::R*t)
+          t43:=t42+0.113154029257547662245053090840E-25::R*cos(42.0::R*t)
+          t44:=t43-0.285995789977932163790414326136E-26::R*cos(43.0::R*t)
+          t45:=t44+0.724077580692267361758172726753E-27::R*cos(44.0::R*t)
+          t46:=t45-0.183613223412577898050666710105E-27::R*cos(45.0::R*t)
+          t47:=t46+0.466312873522730486582600122073E-28::R*cos(46.0::R*t)
+          t48:=t47-0.118595958891902887946724005478E-28::R*cos(47.0::R*t)
+          t49:=t48+0.302029059055671310731137614875E-29::R*cos(48.0::R*t)
+          t50:=t49-0.770165054816636606098827057102E-30::R*cos(49.0::R*t)
+          t50::OPR
+
+@
+
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients - Continued}
+(e)
+$$ xe^{-x}Ei(x)=\sum_{k-0}^{47}\ {'}{A_kT_k(t)},\ \ t=(x-22)/10,\ \ 
+(12 \le x \le 32)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 &  0.2117028640 4369866832 9789991614E 01\\
+ 1 & -0.3204237273 7548579499 0618303177E-01\\
+ 2 &  0.8891732077 3531683589 0182400335E-02\\
+ 3 & -0.2507952805 1892993708 8352442063E-02\\
+ 4 &  0.7202789465 9598754887 5760902487E-03\\
+ 5 & -0.2103490058 5011305342 3531441256E-03\\
+ 6 &  0.6205732318 2769321658 8857730842E-04\\
+ 7 & -0.1826566749 8167026544 9155689733E-04\\
+ 8 &  0.5270651575 2893637580 7788296811E-05\\
+ 9 & -0.1459666547 6199457532 3066719367E-05\\
+10 &  0.3781719973 5896367198 0484193981E-06\\
+11 & -0.8842581282 8407192007 7971589012E-07\\
+12 &  0.1741749198 5383936137 7350309156E-07\\
+13 & -0.2313517747 0436906350 6474480152E-08\\
+14 & -0.1228609819 1808623883 2104835230E-09\\
+15 &  0.2349966236 3228637047 8311381926E-09\\
+16 & -0.1100719401 0272628769 0738963049E-09\\
+17 &  0.3848275157 8612071114 9705563369E-10\\
+18 & -0.1148440967 4900158965 8439301603E-10\\
+19 &  0.3056876293 0885208263 0893626200E-11\\
+20 & -0.7388278729 2847356645 4163131431E-12\\
+21 &  0.1630933094 1659411056 4148013749E-12\\
+22 & -0.3276989373 3127124965 7111774748E-13\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+23 &  0.5898114347 0713196171 1164283918E-14\\
+24 & -0.9099707635 9564920464 3554720718E-15\\
+25 &  0.1040752382 6695538658 5405697541E-15\\
+26 & -0.1809815426 0592279322 7163355935E-17\\
+27 & -0.3777098842 5639477336 9593494417E-17\\
+28 &  0.1580332901 0284795713 6759888420E-17\\
+29 & -0.4684291758 8088273064 8433752957E-18\\
+30 &  0.1199516852 5919809370 7533478542E-18\\
+31 & -0.2823594749 8418651767 9349931117E-19\\
+32 &  0.6293738065 6446352262 7520190349E-20\\
+33 & -0.1352410249 5047975630 5343973177E-20\\
+34 &  0.2837106053 8552914159 0980426210E-21\\
+35 & -0.5867007420 2463832353 1936371015E-22\\
+36 &  0.1205247636 0954731111 2449686917E-22\\
+37 & -0.2474446616 9988486972 8416011246E-23\\
+38 &  0.5099962585 8378500814 2986465688E-24\\
+39 & -0.1058382578 7754224088 7093294733E-24\\
+40 &  0.2215276245 0704827856 6429387155E-25\\
+41 & -0.4679278754 7569625867 1852546231E-26\\
+42 &  0.9972872990 6020770482 4269828079E-27\\
+43 & -0.2143267945 2167880459 1907805844E-27\\
+44 &  0.4640656908 8381811433 8414829515E-28\\
+45 & -0.1011447349 2115139094 8461800780E-28\\
+46 &  0.2217211522 7100771109 3046878345E-29\\
+47 & -0.4884890469 2437855322 4914645512E-30\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei5(y:OPR):OPR ==
+          x:R:=retract(y)
+          t:R:=acos((x-22.0::R)/10.0::R)::R
+          t01:=    0.211702864043698668329789991614E1::R*cos(0.0::R)::R/2.0::R
+          t02:=t01-0.320423727375485794990618303177E-01::R*cos(t)
+          t03:=t02+0.889173207735316835890182400335E-02::R*cos( 2.0::R*t)
+          t04:=t03-0.250795280518929937088352442063E-02::R*cos( 3.0::R*t)
+          t05:=t04+0.720278946595987548875760902487E-03::R*cos( 4.0::R*t)
+          t06:=t05-0.210349005850113053423531441256E-03::R*cos( 5.0::R*t)
+          t07:=t06+0.620573231827693216588857730842E-04::R*cos( 6.0::R*t)
+          t08:=t07-0.182656674981670265449155689733E-04::R*cos( 7.0::R*t)
+          t09:=t08+0.527065157528936375807788296811E-05::R*cos( 8.0::R*t)
+          t10:=t09-0.145966654761994575323066719367E-05::R*cos( 9.0::R*t)
+          t11:=t10+0.378171997358963671980484193981E-06::R*cos(10.0::R*t)
+          t12:=t11-0.884258128284071920077971589012E-07::R*cos(11.0::R*t)
+          t13:=t12+0.174174919853839361377350309156E-07::R*cos(12.0::R*t)
+          t14:=t13-0.231351774704369063506474480152E-08::R*cos(13.0::R*t)
+          t15:=t14-0.122860981918086238832104835230E-09::R*cos(14.0::R*t)
+          t16:=t15+0.234996623632286370478311381926E-09::R*cos(15.0::R*t)
+          t17:=t16-0.110071940102726287690738963049E-09::R*cos(16.0::R*t)
+          t18:=t17+0.384827515786120711149705563369E-10::R*cos(17.0::R*t)
+          t19:=t18-0.114844096749001589658439301603E-10::R*cos(18.0::R*t)
+          t20:=t19+0.305687629308852082630893626200E-11::R*cos(19.0::R*t)
+          t21:=t20-0.738827872928473566454163131431E-12::R*cos(20.0::R*t)
+          t22:=t21+0.163093309416594110564148013749E-12::R*cos(21.0::R*t)
+          t23:=t22-0.327698937331271249657111774748E-13::R*cos(22.0::R*t)
+          t24:=t23+0.589811434707131961711164283918E-14::R*cos(23.0::R*t)
+          t25:=t24-0.909970763595649204643554720718E-15::R*cos(24.0::R*t)
+          t26:=t25+0.104075238266955386585405697541E-15::R*cos(25.0::R*t)
+          t27:=t26-0.180981542605922793227163355935E-17::R*cos(26.0::R*t)
+          t28:=t27-0.377709884256394773369593494417E-17::R*cos(27.0::R*t)
+          t29:=t28+0.158033290102847957136759888420E-17::R*cos(28.0::R*t)
+          t30:=t29-0.468429175880882730648433752957E-18::R*cos(29.0::R*t)
+          t31:=t30+0.119951685259198093707533478542E-18::R*cos(30.0::R*t)
+          t32:=t31-0.282359474984186517679349931117E-19::R*cos(31.0::R*t)
+          t33:=t32+0.629373806564463522627520190349E-20::R*cos(32.0::R*t)
+          t34:=t33-0.135241024950479756305343973177E-20::R*cos(33.0::R*t)
+          t35:=t34+0.283710605385529141590980426210E-21::R*cos(34.0::R*t)
+          t36:=t35-0.586700742024638323531936371015E-22::R*cos(35.0::R*t)
+          t37:=t36+0.120524763609547311112449686917E-22::R*cos(36.0::R*t)
+          t38:=t37-0.247444661699884869728416011246E-23::R*cos(37.0::R*t)
+          t39:=t38+0.509996258583785008142986465688E-24::R*cos(38.0::R*t)
+          t40:=t39-0.105838257877542240887093294733E-24::R*cos(39.0::R*t)
+          t41:=t40+0.221527624507048278566429387155E-25::R*cos(40.0::R*t)
+          t42:=t41-0.467927875475696258671852546231E-26::R*cos(41.0::R*t)
+          t43:=t42+0.997287299060207704824269828079E-27::R*cos(42.0::R*t)
+          t44:=t42-0.214326794521678804591907805844E-27::R*cos(43.0::R*t)
+          t45:=t42+0.464065690883818114338414829515E-28::R*cos(44.0::R*t)
+          t46:=t42-0.101144734921151390948461800780E-28::R*cos(45.0::R*t)
+          t47:=t42+0.221721152271007711093046878345E-29::R*cos(46.0::R*t)
+          t48:=t42-0.488489046924378553224914645512E-30::R*cos(47.0::R*t)
+          t48::OPR
+
+@
+{\vbox{\vskip 1cm}}
+
+{\bf Table 3: Chebyshev Coefficients - Continued}
+(f)
+$$ xe^{-x}Ei(x)=\sum_{k-0}^{46}\ {'}{A_kT_k(t)},\ \ t=(64/x)-1,\ \ 
+(32 \le x < \infty)
+$$
+\begin{tabular}{|r|r|}
+k & $A_k$\hbox{\hskip 3cm}\\
+&\\
+ 0 &  0.2032843945 7961669908 7873844202E 01\\
+ 1 &  0.1669920452 0313628514 7618434339E-01\\
+ 2 &  0.2845284724 3613468074 2489985325E-03\\
+ 3 &  0.7563944358 5162064894 8786693854E-05\\
+ 4 &  0.2798971289 4508591575 0484318090E-06\\
+ 5 &  0.1357901828 5345310695 2556392593E-07\\
+ 6 &  0.8343596202 0404692558 5610289412E-09\\
+ 7 &  0.6370971727 6402484382 7524337306E-10\\
+ 8 &  0.6007247608 8118612357 6083084850E-11\\
+ 9 &  0.7022876174 6797735907 5059216588E-12\\
+10 &  0.1018302673 7036876930 9667322152E-12\\
+11 &  0.1761812903 4308800404 0656741554E-13\\
+12 &  0.3250828614 2353606942 4072007647E-14\\
+13 &  0.5071770025 5058186788 1479300685E-15\\
+14 &  0.1665177387 0432942985 3520036957E-16\\
+15 & -0.3166753890 7975144007 2410018963E-16\\
+16 & -0.1588403763 6641415154 8423134074E-16\\
+17 & -0.4175513256 1380188308 9626455063E-17\\
+18 & -0.2892347749 7071418820 2868862358E-18\\
+19 &  0.2800625903 3966080728 9978777339E-18\\
+20 &  0.1322938639 5392708914 0532005364E-18\\
+21 &  0.1804447444 1773019958 5334811191E-19\\
+22 & -0.7905384086 5226165620 2021080364E-20\\
+23 & -0.4435711366 3695734471 8167314045E-20\\
+\end{tabular}
+\begin{tabular}{|r|r|}
+24 & -0.4264103994 9781026176 0579779746E-21\\
+25 &  0.3920101766 9371439072 5625388636E-21\\
+26 &  0.1527378051 3439636447 2804486402E-21\\
+27 & -0.1024849527 0494906078 6953149788E-22\\
+28 & -0.2134907874 7710893794 8904287231E-22\\
+29 & -0.3239139475 1602368761 4279789345E-23\\
+30 &  0.2142183762 2964597029 6249355934E-23\\
+31 &  0.8234609419 6189955316 9207838151E-24\\
+32 & -0.1524652829 6206721081 1495038147E-24\\
+33 & -0.1378208282 4882440129 0438126477E-24\\
+34 &  0.2131311201 4287370679 1513005998E-26\\
+35 &  0.2012649651 8713266585 9213006507E-25\\
+36 &  0.1995535662 0563740232 0607178286E-26\\
+37 & -0.2798995812 2017971142 6020884464E-26\\
+38 & -0.5534511830 5070025094 9784942560E-27\\
+39 &  0.3884995422 6845525312 9749000696E-27\\
+40 &  0.1121304407 2330701254 0043264712E-27\\
+41 & -0.5566568286 7445948805 7823816866E-28\\
+42 & -0.2045482612 4651357628 8865878722E-28\\
+43 &  0.8453814064 4893808943 7361193598E-29\\
+44 &  0.3565755151 2015152659 0791715785E-29\\
+45 & -0.1383652423 4779775181 0195772006E-29\\
+46 & -0.6062142653 2093450576 7865286306E-30\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
+        Ei6(y:OPR):OPR ==
+          infinite? y => 1
+          x:R:=retract(y)
+          m:R:=64.0::R/x-1.0::R
+          t:R:=acos(m::R)::R
+          t01:=    0.203284394579616699087873844202E1::R*cos(0.0::R)::R/2.0::R
+          t02:=t01+0.166992045203136285147618434339E-01::R*cos(t)
+          t03:=t02+0.284528472436134680742489985325E-03::R*cos( 2.0::R*t)
+          t04:=t03+0.756394435851620648948786693854E-05::R*cos( 3.0::R*t)
+          t05:=t04+0.279897128945085915750484318090E-06::R*cos( 4.0::R*t)
+          t06:=t05+0.135790182853453106952556392593E-07::R*cos( 5.0::R*t)
+          t07:=t06+0.834359620204046925585610289412E-09::R*cos( 6.0::R*t)
+          t08:=t07+0.637097172764024843827524337306E-10::R*cos( 7.0::R*t)
+          t09:=t08+0.600724760881186123576083084850E-11::R*cos( 8.0::R*t)
+          t10:=t09+0.702287617467977359075059216588E-12::R*cos( 9.0::R*t)
+          t11:=t10+0.101830267370368769309667322152E-12::R*cos(10.0::R*t)
+          t12:=t11+0.176181290343088004040656741554E-13::R*cos(11.0::R*t)
+          t13:=t12+0.325082861423536069424072007647E-14::R*cos(12.0::R*t)
+          t14:=t13+0.507177002550581867881479300685E-15::R*cos(13.0::R*t)
+          t15:=t14+0.166517738704329429853520036957E-16::R*cos(14.0::R*t)
+          t16:=t15-0.316675389079751440072410018963E-16::R*cos(15.0::R*t)
+          t17:=t16-0.158840376366414151548423134074E-16::R*cos(16.0::R*t)
+          t18:=t17-0.417551325613801883089626455063E-17::R*cos(17.0::R*t)
+          t19:=t18-0.289234774970714188202868862358E-18::R*cos(18.0::R*t)
+          t20:=t19+0.280062590339660807289978777339E-18::R*cos(19.0::R*t)
+          t21:=t20+0.132293863953927089140532005364E-18::R*cos(20.0::R*t)
+          t22:=t21+0.180444744417730199585334811191E-19::R*cos(21.0::R*t)
+          t23:=t22-0.790538408652261656202021080364E-20::R*cos(22.0::R*t)
+          t24:=t23-0.443571136636957344718167314045E-20::R*cos(23.0::R*t)
+          t25:=t24-0.426410399497810261760579779746E-21::R*cos(24.0::R*t)
+          t26:=t25+0.392010176693714390725625388636E-21::R*cos(25.0::R*t)
+          t27:=t26+0.152737805134396364472804486402E-21::R*cos(26.0::R*t)
+          t28:=t27-0.102484952704949060786953149788E-22::R*cos(27.0::R*t)
+          t29:=t28-0.213490787477108937948904287231E-22::R*cos(28.0::R*t)
+          t30:=t29-0.323913947516023687614279789345E-23::R*cos(29.0::R*t)
+          t31:=t30+0.214218376229645970296249355934E-23::R*cos(30.0::R*t)
+          t32:=t31+0.823460941961899553169207838151E-24::R*cos(31.0::R*t)
+          t33:=t32-0.152465282962067210811495038147E-24::R*cos(32.0::R*t)
+          t34:=t33-0.137820828248824401290438126477E-24::R*cos(33.0::R*t)
+          t35:=t34+0.213131120142873706791513005998E-26::R*cos(34.0::R*t)
+          t36:=t35+0.201264965187132665859213006507E-25::R*cos(35.0::R*t)
+          t37:=t36+0.199553566205637402320607178286E-26::R*cos(36.0::R*t)
+          t38:=t37-0.279899581220179711426020884464E-26::R*cos(37.0::R*t)
+          t39:=t38-0.553451183050700250949784942560E-27::R*cos(38.0::R*t)
+          t40:=t39+0.388499542268455253129749000696E-27::R*cos(39.0::R*t)
+          t41:=t40+0.112130440723307012540043264712E-27::R*cos(40.0::R*t)
+          t42:=t41-0.556656828674459488057823816866E-28::R*cos(41.0::R*t)
+          t43:=t42-0.204548261246513576288865878722E-28::R*cos(42.0::R*t)
+          t44:=t43+0.845381406448938089437361193598E-29::R*cos(43.0::R*t)
+          t45:=t44+0.356575515120151526590791715785E-29::R*cos(44.0::R*t)
+          t46:=t45-0.138365242347797751810195772006E-29::R*cos(45.0::R*t)
+          t47:=t46-0.606214265320934505767865286306E-30::R*cos(46.0::R*t)
+          t47::OPR
+
+@
+
+{\vbox{\vskip 1cm}}
+
+{\bf Table 4: Function Values of the Associated Functions}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=-(20/x)-1$ & $xe^{-x}Ei(x)$\hbox{\hskip 3cm}\\
+&&\\
+$-\infty$ & -1.000 & 0.1000000000 0000000000 0000000000 E 01\\
+-160      & -0.875 & 0.9938266956 7406127387 8797850088 E 00\\
+-80       & -0.750 & 0.9878013330 9428877356 4522608410 E 00\\
+-53 1/3   & -0.625 & 0.9819162901 4319443961 7735426105 E 00\\
+-40       & -0.500 & 0.9761646031 8514305080 8000604060 E 00\\
+-32       & -0.375 & 0.9705398840 7466392046 2584664361 E 00\\
+-26 2/3   & -0.250 & 0.9650362511 2337703576 3536593528 E 00\\
+-22 6/7   & -0.125 & 0.9596482710 7936727616 5478970820 E 00\\
+-20       & -0.000 & 0.9543709099 1921683397 5195829433 E 00\\
+-17 7/9   &  0.125 & 0.9491994907 7974574460 6445346803 E 00\\
+-16       &  0.250 & 0.9441296577 3690297898 4149471583 E 00\\
+-14 6/11  &  0.375 & 0.9391573444 1928424124 0422409988 E 00\\
+-13 1/3   &  0.500 & 0.9342787466 5341046480 9375801650 E 00\\
+-12 4/13  &  0.625 & 0.9294902984 9721403772 5319679042 E 00\\
+-11 3/7   &  0.750 & 0.9247886511 4084169605 5993585492 E 00\\
+-10 2/3   &  0.875 & 0.9201706542 4944567620 2148012149 E 00\\
+-10       &  1.000 & 0.9156333393 9788081876 0698157666 E 00
+\end{tabular}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=-(x+7)/3$ & $xe^{-x}Ei(x)$\hbox{\hskip 3cm}\\
+&&\\
+-10.000 & -1.000 & 0.9156333393 9788081876 0698157661 E 01\\
+ -9.625 & -0.875 & 0.9128444614 6799341885 6575662217 E 00\\
+ -9.250 & -0.750 & 0.9098627515 2542413937 8954274597 E 00\\
+ -8.875 & -0.625 & 0.9066672706 5475388033 4995756418 E 00\\
+ -8.500 & -0.500 & 0.9032339019 7320784414 4682926135 E 00\\
+ -8.125 & -0.375 & 0.8995347176 8847383630 1415777697 E 00\\
+ -7.750 & -0.250 & 0.8955371870 8753915717 9475513219 E 00\\
+ -7.375 & -0.125 & 0.8912031763 2125431626 7087476258 E 00\\
+ -7.000 & -0.000 & 0.8864876725 3642935289 3993846569 E 00\\
+ -6.625 &  0.125 & 0.8813371384 6821020039 4305706270 E 00\\
+ -6.250 &  0.250 & 0.8756873647 8846593227 6462155532 E 00\\
+ -5.875 &  0.375 & 0.8694606294 5411341030 2047153364 E 00\\
+ -5.500 &  0.500 & 0.8625618846 9070142209 0918986586 E 00\\
+ -5.125 &  0.625 & 0.8548735538 9019954239 2425567234 E 00\\
+ -4.750 &  0.750 & 0.8462482991 0358736117 1665798810 E 00\\
+ -4.375 &  0.875 & 0.8364987545 5629874174 2152267582 E 00\\
+ -4.000 &  1.000 & 0.8253825996 0422333240 8183035504 E 00
+\end{tabular}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=x/4$ &
+$[Ei(x)-log\vert x\vert - \gamma]/x$\hbox{\hskip 2cm}\\
+&&\\
+ -4.0 & -1.000 & 0.4918223446 0781809647 9962798267 E 00\\
+ -3.5 & -0.875 & 0.5248425066 4412835691 8258753311 E 00\\
+ -3.0 & -0.750 & 0.5629587782 2127986313 8086024270 E 00\\
+ -2.5 & -0.625 & 0.6073685258 5838306451 4266925640 E 00\\
+ -2.0 & -0.500 & 0.6596316780 8476964479 5492023380 E 00\\
+ -1.5 & -0.375 & 0.7218002369 4421992965 7623030310 E 00\\
+ -1.0 & -0.250 & 0.7965995992 9705313428 3675865540 E 00\\
+ -0.5 & -0.125 & 0.8876841582 3549672587 2151815870 E 00\\
+  0.0 & -0.000 & 0.1000000000 0000000000 0000000000 E 01\\
+  0.5 &  0.125 & 0.1140302841 0431720574 6248768807 E 01\\
+  1.0 &  0.250 & 0.1317902151 4544038948 6000884424 E 01\\
+  1.5 &  0.375 & 0.1545736450 7467337302 4859074039 E 01\\
+  2.0 &  0.500 & 0.1841935755 2702059966 7788045934 E 01\\
+  2.5 &  0.625 & 0.2232103799 1211651144 5340506423 E 01\\
+  3.0 &  0.750 & 0.2752668205 6852580020 0219289740 E 01\\
+  3.5 &  0.875 & 0.3455821531 9301241243 7300898811 E 01\\
+  4.0 &  1.000 & 0.4416841111 0086991358 0118598668 E 01
+\end{tabular}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=(x-8)/4$ &$xe^{-x}Ei(x)$\hbox{\hskip 3cm}\\
+&&\\
+ 4.0 & -1.000 & 0.1438208031 4544827847 0968670330 E 01\\
+ 4.5 & -0.875 & 0.1396419029 6297460710 0674523183 E 01\\
+ 5.0 & -0.750 & 0.1353831277 4552859779 0189174047 E 01\\
+ 5.5 & -0.625 & 0.1314143565 7421192454 1219816991 E 01\\
+ 6.0 & -0.500 & 0.1278883860 4895616189 2314099578 E 01\\
+ 6.5 & -0.375 & 0.1248391155 0017014864 0741941387 E 01\\
+ 7.0 & -0.250 & 0.1222408052 3605310590 3656846622 E 01\\
+ 7.5 & -0.125 & 0.1200421499 5996307864 3879158950 E 01\\
+ 8.0 & -0.000 & 0.1181847986 9872079731 7739362644 E 01\\
+ 8.5 &  0.125 & 0.1166126525 8117484943 9918142965 E 01\\
+ 9.0 &  0.250 & 0.1152759208 7089248132 2396814952 E 01\\
+ 9.5 &  0.375 & 0.1141323475 9526242015 5338560641 E 01\\
+10.0 &  0.500 & 0.1131470204 7341077803 4051681355 E 01\\
+10.5 &  0.625 & 0.1122915570 0177606064 2888630755 E 01\\
+11.0 &  0.750 & 0.1115430938 9980384416 4779434229 E 01\\
+11.5 &  0.875 & 0.1108832926 3050773058 6855234934 E 01\\
+12.0 &  1.000 & 0.1102974544 9067590726 7241234953 E 01\\
+\end{tabular}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=(x-22)/10$ &$xe^{-x}Ei(x)$\hbox{\hskip 3cm}\\
+&&\\
+12.00 & -1.000 & 0.1102974544 9067590726 7241234952 E 01\\
+13.25 & -0.875 & 0.1090844898 2154756926 6468614954 E 01\\
+14.50 & -0.750 & 0.1081351395 7351912850 6346643795 E 01\\
+15.75 & -0.625 & 0.1073701384 1997572371 2157900374 E 01\\
+17.00 & -0.500 & 0.1067393691 9585378312 9572196197 E 01\\
+18.25 & -0.375 & 0.1062096608 6221502426 8372647556 E 01\\
+19.50 & -0.250 & 0.1057581342 1587250319 5393949410 E 01\\
+20.75 & -0.125 & 0.1053684451 2894094408 2102194964 E 01\\
+22.00 & -0.000 & 0.1050285719 6851897941 1780664532 E 01\\
+23.25 &  0.125 & 0.1047294551 7053248581 1492365591 E 01\\
+24.50 &  0.250 & 0.1044641267 9046436368 9761075289 E 01\\
+25.75 &  0.375 & 0.1042271337 2023202388 5710928048 E 01\\
+27.00 &  0.500 & 0.1040141438 3230104381 3713899754 E 01\\
+28.25 &  0.625 & 0.1038216700 3601458768 0056548394 E 01\\
+29.50 &  0.750 & 0.1036468726 2924118457 5154685419 E 01\\
+30.75 &  0.875 & 0.1034874149 8964796947 2990938990 E 01\\
+32.00 &  1.000 & 0.1033413564 2162410494 3493552567 E 01\\
+\end{tabular}
+
+{\vbox{\vskip 1cm}}
+
+\begin{tabular}{|r|c|r|}
+x\hbox{\hskip 0.5cm} & $t=(64/x)-1$ &$xe^{-x}Ei(x)$\hbox{\hskip 3cm}\\
+&&\\
+$\infty$ & -1.000 & 0.100000000 0000000000 00000000001 E 01\\
+512      & -0.875 & 0.100196079 9450711925 31337468473 E 01\\
+256      & -0.750 & 0.100393713 0905698627 88009078297 E 01\\
+170 2/3  & -0.625 & 0.100592927 5692929112 94663030932 E 01\\
+128      & -0.500 & 0.100793752 4408140182 81776821694 E 01\\
+102 2/5  & -0.375 & 0.100996217 7406449755 74367545570 E 01\\
+85 1/3   & -0.250 & 0.101200354 5332988482 01864466702 E 01\\
+73 1/7   & -0.125 & 0.101406194 9696971331 45942329335 E 01\\
+64       & -0.000 & 0.101613772 3494325321 70357100831 E 01\\
+56 8/9   &  0.125 & 0.101823121 1884832696 82337017143 E 01\\
+51 1/5   &  0.250 & 0.102034277 2930783774 87217829808 E 01\\
+46 6/11  &  0.375 & 0.102247277 8405420595 91275364791 E 01\\
+42 2/3   &  0.500 & 0.102462161 4681078391 01187804247 E 01\\
+39 5/13  &  0.625 & 0.102678968 3709028524 50984510823 E 01\\
+36 4/7   &  0.750 & 0.102897740 4105808008 63378435059 E 01\\
+34 2/15  &  0.875 & 0.103118521 2364659263 55875784663 E 01\\
+32       &  1.000 & 0.103341356 4216241049 43493552567 E 01\\
+\end{tabular}
+
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+
         polygamma(k,z)  == CPSI(k, z)$Lisp
         polygamma(k,x)  == RPSI(k, x)$Lisp
 
@@ -811,5 +2350,43 @@ Selected Results and Methods''. New York: van Nostrand Reinhold, 1983.
 \bibitem{7} Cody, W.J., and H.C. Thatcher, Jr. ``Rational Chebyshev
 Approximations for the Exponential Integral $E_1(x)$.''
 Mathematics of Computation, 11, pp. 641-649, 1968
+\bibitem{8} Lee, K.L.,``High-precision Chebyshev series approximation
+to the exponential integral'', NASA-TN-D-5953, A-3571, No Copyright
+Doc. ID=19700026648, Accession ID=70N35964, Aug 1970
+\bibitem{9} Harris, Frank E.: Tables of the Exponential Integral
+Ei(x). Math. Tables and Other Aids to Computation, vol. 11, 1957,
+pp.9-16 
+\bibitem{10} Miller, James; and Hurst, R.P.: Simplified Calculation of
+the Exponential Integral. Math. Tables and Other Aids to Computation,
+vol. 12, 1958, pp 187-193.
+\bibitem{11} Clenshaw, C.W.: Chebyshev Series for Mathematical
+Functions. Mathematical Tables, vol. 5, National Physical Laboratory,
+Her Majesty's Stationery Office, London, 1962, p. 29.
+\bibitem{12} Cody, W.J.; and Thacher, H.C., Jr.: Rational
+Approximations for the Exponential Integral $E_1(x)$. Math. Comp.,
+vol.22, July 1968, pp. 641-649.
+\bibitem{13} Cody, W.J.; and Thacher, H.C., Jr.: Rational
+Approximations for the Exponential Integral $Ei(x)$. Math. Comp.,
+vol.22, April 1969, pp. 289-303.
+\bibitem{14} Murnaghan, F.D.; and Wrench, J.W., Jr.: The Converging
+Factor for the Exponential Integral. Rep. 1535, David Taylor Model
+Basin Applied Mathematics Lab., Jan. 1963.
+\bibitem{16} Clenshaw, C.W.: The Numerical Solution of Linear
+Differential Equation in Chebyshev Series. Proc. Cambridge Phil. Soc.,
+vol. 53, 1957, pp 134-149
+\bibitem{17} Fox, L.; and Parker, I.B.: Chebyshev Polynomials in
+Numerical Analysis. Oxford Univ. Press, London, 1968.
+\bibitem{18} Jeffrey, Alan ``Handbook of Mathematical Formulas and
+Integrals'' Elsevier Academic Press 2004 3rd Edition ISBN
+0-12-382256-4 pp167-171
+\bibitem{19} Press, William, et.al., ``Numerical Recipes in C''
+Press Syndicate Univ. of Cambridge, 1995 ISBN 0-521-43108-5 
+pp190-194
+\bibitem{20} Press, William, et.al., ``Numerical Recipes in C''
+Press Syndicate Univ. of Cambridge, 1995 ISBN 0-521-43108-5 
+p196
+\bibitem{21} Press, William, et.al., ``Numerical Recipes in C''
+Press Syndicate Univ. of Cambridge, 1995 ISBN 0-521-43108-5 
+p222-225
 \end{thebibliography}
 \end{document}
diff --git a/src/input/Makefile.pamphlet b/src/input/Makefile.pamphlet
index 6cc1513..a54a9e7 100644
--- a/src/input/Makefile.pamphlet
+++ b/src/input/Makefile.pamphlet
@@ -302,8 +302,8 @@ REGRES= algaggr.regress algbrbf.regress  algfacob.regress alist.regress  \
     cycles1.regress   cycles.regress   cyfactor.regress \
     danzwill.regress  decimal.regress  defintef.regress defintrf.regress \
     derham.regress    dfloat.regress   dhtri.regress    divisor.regress \
-    dmp.regress       dpol.regress     e1.regress       easter.regress  \
-    efi.regress \
+    dmp.regress       dpol.regress     e1.regress       ei.regress \
+    easter.regress    efi.regress \
     eigen.regress     elemfun.regress  elemnum.regress  elfuts.regress \
     elt.regress       en.regress \
     eq.regress        eqtbl.regress    equation2.regress \
@@ -542,6 +542,7 @@ FILES= ${OUT}/algaggr.input  ${OUT}/algbrbf.input    ${OUT}/algfacob.input \
        ${OUT}/drawcfun.input ${OUT}/drawcurv.input \
        ${OUT}/draw.input     ${OUT}/drawcx.input     ${OUT}/drawex.input \
        ${OUT}/drawpoly.input ${OUT}/drawx.input      ${OUT}/e1.input     \
+       ${OUT}/ei.input       \
        ${OUT}/easter.input   ${OUT}/efi.input        ${OUT}/egg.input      \
        ${OUT}/eigen.input \
        ${OUT}/elemfun.input  ${OUT}/elemnum.input    ${OUT}/elfuts.input \
@@ -776,7 +777,7 @@ DOCFILES= \
   ${DOC}/e04jaf.input.dvi      ${DOC}/e04mbf.input.dvi     \
   ${DOC}/e04naf.input.dvi      ${DOC}/e04ucf.input.dvi     \
   ${DOC}/e04ycf.input.dvi      ${DOC}/e1.input.dvi         \
-  ${DOC}/easter.input.dvi     \
+  ${DOC}/ei.input.dvi          ${DOC}/easter.input.dvi     \
   ${DOC}/ecfact.as.dvi         ${DOC}/efi.input.dvi        \
   ${DOC}/egg.input.dvi         ${DOC}/eigen.input.dvi      \
   ${DOC}/elemfun.input.dvi     ${DOC}/elemnum.input.dvi    \
diff --git a/src/input/ei.input.pamphlet b/src/input/ei.input.pamphlet
new file mode 100644
index 0000000..9c84341
--- /dev/null
+++ b/src/input/ei.input.pamphlet
@@ -0,0 +1,2311 @@
+\documentclass{article}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input ei.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+The Ei implementation in Axiom uses Chebyshev\cite{1} polynomials
+to approximate the function. The coefficients are not used
+here but kept here for reference purposes.
+
+The values generated are compared against the values in
+Abramowitz and Stegun\cite{2}.
+<<*>>=
+)spool ei.output
+)set message test on
+)set message auto off
+)clear all
+digits 35
+
+--S 1 of 20
+gamma:=0.577215664901532860606512090082
+--R 
+--R
+--R   (2)  0.5772156649 0153286060 6512090082
+--R                                                                  Type: Float
+--E 1
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(-\infty < x \le -10)$ in the polynomial
+$$\sum_{k=0}^{40}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=(-20/x)-1$
+
+<<*>>=
+
+--S 2 of 20
+aChebyshev:=_
+[0.191217322586055345391519326510E1,_
+-0.420835505286848437550974986680E-01,_
+ 0.172281962728432678337118157835E-02,_
+-0.991578217344456364559842322973E-04,_
+ 0.717609316802277505265590665592E-05,_
+-0.615273314509512696827956791331E-06,_
+ 0.602485710656275831293999701610E-07,_
+-0.657384884528830482295894189637E-08,_
+ 0.785316754183239981994810079871E-09,_
+-0.101373028800387898554202774257E-09,_
+ 0.139977041322676860277823488623E-10,_
+-0.205100837678381899618962318711E-11,_
+ 0.316838872600247781814907985818E-12,_
+-0.513276008283918065415984751899E-13,_
+ 0.868093304076654934187433687383E-14,_
+-0.152701504090308497198572355351E-14,_
+ 0.278468625164935739650105251453E-15,_
+-0.524989043742176696808472933696E-16,_
+ 0.102071799124856129247455787226E-16,_
+-0.204226467989971841308462421876E-17,_
+ 0.419706417272648474408827228562E-18,_
+-0.884450817617281050816483737536E-19,_
+ 0.190827262959471741995060168262E-19,_
+-0.420974622293519950336450865676E-20,_
+ 0.948390405819837327641500214512E-21,_
+-0.217946786013667431994032574014E-21,_
+ 0.510393686907145094993452562741E-22,_
+-0.121688311333441509089746779693E-22,_
+ 0.295128916644787519294773757144E-23,_
+-0.727535376377284689714438950920E-24,_
+ 0.182163904862307396121667115976E-24,_
+-0.462962996316331716612753482064E-25,_
+ 0.119353979097157791523052371292E-25,_
+-0.311949328522014244931062147473E-26,_
+ 0.826141973453346642284170028518E-27,_
+-0.221580337366098298302591177697E-27,_
+ 0.601603167165426389045303124429E-28,_
+-0.165272509838212659649744302314E-28,_
+ 0.459223035877302702795636377166E-29,_
+-0.129006276721326384737453212670E-29,_
+ 0.366271848103200259081177078922E-30]
+--R 
+--R
+--R   (3)
+--R   [1.9121732258 6055345391 51932651, - 0.0420835505 2868484375 5097498668,
+--R    0.0017228196 2728432678 3371181578 35,
+--R    - 0.0000991578 2173444563 6455984232 2973,
+--R    0.0000071760 9316802277 5052655906 65592,
+--R    - 0.6152733145 0951269682 7956791331 E -6,
+--R    0.6024857106 5627583129 399970161 E -7,
+--R    - 0.6573848845 2883048229 5894189637 E -8,
+--R    0.7853167541 8323998199 4810079871 E -9,
+--R    - 0.1013730288 0038789855 4202774257 E -9,
+--R    0.1399770413 2267686027 7823488623 E -10,
+--R    - 0.2051008376 7838189961 8962318711 E -11,
+--R    0.3168388726 0024778181 4907985818 E -12,
+--R    - 0.5132760082 8391806541 5984751899 E -13,
+--R    0.8680933040 7665493418 7433687383 E -14,
+--R    - 0.1527015040 9030849719 8572355351 E -14,
+--R    0.2784686251 6493573965 0105251453 E -15,
+--R    - 0.5249890437 4217669680 8472933696 E -16,
+--R    0.1020717991 2485612924 7455787226 E -16,
+--R    - 0.2042264679 8997184130 8462421876 E -17,
+--R    0.4197064172 7264847440 8827228562 E -18,
+--R    - 0.8844508176 1728105081 6483737536 E -19,
+--R    0.1908272629 5947174199 5060168262 E -19,
+--R    - 0.4209746222 9351995033 6450865676 E -20,
+--R    0.9483904058 1983732764 1500214512 E -21,
+--R    - 0.2179467860 1366743199 4032574014 E -21,
+--R    0.5103936869 0714509499 3452562741 E -22,
+--R    - 0.1216883113 3344150908 9746779693 E -22,
+--R    0.2951289166 4478751929 4773757144 E -23,
+--R    - 0.7275353763 7728468971 443895092 E -24,
+--R    0.1821639048 6230739612 1667115976 E -24,
+--R    - 0.4629629963 1633171661 2753482064 E -25,
+--R    0.1193539790 9715779152 3052371292 E -25,
+--R    - 0.3119493285 2201424493 1062147473 E -26,
+--R    0.8261419734 5334664228 4170028518 E -27,
+--R    - 0.2215803373 6609829830 2591177697 E -27,
+--R    0.6016031671 6542638904 5303124429 E -28,
+--R    - 0.1652725098 3821265964 9744302314 E -28,
+--R    0.4592230358 7730270279 5636377166 E -29,
+--R    - 0.1290062767 2132638473 745321267 E -29,
+--R    0.3662718481 0320025908 1177078922 E -30]
+--R                                                             Type: List Float
+--E 2
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 3 of 20
+[[-160.,0.993826695674061273878797850088,_
+ Ei1(-160.0),Ei1(-160.0)-0.993826695674061273878797850088],_
+[-80.0,0.987801333094288773564522608410,_
+ Ei1(-80.0),Ei1(-80.0)-0.987801333094288773564522608410],_
+[-53.0-1.0/3.0,0.981916290143194439617735426105,_
+ Ei1(-53.0-1.0/3.0),Ei1(-53.0-1.0/3.0)-0.981916290143194439617735426105],_
+[-40.0,0.976164603185143050808000604060,_
+ Ei1(-40.0),Ei1(-40.0)-0.976164603185143050808000604060],_
+[-32.0,0.970539884074663920462584664361,_
+ Ei1(-32.0),Ei1(-32.0)-0.970539884074663920462584664361],_
+[-26.0-2.0/3.0,0.965036251123377035763536593528,_
+ Ei1(-26.0-2.0/3.0),Ei1(-26.0-2.0/3.0)-0.965036251123377035763536593528],_
+[-22.0-6.0/7.0,0.959648271079367276165478970820,_
+ Ei1(-22.0-6.0/7.0),Ei1(-22.0-6.0/7.0)-0.959648271079367276165478970820],_
+[-20.0,0.954370909919216833975195829433,_
+ Ei1(-20.0),Ei1(-20.0)-0.954370909919216833975195829433],_
+[-17.0-7.0/9.0,0.949199490779745744606445346803,_
+ Ei1(-17.0-7.0/9.0),Ei1(-17.0-7.0/9.0)-0.949199490779745744606445346803],_
+[-16.0,0.944129657736902978984149471583,_
+ Ei1(-16.0),Ei1(-16.0)-0.944129657736902978984149471583],_
+[-14.0-6.0/11.0,0.939157344419284241240422409988,_
+ Ei1(-14.0-6.0/11.0),Ei1(-14.0-6.0/11.0)-0.939157344419284241240422409988],_
+[-13.0-1.0/3.0,0.934278746653410464809375801650,_
+ Ei1(-13.0-1.0/3.0),Ei1(-13.0-1.0/3.0)-0.934278746653410464809375801650],_
+[-12.0-4.0/13.0,0.929490298497214037725319679042,_
+ Ei1(-12.0-4.0/13.0),Ei1(-12.0-4.0/13.0)-0.929490298497214037725319679042],_
+[-11.0-3.0/7.0,0.924788651140841696055993585492,_
+ Ei1(-11.0-3.0/7.0),Ei1(-11.0-3.0/7.0)-0.924788651140841696055993585492],_
+[-10.0-2.0/3.0,0.920170654249445676202148012149,_
+ Ei1(-10.0-2.0/3.0),Ei1(-10.0-2.0/3.0)-0.920170654249445676202148012149],_
+[-10.0,0.915633339397880818760698157666,_
+ Ei1(-10.0),Ei1(-10.0)-0.915633339397880818760698157666]]
+--R 
+--R
+--R   (4)
+--R   [[- 160.,0.99382669567406123,0.99382669567406123,0.],
+--R    [- 80.,0.98780133309428875,0.98780133309428886,1.1102230246251565E-16],
+--R    [- 53.333333333333336,0.98191629014319448,0.98191629014319448,0.],
+--R    [- 40.,0.97616460318514309,0.97616460318514309,0.],
+--R    [- 32.,0.97053988407466396,0.97053988407466363,- 3.3306690738754696E-16],
+--R    [- 26.666666666666668,0.96503625112337699,0.96503625112337699,0.],
+--R
+--R     [- 22.857142857142858, 0.95964827107936723, 0.95964827107936734,
+--R      1.1102230246251565E-16]
+--R     ,
+--R    [- 20.,0.9543709099192168,0.95437090991921691,1.1102230246251565E-16],
+--R    [- 17.777777777777779,0.94919949077974575,0.94919949077974575,0.],
+--R    [- 16.,0.94412965773690294,0.94412965773690294,0.],
+--R
+--R     [- 14.545454545454545, 0.93915734441928422, 0.93915734441928411,
+--R      - 1.1102230246251565E-16]
+--R     ,
+--R
+--R     [- 13.333333333333334, 0.93427874665341049, 0.9342787466534106,
+--R      1.1102230246251565E-16]
+--R     ,
+--R
+--R     [- 12.307692307692308, 0.92949029849721398, 0.92949029849721387,
+--R      - 1.1102230246251565E-16]
+--R     ,
+--R    [- 11.428571428571429,0.92478865114084174,0.92478865114084174,0.],
+--R
+--R     [- 10.666666666666666, 0.92017065424944566, 0.92017065424944577,
+--R      1.1102230246251565E-16]
+--R     ,
+--R    [- 10.,0.91563333939788083,0.91563333939788094,1.1102230246251565E-16]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 3
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(-10 \le x \le -4)$ in the polynomial
+$$\sum_{k=0}^{43}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=(x+7)/3$
+
+<<*>>=
+--S 4 of 20
+bChebyshev:=[_
+ 0.175755649606129373848762834691E1,_
+-0.435854151773616611705001867964E-01,_
+-0.797950713955842540133217027492E-02,_
+-0.148437232730371213850970210001E-02,_
+-0.280030198437751457486203954948E-03,_
+-0.534864851286579323039177361553E-04,_
+-0.103286724357355486610233266460E-04,_
+-0.201408331300553687732226198639E-05,_
+-0.396175843427386645822338443500E-06,_
+-0.785387276709663163067607656069E-07,_
+-0.156792598100746982624616270279E-07,_
+-0.315005593937639988250007372851E-08,_
+-0.636509682252420373040380263972E-09,_
+-0.129288811328056318356593121259E-09,_
+-0.263869099965925576132149942808E-10,_
+-0.540895828704506873491922207896E-11,_
+-0.111322278460108989997676692708E-11,_
+-0.229962472607446246184338864145E-12,_
+-0.476668238949519026223913482091E-13,_
+-0.991175674733527094506246643371E-14,_
+-0.206710358049570724000900805021E-14,_
+-0.432277678338338505645764394579E-15,_
+-0.906301479966501725514905603356E-16,_
+-0.190466997958166139744015963342E-16,_
+-0.401179232635027866346744227520E-17,_
+-0.846777213001683223134166334685E-18,_
+-0.179084273365869665555826492204E-18,_
+-0.379449063817147824401106175166E-19,_
+-0.805399923679827985260999654058E-20,_
+-0.171233901123620129743228671244E-20,_
+-0.364627405877496862086576562816E-21,_
+-0.777596963889394794353098157647E-22,_
+-0.166062849844840205662531950966E-22,_
+-0.355117862578825093005927145352E-23,_
+-0.760372268594135809295734653294E-24,_
+-0.163007413725849002889638374755E-24,_
+-0.349857520272863223507538497255E-25,_
+-0.751717962789009882460645145143E-26,_
+-0.161687744005272276298777317918E-26,_
+-0.348127008572475691748202271565E-27,_
+-0.750270777550246547010642233720E-28,_
+-0.161845436449591026807612330206E-28,_
+-0.349436677170516166749482836452E-29,_
+-0.755103690612616785856037026797E-30]
+--R 
+--R
+--R   (5)
+--R   [1.7575564960 6129373848 762834691, - 0.0435854151 7736166117 0500186796 4,
+--R    - 0.0079795071 3955842540 1332170274 92,
+--R    - 0.0014843723 2730371213 8509702100 01,
+--R    - 0.0002800301 9843775145 7486203954 948,
+--R    - 0.0000534864 8512865793 2303917736 1553,
+--R    - 0.0000103286 7243573554 8661023326 646,
+--R    - 0.0000020140 8331300553 6877322261 98639,
+--R    - 0.3961758434 2738664582 23384435 E -6,
+--R    - 0.7853872767 0966316306 7607656069 E -7,
+--R    - 0.1567925981 0074698262 4616270279 E -7,
+--R    - 0.3150055939 3763998825 0007372851 E -8,
+--R    - 0.6365096822 5242037304 0380263972 E -9,
+--R    - 0.1292888113 2805631835 6593121259 E -9,
+--R    - 0.2638690999 6592557613 2149942808 E -10,
+--R    - 0.5408958287 0450687349 1922207896 E -11,
+--R    - 0.1113222784 6010898999 7676692708 E -11,
+--R    - 0.2299624726 0744624618 4338864145 E -12,
+--R    - 0.4766682389 4951902622 3913482091 E -13,
+--R    - 0.9911756747 3352709450 6246643371 E -14,
+--R    - 0.2067103580 4957072400 0900805021 E -14,
+--R    - 0.4322776783 3833850564 5764394579 E -15,
+--R    - 0.9063014799 6650172551 4905603356 E -16,
+--R    - 0.1904669979 5816613974 4015963342 E -16,
+--R    - 0.4011792326 3502786634 674422752 E -17,
+--R    - 0.8467772130 0168322313 4166334685 E -18,
+--R    - 0.1790842733 6586966555 5826492204 E -18,
+--R    - 0.3794490638 1714782440 1106175166 E -19,
+--R    - 0.8053999236 7982798526 0999654058 E -20,
+--R    - 0.1712339011 2362012974 3228671244 E -20,
+--R    - 0.3646274058 7749686208 6576562816 E -21,
+--R    - 0.7775969638 8939479435 3098157647 E -22,
+--R    - 0.1660628498 4484020566 2531950966 E -22,
+--R    - 0.3551178625 7882509300 5927145352 E -23,
+--R    - 0.7603722685 9413580929 5734653294 E -24,
+--R    - 0.1630074137 2584900288 9638374755 E -24,
+--R    - 0.3498575202 7286322350 7538497255 E -25,
+--R    - 0.7517179627 8900988246 0645145143 E -26,
+--R    - 0.1616877440 0527227629 8777317918 E -26,
+--R    - 0.3481270085 7247569174 8202271565 E -27,
+--R    - 0.7502707775 5024654701 064223372 E -28,
+--R    - 0.1618454364 4959102680 7612330206 E -28,
+--R    - 0.3494366771 7051616674 9482836452 E -29,
+--R    - 0.7551036906 1261678585 6037026797 E -30]
+--R                                                             Type: List Float
+--E 4
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 5 of 20
+[[-10.000,0.915633339397880818760698157661,_
+  Ei2(-10.000),Ei2(-10.000)-0.915633339397880818760698157661],_
+[ -9.625,0.912844461467993418856575662217,_
+  Ei2( -9.625),Ei2( -9.625)-0.912844461467993418856575662217],_
+[ -9.250,0.909862751525424139378954274597,_
+  Ei2( -9.250),Ei2( -9.250)-0.909862751525424139378954274597],_
+[ -8.875,0.906667270654753880334995756418,_
+  Ei2( -8.875),Ei2( -8.875)-0.906667270654753880334995756418],_
+[ -8.500,0.903233901973207844144682926135,_
+  Ei2( -8.500),Ei2( -8.500)-0.903233901973207844144682926135],_
+[ -8.125,0.899534717688473836301415777697,_
+  Ei2( -8.125),Ei2( -8.125)-0.899534717688473836301415777697],_
+[ -7.750,0.895537187087539157179475513219,_
+  Ei2( -7.750),Ei2( -7.750)-0.895537187087539157179475513219],_
+[ -7.375,0.891203176321254316267087476258,_
+  Ei2( -7.375),Ei2( -7.375)-0.891203176321254316267087476258],_
+[ -7.000,0.886487672536429352893993846569,_
+  Ei2( -7.000),Ei2( -7.000)-0.886487672536429352893993846569],_
+[ -6.625,0.881337138468210200394305706270,_
+  Ei2( -6.625),Ei2( -6.625)-0.881337138468210200394305706270],_
+[ -6.250,0.875687364788465932276462155532,_
+  Ei2( -6.250),Ei2( -6.250)-0.875687364788465932276462155532],_
+[ -5.875,0.869460629454113410302047153364,_
+  Ei2( -5.875),Ei2( -5.875)-0.869460629454113410302047153364],_
+[ -5.500,0.862561884690701422090918986586,_
+  Ei2( -5.500),Ei2( -5.500)-0.862561884690701422090918986586],_
+[ -5.125,0.854873553890199542392425567234,_
+  Ei2( -5.125),Ei2( -5.125)-0.854873553890199542392425567234],_
+[ -4.750,0.846248299103587361171665798810,_
+  Ei2( -4.750),Ei2( -4.750)-0.846248299103587361171665798810],_
+[ -4.375,0.836498754556298741742152267582,_
+  Ei2( -4.375),Ei2( -4.375)-0.836498754556298741742152267582],_
+[ -4.000,0.825382599604223332408183035504,_
+  Ei2( -4.000),Ei2( -4.000)-0.825382599604223332408183035504]]
+--R 
+--R
+--R   (6)
+--R   [[- 10.,0.91563333939788083,0.91563333939788083,0.],
+--R    [- 9.625,0.91284446146799347,0.91284446146799336,- 1.1102230246251565E-16],
+--R    [- 9.25,0.90986275152542417,0.90986275152542395,- 2.2204460492503131E-16],
+--R    [- 8.875,0.90666727065475383,0.90666727065475394,1.1102230246251565E-16],
+--R    [- 8.5,0.90323390197320785,0.90323390197320796,1.1102230246251565E-16],
+--R    [- 8.125,0.89953471768847382,0.89953471768847415,3.3306690738754696E-16],
+--R    [- 7.75,0.89553718708753915,0.89553718708753927,1.1102230246251565E-16],
+--R    [- 7.375,0.89120317632125434,0.89120317632125423,- 1.1102230246251565E-16],
+--R    [- 7.,0.88648767253642935,0.88648767253642924,- 1.1102230246251565E-16],
+--R    [- 6.625,0.88133713846821016,0.88133713846821005,- 1.1102230246251565E-16],
+--R    [- 6.25,0.87568736478846598,0.87568736478846598,0.],
+--R    [- 5.875,0.8694606294541134,0.86946062945411307,- 3.3306690738754696E-16],
+--R    [- 5.5,0.86256188469070139,0.86256188469070139,0.],
+--R    [- 5.125,0.85487355389019959,0.85487355389019937,- 2.2204460492503131E-16],
+--R    [- 4.75,0.84624829910358734,0.84624829910358745,1.1102230246251565E-16],
+--R    [- 4.375,0.83649875455629874,0.83649875455629874,0.],
+--R    [- 4.,0.82538259960422333,0.82538259960422322,- 1.1102230246251565E-16]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 5
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(-4 \le x \le 4)$ in the polynomial
+$$\sum_{k=0}^{33}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=x/4$
+
+<<*>>=
+--S 6 of 20
+cChebyshev:=[_
+0.329370010376739129393905231421E1,_
+0.167983505237130291565505796064E1,_
+0.722043610567875435240299679644E0,_
+0.260031236054809561713740181192E0,_
+0.801049430817375022394742889237E-01,_
+0.215140366397633375480552483005E-01,_
+0.511620778993033120621968910894E-02,_
+0.109093286100739135605066199014E-02,_
+0.210741532023938916318348675226E-03,_
+0.371990451665188857095940815956E-04,_
+0.604349163712387875704767032866E-05,_
+0.909295427396260952649596541772E-06,_
+0.127380516065926478865567184969E-06,_
+0.166918574841098907390896143814E-07,_
+0.205441702640104792547612484551E-08,_
+0.238358444446681765914052321417E-09,_
+0.261538637888544296669068664148E-10,_
+0.272185862285416706446550268995E-11,_
+0.269375003198357929925326427442E-12,_
+0.254122094670726355467884089307E-13,_
+0.229013040686503709418510620516E-14,_
+0.197546573907462299401057650412E-15,_
+0.163402455192893174068635419984E-16,_
+0.129823543707963760991961293204E-17,_
+0.992258792507371059644632581302E-19,_
+0.730625280672210329447230880087E-20,_
+0.518967683460434512720780080019E-21,_
+0.356040945409970681128043162227E-22,_
+0.236197943257938642370187203948E-23,_
+0.151683776772145297549624516819E-24,_
+0.943908972224487442925310405245E-26,_
+0.569722755950369211989581737831E-27,_
+0.333833362779543303156597939562E-28,_
+0.190062601281619148526680482237E-29]
+--R 
+--R
+--R   (7)
+--R   [3.2937001037 6739129393 905231421, 1.6798350523 7130291565 505796064,
+--R    0.7220436105 6787543524 0299679644, 0.2600312360 5480956171 3740181192,
+--R    0.0801049430 8173750223 9474288923 7, 0.0215140366 3976333754 8055248300 5,
+--R    0.0051162077 8993033120 6219689108 94,
+--R    0.0010909328 6100739135 6050661990 14,
+--R    0.0002107415 3202393891 6318348675 226,
+--R    0.0000371990 4516651888 5709594081 5956,
+--R    0.0000060434 9163712387 8757047670 32866,
+--R    0.9092954273 9626095264 9596541772 E -6,
+--R    0.1273805160 6592647886 5567184969 E -6,
+--R    0.1669185748 4109890739 0896143814 E -7,
+--R    0.2054417026 4010479254 7612484551 E -8,
+--R    0.2383584444 4668176591 4052321417 E -9,
+--R    0.2615386378 8854429666 9068664148 E -10,
+--R    0.2721858622 8541670644 6550268995 E -11,
+--R    0.2693750031 9835792992 5326427442 E -12,
+--R    0.2541220946 7072635546 7884089307 E -13,
+--R    0.2290130406 8650370941 8510620516 E -14,
+--R    0.1975465739 0746229940 1057650412 E -15,
+--R    0.1634024551 9289317406 8635419984 E -16,
+--R    0.1298235437 0796376099 1961293204 E -17,
+--R    0.9922587925 0737105964 4632581302 E -19,
+--R    0.7306252806 7221032944 7230880087 E -20,
+--R    0.5189676834 6043451272 0780080019 E -21,
+--R    0.3560409454 0997068112 8043162227 E -22,
+--R    0.2361979432 5793864237 0187203948 E -23,
+--R    0.1516837767 7214529754 9624516819 E -24,
+--R    0.9439089722 2448744292 5310405245 E -26,
+--R    0.5697227559 5036921198 9581737831 E -27,
+--R    0.3338333627 7954330315 6597939562 E -28,
+--R    0.1900626012 8161914852 6680482237 E -29]
+--R                                                             Type: List Float
+--E 6
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 7 of 20
+[[-4.0,0.491822344607818096479962798267,_
+  Ei3(-4.0),Ei3(-4.0)-0.491822344607818096479962798267],_
+[-3.5,0.524842506644128356918258753311,_
+  Ei3(-3.5),Ei3(-3.5)-0.524842506644128356918258753311],_
+[-3.0,0.562958778221279863138086024270,_
+  Ei3(-3.0),Ei3(-3.0)-0.562958778221279863138086024270],_
+[-2.5,0.607368525858383064514266925640,_
+  Ei3(-2.5),Ei3(-2.5)-0.607368525858383064514266925640],_
+[-2.0,0.659631678084769644795492023380,_
+  Ei3(-2.0),Ei3(-2.0)-0.659631678084769644795492023380],_
+[-1.5,0.721800236944219929657623030310,_
+  Ei3(-1.5),Ei3(-1.5)-0.721800236944219929657623030310],_
+[-1.0,0.796599599297053134283675865540,_
+  Ei3(-1.0),Ei3(-1.0)-0.796599599297053134283675865540],_
+[-0.5,0.887684158235496725872151815870,_
+  Ei3(-0.5),Ei3(-0.5)-0.887684158235496725872151815870],_
+[0.0,1.00000000000000000000000000000,_
+  Ei3(0.0),Ei3(0.0)-1.00000000000000000000000000000],_
+[0.5,1.14030284104317205746248768807,_
+  Ei3(0.5),Ei3(0.5)-1.14030284104317205746248768807],_
+[1.0,1.31790215145440389486000884424,_
+  Ei3(1.0),Ei3(1.0)-1.31790215145440389486000884424],_
+[1.5,1.54573645074673373024859074039,_
+  Ei3(1.5),Ei3(1.5)-1.54573645074673373024859074039],_
+[2.0,1.84193575527020599667788045934,_
+  Ei3(2.0),Ei3(2.0)-1.84193575527020599667788045934],_
+[2.5,2.23210379912116511445340506423,_
+  Ei3(2.5),Ei3(2.5)-2.23210379912116511445340506423],_
+[3.0,2.75266820568525800200219289740,_
+  Ei3(3.0),Ei3(3.0)-2.75266820568525800200219289740],_
+[3.5,3.45582153193012412437300898811,_
+  Ei3(3.5),Ei3(3.5)-3.45582153193012412437300898811],_
+[4.0,4.41684111100869913580118598668,_
+  Ei3(4.0),Ei3(4.0)-4.41684111100869913580118598668]]
+--R 
+--R
+--R   (8)
+--R   [[- 4.,0.4918223446078181,0.49182234460781826,1.6653345369377348E-16],
+--R    [- 3.5,0.52484250664412835,0.52484250664412835,0.],
+--R    [- 3.,0.56295877822127982,0.56295877822128015,3.3306690738754696E-16],
+--R    [- 2.5,0.60736852585838308,0.60736852585838341,3.3306690738754696E-16],
+--R    [- 2.,0.65963167808476963,0.65963167808476975,1.1102230246251565E-16],
+--R    [- 1.5,0.72180023694421991,0.72180023694422013,2.2204460492503131E-16],
+--R    [- 1.,0.79659959929705315,0.79659959929705293,- 2.2204460492503131E-16],
+--R    [- 0.5,0.88768415823549673,0.88768415823549696,2.2204460492503131E-16],
+--R    [0.,1.,1.,0.],
+--R    [0.5,1.1403028410431721,1.1403028410431715,- 6.6613381477509392E-16],
+--R    [1.,1.3179021514544038,1.3179021514544034,- 4.4408920985006262E-16],
+--R    [1.5,1.5457364507467337,1.5457364507467335,- 2.2204460492503131E-16],
+--R    [2.,1.841935755270206,1.8419357552702071,1.1102230246251565E-15],
+--R    [2.5,2.2321037991211652,2.2321037991211647,- 4.4408920985006262E-16],
+--R    [3.,2.7526682056852581,2.7526682056852589,8.8817841970012523E-16],
+--R    [3.5,3.4558215319301242,3.4558215319301238,- 4.4408920985006262E-16],
+--R    [4.,4.4168411110086989,4.4168411110087007,1.7763568394002505E-15]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 7
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(4 \le x \le 12)$ in the polynomial
+$$\sum_{k=0}^{49}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=(x-8)/4$
+
+<<*>>=
+--S 8 of 20
+dChebyshev:=[_
+ 0.245513353878129528673420457043E1,_
+-0.162438379130376524396002276856E0,_
+ 0.449575308093572641480785417193E-01,_
+-0.674157867998922998848718835050E-02,_
+-0.130669714280329428051599341387E-02,_
+ 0.138108314600072576020202089820E-02,_
+-0.585022879015965798687368242394E-03,_
+ 0.174929934107891970038740976432E-03,_
+-0.404728149905293035522869333800E-04,_
+ 0.721710241217099750035752600049E-05,_
+-0.861277697019867752414815450193E-06,_
+-0.251447529653225597779084739054E-09,_ -- E-06? or wrong place?
+ 0.379474713820149510814074505574E-07,_
+-0.144211796952119806160265640172E-07,_
+ 0.393504929597610131087190848042E-08,_
+-0.928468940106331753047289210353E-09,_
+ 0.203178956800654613366090995698E-09,_
+-0.429249850499236831427918026902E-10,_
+ 0.899264717778123935268001544182E-11,_
+-0.190086911841210975242396635722E-11,_
+ 0.409219891222373834526121178338E-12,_
+-0.899925343729319019825435824585E-13,_
+ 0.201965467082426383354948543451E-13,_
+-0.461293026138308207194950531726E-14,_
+ 0.106902307293863695668857256409E-14,_
+-0.250703007057007295692572254042E-15,_
+ 0.593732250379155160706073763509E-16,_
+-0.141773458243766252344732005648E-16,_
+ 0.340920375436080893426806402093E-17,_
+-0.824829026950549379288702529656E-18,_
+ 0.200636971262144231398824095937E-18,_
+-0.490385166796742224403498152027E-19,_
+ 0.120373448234833217166664609324E-19,_
+-0.296628244714136825381453572575E-20,_
+ 0.733551238428807599242142328436E-21,_
+-0.181992414290851127344263485604E-21,_
+ 0.452862937429576060217359526404E-22,_
+-0.112998004375060961338906717853E-22,_
+ 0.282668125129011656923764408445E-23,_
+-0.708771797716904961666732640699E-24,_
+ 0.178110452401870951534401530034E-24,_
+-0.448500407661896357312006142358E-25,_
+ 0.113154029257547662245053090840E-25,_
+-0.285995789977932163790414326136E-26,_
+ 0.724077580692267361758172726753E-27,_
+-0.183613223412577898050666710105E-27,_
+ 0.466312873522730486582600122073E-28,_
+-0.118595958891902887946724005478E-28,_
+ 0.302029059055671310731137614875E-29,_
+-0.770165054816636606098827057102E-30]
+--R 
+--R
+--R   (9)
+--R   [2.4551335387 8129528673 420457043, - 0.1624383791 3037652439 6002276856,
+--R    0.0449575308 0935726414 8078541719 3,
+--R    - 0.0067415786 7998922998 8487188350 5,
+--R    - 0.0013066971 4280329428 0515993413 87,
+--R    0.0013810831 4600072576 0202020898 2,
+--R    - 0.0005850228 7901596579 8687368242 394,
+--R    0.0001749299 3410789197 0038740976 432,
+--R    - 0.0000404728 1499052930 3552286933 38,
+--R    0.0000072171 0241217099 7500357526 00049,
+--R    - 0.8612776970 1986775241 4815450193 E -6,
+--R    - 0.2514475296 5322559777 9084739054 E -9,
+--R    0.3794747138 2014951081 4074505574 E -7,
+--R    - 0.1442117969 5211980616 0265640172 E -7,
+--R    0.3935049295 9761013108 7190848042 E -8,
+--R    - 0.9284689401 0633175304 7289210353 E -9,
+--R    0.2031789568 0065461336 6090995698 E -9,
+--R    - 0.4292498504 9923683142 7918026902 E -10,
+--R    0.8992647177 7812393526 8001544182 E -11,
+--R    - 0.1900869118 4121097524 2396635722 E -11,
+--R    0.4092198912 2237383452 6121178338 E -12,
+--R    - 0.8999253437 2931901982 5435824585 E -13,
+--R    0.2019654670 8242638335 4948543451 E -13,
+--R    - 0.4612930261 3830820719 4950531726 E -14,
+--R    0.1069023072 9386369566 8857256409 E -14,
+--R    - 0.2507030070 5700729569 2572254042 E -15,
+--R    0.5937322503 7915516070 6073763509 E -16,
+--R    - 0.1417734582 4376625234 4732005648 E -16,
+--R    0.3409203754 3608089342 6806402093 E -17,
+--R    - 0.8248290269 5054937928 8702529656 E -18,
+--R    0.2006369712 6214423139 8824095937 E -18,
+--R    - 0.4903851667 9674222440 3498152027 E -19,
+--R    0.1203734482 3483321716 6664609324 E -19,
+--R    - 0.2966282447 1413682538 1453572575 E -20,
+--R    0.7335512384 2880759924 2142328436 E -21,
+--R    - 0.1819924142 9085112734 4263485604 E -21,
+--R    0.4528629374 2957606021 7359526404 E -22,
+--R    - 0.1129980043 7506096133 8906717853 E -22,
+--R    0.2826681251 2901165692 3764408445 E -23,
+--R    - 0.7087717977 1690496166 6732640699 E -24,
+--R    0.1781104524 0187095153 4401530034 E -24,
+--R    - 0.4485004076 6189635731 2006142358 E -25,
+--R    0.1131540292 5754766224 505309084 E -25,
+--R    - 0.2859957899 7793216379 0414326136 E -26,
+--R    0.7240775806 9226736175 8172726753 E -27,
+--R    - 0.1836132234 1257789805 0666710105 E -27,
+--R    0.4663128735 2273048658 2600122073 E -28,
+--R    - 0.1185959588 9190288794 6724005478 E -28,
+--R    0.3020290590 5567131073 1137614875 E -29,
+--R    - 0.7701650548 1663660609 8827057102 E -30]
+--R                                                             Type: List Float
+--E 8
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 9 of 20
+[[4.0,1.43820803145448278470968670330,_
+  Ei4(4.0),Ei4(4.0)-1.43820803145448278470968670330],_
+[4.5,1.39641902962974607100674523183,_
+  Ei4(4.5), Ei4(4.5)-1.39641902962974607100674523183],_
+[5.0,1.35383127745528597790189174047,_
+  Ei4(5.0),Ei4(5.0)-1.35383127745528597790189174047],_
+[5.5,1.31414356574211924541219816991,_
+  Ei4(5.5),Ei4(5.5)-1.31414356574211924541219816991],_
+[6.0,1.27888386048956161892314099578,_
+  Ei4(6.0),Ei4(6.0)-1.27888386048956161892314099578],_
+[6.5,1.24839115500170148640741941387,_
+  Ei4(6.5),Ei4(6.5)-1.24839115500170148640741941387],_
+[7.0,1.22240805236053105903656846622,_
+  Ei4(7.0),Ei4(7.0)-1.22240805236053105903656846622],_
+[7.5,1.20042149959963078643879158950,_
+  Ei4(7.5),Ei4(7.5)-1.20042149959963078643879158950],_
+[8.0,1.18184798698720797317739362644,_
+  Ei4(8.0),Ei4(8.0)-1.18184798698720797317739362644],_
+[8.5,1.16612652581174849439918142965,_
+  Ei4(8.5),Ei4(8.5)-1.16612652581174849439918142965],_
+[9.0,1.15275920870892481322396814952,_
+  Ei4(9.0),Ei4(9.0)-1.15275920870892481322396814952],_
+[9.5,1.14132347595262420155338560641,_
+  Ei4(9.5),Ei4(9.5)-1.14132347595262420155338560641],_
+[10.0,1.13147020473410778034051681355,_
+  Ei4(10.0),Ei4(10.0)-1.13147020473410778034051681355],_
+[10.5,1.12291557001776060642888630755,_
+  Ei4(10.5),Ei4(10.5)-1.12291557001776060642888630755],_
+[11.0,1.11543093899803844164779434229,_
+  Ei4(11.0),Ei4(11.0)-1.11543093899803844164779434229],_
+[11.5,1.10883292630507730586855234934,_
+  Ei4(11.5),Ei4(11.5)-1.10883292630507730586855234934],_
+[12.0,1.10297454490675907267241234953,_
+  Ei4(12.0),Ei4(12.0)-1.10297454490675907267241234953]]
+--R 
+--R
+--R   (10)
+--R   [[4.,1.4382080314544827,1.4382080314544827,0.],
+--R    [4.5,1.3964190296297461,1.3964190296297465,4.4408920985006262E-16],
+--R    [5.,1.3538312774552861,1.3538312774552856,- 4.4408920985006262E-16],
+--R    [5.5,1.3141435657421192,1.314143565742119,- 2.2204460492503131E-16],
+--R    [6.,1.2788838604895616,1.2788838604895618,2.2204460492503131E-16],
+--R    [6.5,1.2483911550017015,1.2483911550017011,- 4.4408920985006262E-16],
+--R    [7.,1.222408052360531,1.222408052360531,0.],
+--R    [7.5,1.2004214995996307,1.2004214995996305,- 2.2204460492503131E-16],
+--R    [8.,1.1818479869872081,1.1818479869872081,0.],
+--R    [8.5,1.1661265258117486,1.1661265258117477,- 8.8817841970012523E-16],
+--R    [9.,1.1527592087089249,1.1527592087089251,2.2204460492503131E-16],
+--R    [9.5,1.1413234759526243,1.1413234759526236,- 6.6613381477509392E-16],
+--R    [10.,1.1314702047341079,1.1314702047341079,0.],
+--R    [10.5,1.1229155700177607,1.1229155700177604,- 2.2204460492503131E-16],
+--R    [11.,1.1154309389980384,1.115430938998039,6.6613381477509392E-16],
+--R    [11.5,1.1088329263050773,1.1088329263050771,- 2.2204460492503131E-16],
+--R    [12.,1.1029745449067592,1.1029745449067592,0.]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 9
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(12 \le x \le 32)$ in the polynomial
+$$\sum_{k=0}^{47}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=(x-22)/10$
+
+<<*>>=
+--S 10 of 20
+eChebyshev:=[_
+ 0.211702864043698668329789991614E1,_
+-0.320423727375485794990618303177E-01,_
+ 0.889173207735316835890182400335E-02,_
+-0.250795280518929937088352442063E-02,_
+ 0.720278946595987548875760902487E-03,_
+-0.210349005850113053423531441256E-03,_
+ 0.620573231827693216588857730842E-04,_
+-0.182656674981670265449155689733E-04,_
+ 0.527065157528936375807788296811E-05,_ --? 7560 or 7580?
+-0.145966654761994575323066719367E-05,_
+ 0.378171997358963671980484193981E-06,_
+-0.884258128284071920077971589012E-07,_
+ 0.174174919853839361377350309156E-07,_
+-0.231351774704369063506474480152E-08,_
+-0.122860981918086238832104835230E-09,_
+ 0.234996623632286370478311381926E-09,_
+-0.110071940102726287690738963049E-09,_
+ 0.384827515786120711149705563369E-10,_
+-0.114844096749001589658439301603E-10,_
+ 0.305687629308852082630893626200E-11,_
+-0.738827872928473566454163131431E-12,_
+ 0.163093309416594110564148013749E-12,_
+-0.327698937331271249657111774748E-13,_
+ 0.589811434707131961711164283918E-14,_
+-0.909970763595649204643554720718E-15,_
+ 0.104075238266955386585405697541E-15,_
+-0.180981542605922793227163355935E-17,_
+-0.377709884256394773369593494417E-17,_
+ 0.158033290102847957136759888420E-17,_
+-0.468429175880882730648433752957E-18,_
+ 0.119951685259198093707533478542E-18,_
+-0.282359474984186517679349931117E-19,_
+ 0.629373806564463522627520190349E-20,_
+-0.135241024950479756305343973177E-20,_
+ 0.283710605385529141590980426210E-21,_
+-0.586700742024638323531936371015E-22,_
+ 0.120524763609547311112449686917E-22,_
+-0.247444661699884869728416011246E-23,_
+ 0.509996258583785008142986465688E-24,_
+-0.105838257877542240887093294733E-24,_
+ 0.221527624507048278566429387155E-25,_
+-0.467927875475696258671852546231E-26,_
+ 0.997287299060207704824269828079E-27,_
+-0.214326794521678804591907805844E-27,_
+ 0.464065690883818114338414829515E-28,_
+-0.101144734921151390948461800780E-28,_
+ 0.221721152271007711093046878345E-29,_
+-0.488489046924378553224914645512E-30]
+--R 
+--R
+--R   (11)
+--R   [2.1170286404 3698668329 789991614, - 0.0320423727 3754857949 9061830317 7,
+--R    0.0088917320 7735316835 8901824003 35,
+--R    - 0.0025079528 0518929937 0883524420 63,
+--R    0.0007202789 4659598754 8875760902 487,
+--R    - 0.0002103490 0585011305 3423531441 256,
+--R    0.0000620573 2318276932 1658885773 0842,
+--R    - 0.0000182656 6749816702 6544915568 9733,
+--R    0.0000052706 5157528936 3758077882 96811,
+--R    - 0.0000014596 6654761994 5753230667 19367,
+--R    0.3781719973 5896367198 0484193981 E -6,
+--R    - 0.8842581282 8407192007 7971589012 E -7,
+--R    0.1741749198 5383936137 7350309156 E -7,
+--R    - 0.2313517747 0436906350 6474480152 E -8,
+--R    - 0.1228609819 1808623883 210483523 E -9,
+--R    0.2349966236 3228637047 8311381926 E -9,
+--R    - 0.1100719401 0272628769 0738963049 E -9,
+--R    0.3848275157 8612071114 9705563369 E -10,
+--R    - 0.1148440967 4900158965 8439301603 E -10,
+--R    0.3056876293 0885208263 08936262 E -11,
+--R    - 0.7388278729 2847356645 4163131431 E -12,
+--R    0.1630933094 1659411056 4148013749 E -12,
+--R    - 0.3276989373 3127124965 7111774748 E -13,
+--R    0.5898114347 0713196171 1164283918 E -14,
+--R    - 0.9099707635 9564920464 3554720718 E -15,
+--R    0.1040752382 6695538658 5405697541 E -15,
+--R    - 0.1809815426 0592279322 7163355935 E -17,
+--R    - 0.3777098842 5639477336 9593494417 E -17,
+--R    0.1580332901 0284795713 675988842 E -17,
+--R    - 0.4684291758 8088273064 8433752957 E -18,
+--R    0.1199516852 5919809370 7533478542 E -18,
+--R    - 0.2823594749 8418651767 9349931117 E -19,
+--R    0.6293738065 6446352262 7520190349 E -20,
+--R    - 0.1352410249 5047975630 5343973177 E -20,
+--R    0.2837106053 8552914159 098042621 E -21,
+--R    - 0.5867007420 2463832353 1936371015 E -22,
+--R    0.1205247636 0954731111 2449686917 E -22,
+--R    - 0.2474446616 9988486972 8416011246 E -23,
+--R    0.5099962585 8378500814 2986465688 E -24,
+--R    - 0.1058382578 7754224088 7093294733 E -24,
+--R    0.2215276245 0704827856 6429387155 E -25,
+--R    - 0.4679278754 7569625867 1852546231 E -26,
+--R    0.9972872990 6020770482 4269828079 E -27,
+--R    - 0.2143267945 2167880459 1907805844 E -27,
+--R    0.4640656908 8381811433 8414829515 E -28,
+--R    - 0.1011447349 2115139094 846180078 E -28,
+--R    0.2217211522 7100771109 3046878345 E -29,
+--R    - 0.4884890469 2437855322 4914645512 E -30]
+--R                                                             Type: List Float
+--E 10
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 11 of 20
+[[12.00,1.10297454490675907267241234952,_
+  Ei5(12.00),Ei5(12.00)-1.10297454490675907267241234952],_
+[13.25,1.09084489821547569266468614954,_
+  Ei5(13.25),Ei5(13.25)-1.09084489821547569266468614954],_
+[14.50,1.08135139573519128506346643795,_
+  Ei5(14.50),Ei5(14.50)-1.08135139573519128506346643795],_
+[15.75,1.07370138419975723712157900374,_
+  Ei5(15.75),Ei5(15.75)-1.07370138419975723712157900374],_
+[17.00,1.06739369195853783129572196197,_
+  Ei5(17.00),Ei5(17.00)-1.06739369195853783129572196197],_
+[18.25,1.06209660862215024268372647556,_
+  Ei5(18.25),Ei5(18.25)-1.06209660862215024268372647556],_
+[19.50,1.05758134215872503195393949410,_
+  Ei5(19.50),Ei5(19.50)-1.05758134215872503195393949410],_
+[20.75,1.05368445128940944082102194964,_
+  Ei5(20.75),Ei5(20.75)-1.05368445128940944082102194964],_
+[22.00,1.05028571968518979411780664532,_
+  Ei5(22.00),Ei5(22.00)-1.05028571968518979411780664532],_
+[23.25,1.04729455170532485811492365591,_
+  Ei5(23.25),Ei5(23.25)-1.04729455170532485811492365591],_
+[24.50,1.04464126790464363689761075289,_
+  Ei5(24.50),Ei5(24.50)-1.04464126790464363689761075289],_
+[25.75,1.04227133720232023885710928048,_
+  Ei5(25.75),Ei5(25.75)-1.04227133720232023885710928048],_
+[27.00,1.04014143832301043813713899754,_
+  Ei5(27.00),Ei5(27.00)-1.04014143832301043813713899754],_
+[28.25,1.03821670036014587680056548394,_
+  Ei5(28.25),Ei5(28.25)-1.03821670036014587680056548394],_
+[29.50,1.03646872629241184575154685419,_
+  Ei5(29.50),Ei5(29.50)-1.03646872629241184575154685419],_
+[30.75,1.03487414989647969472990938990,_
+  Ei5(30.75),Ei5(30.75)-1.03487414989647969472990938990],_
+[32.00,1.03341356421624104943493552567,_
+  Ei5(32.00),Ei5(32.00)-1.03341356421624104943493552567]]
+--R 
+--R
+--R   (12)
+--R   [[12.,1.1029745449067592,1.1029745449067585,- 6.6613381477509392E-16],
+--R    [13.25,1.0908448982154757,1.090844898215475,- 6.6613381477509392E-16],
+--R    [14.5,1.0813513957351912,1.0813513957351915,2.2204460492503131E-16],
+--R    [15.75,1.0737013841997571,1.0737013841997574,2.2204460492503131E-16],
+--R    [17.,1.0673936919585378,1.0673936919585385,6.6613381477509392E-16],
+--R    [18.25,1.0620966086221502,1.0620966086221502,0.],
+--R    [19.5,1.057581342158725,1.0575813421587252,2.2204460492503131E-16],
+--R    [20.75,1.0536844512894095,1.0536844512894095,0.],
+--R    [22.,1.0502857196851898,1.0502857196851898,0.],
+--R    [23.25,1.0472945517053249,1.0472945517053245,- 4.4408920985006262E-16],
+--R    [24.5,1.0446412679046437,1.0446412679046437,0.],
+--R    [25.75,1.0422713372023202,1.04227133720232,- 2.2204460492503131E-16],
+--R    [27.,1.0401414383230105,1.0401414383230101,- 4.4408920985006262E-16],
+--R    [28.25,1.0382167003601459,1.0382167003601459,0.],
+--R    [29.5,1.0364687262924119,1.0364687262924113,- 6.6613381477509392E-16],
+--R    [30.75,1.0348741498964797,1.0348741498964795,- 2.2204460492503131E-16],
+--R    [32.,1.033413564216241,1.0334135642162412,2.2204460492503131E-16]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 11
+
+@
+These are the Chebyshev coefficients used by Axiom in the range
+$(32 \le x < \infty)$ in the polynomial
+$$\sum_{k=0}^{46}\ ^{'}{A_kT_k(t)}$$
+with the scaling factor $t=(64/X)-1$
+
+<<*>>=
+
+--S 12 of 20
+fChebyshev:=[_
+ 0.203284394579616699087873844202E1,_
+ 0.166992045203136285147618434339E-01,_
+ 0.284528472436134680742489985325E-03,_
+ 0.756394435851620648948786693854E-05,_
+ 0.279897128945085915750484318090E-06,_
+ 0.135790182853453106952556392593E-07,_
+ 0.834359620204046925585610289412E-09,_
+ 0.637097172764024843827524337306E-10,_
+ 0.600724760881186123576083084850E-11,_
+ 0.702287617467977359075059216588E-12,_
+ 0.101830267370368769309667322152E-12,_
+ 0.176181290343088004040656741554E-13,_
+ 0.325082861423536069424072007647E-14,_
+ 0.507177002550581867881479300685E-15,_
+ 0.166517738704329429853520036957E-16,_
+-0.316675389079751440072410018963E-16,_
+-0.158840376366414151548423134074E-16,_
+-0.417551325613801883089626455063E-17,_
+-0.289234774970714188202868862358E-18,_
+ 0.280062590339660807289978777339E-18,_
+ 0.132293863953927089140532005364E-18,_
+ 0.180444744417730199585334811191E-19,_
+-0.790538408652261656202021080364E-20,_
+-0.443571136636957344718167314045E-20,_
+-0.426410399497810261760579779746E-21,_
+ 0.392010176693714390725625388636E-21,_
+ 0.152737805134396364472804486402E-21,_
+-0.102484952704949060786953149788E-22,_
+-0.213490787477108937948904287231E-22,_
+-0.323913947516023687614279789345E-23,_
+ 0.214218376229645970296249355934E-23,_
+ 0.823460941961899553169207838151E-24,_
+-0.152465282962067210811495038147E-24,_
+-0.137820828248824401290438126477E-24,_
+ 0.213131120142873706791513005998E-26,_
+ 0.201264965187132665859213006507E-25,_
+ 0.199553566205637402320607178286E-26,_
+-0.279899581220179711426020884464E-26,_
+-0.553451183050700250949784942560E-27,_
+ 0.388499542268455253129749000696E-27,_
+ 0.112130440723307012540043264712E-27,_
+-0.556656828674459488057823816866E-28,_
+-0.204548261246513576288865878722E-28,_
+ 0.845381406448938089437361193598E-29,_
+ 0.356575515120151526590791715785E-29,_
+-0.138365242347797751810195772006E-29,_
+-0.606214265320934505767865286306E-30]
+--R 
+--R
+--R   (13)
+--R   [2.0328439457 9616699087 873844202, 0.0166992045 2031362851 4761843433 9,
+--R    0.0002845284 7243613468 0742489985 325,
+--R    0.0000075639 4435851620 6489487866 93854,
+--R    0.2798971289 4508591575 048431809 E -6,
+--R    0.1357901828 5345310695 2556392593 E -7,
+--R    0.8343596202 0404692558 5610289412 E -9,
+--R    0.6370971727 6402484382 7524337306 E -10,
+--R    0.6007247608 8118612357 608308485 E -11,
+--R    0.7022876174 6797735907 5059216588 E -12,
+--R    0.1018302673 7036876930 9667322152 E -12,
+--R    0.1761812903 4308800404 0656741554 E -13,
+--R    0.3250828614 2353606942 4072007647 E -14,
+--R    0.5071770025 5058186788 1479300685 E -15,
+--R    0.1665177387 0432942985 3520036957 E -16,
+--R    - 0.3166753890 7975144007 2410018963 E -16,
+--R    - 0.1588403763 6641415154 8423134074 E -16,
+--R    - 0.4175513256 1380188308 9626455063 E -17,
+--R    - 0.2892347749 7071418820 2868862358 E -18,
+--R    0.2800625903 3966080728 9978777339 E -18,
+--R    0.1322938639 5392708914 0532005364 E -18,
+--R    0.1804447444 1773019958 5334811191 E -19,
+--R    - 0.7905384086 5226165620 2021080364 E -20,
+--R    - 0.4435711366 3695734471 8167314045 E -20,
+--R    - 0.4264103994 9781026176 0579779746 E -21,
+--R    0.3920101766 9371439072 5625388636 E -21,
+--R    0.1527378051 3439636447 2804486402 E -21,
+--R    - 0.1024849527 0494906078 6953149788 E -22,
+--R    - 0.2134907874 7710893794 8904287231 E -22,
+--R    - 0.3239139475 1602368761 4279789345 E -23,
+--R    0.2142183762 2964597029 6249355934 E -23,
+--R    0.8234609419 6189955316 9207838151 E -24,
+--R    - 0.1524652829 6206721081 1495038147 E -24,
+--R    - 0.1378208282 4882440129 0438126477 E -24,
+--R    0.2131311201 4287370679 1513005998 E -26,
+--R    0.2012649651 8713266585 9213006507 E -25,
+--R    0.1995535662 0563740232 0607178286 E -26,
+--R    - 0.2798995812 2017971142 6020884464 E -26,
+--R    - 0.5534511830 5070025094 978494256 E -27,
+--R    0.3884995422 6845525312 9749000696 E -27,
+--R    0.1121304407 2330701254 0043264712 E -27,
+--R    - 0.5566568286 7445948805 7823816866 E -28,
+--R    - 0.2045482612 4651357628 8865878722 E -28,
+--R    0.8453814064 4893808943 7361193598 E -29,
+--R    0.3565755151 2015152659 0791715785 E -29,
+--R    - 0.1383652423 4779775181 0195772006 E -29,
+--R    - 0.6062142653 2093450576 7865286306 E -30]
+--R                                                             Type: List Float
+--E 12
+
+@
+In the following table there are 4 columns. The first column
+is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
+column is the exact value shown in the table. Column 3 is the
+value returned by Axiom and column 4 is the difference.
+See special.spad.dvi for details.
+
+<<*>>=
+--S 13 of 20
+[[32,1.03341356421624104943493552567,_
+  Ei6(32.0),Ei6(32.0)-1.03341356421624104943493552567],_
+[34+2/15,1.03118521236465926355875784663,_
+  Ei6(34.0+2/15),Ei6(34.0+2/15)-1.03118521236465926355875784663],_
+[36+4/7,1.02897740410580800863378435059,_
+  Ei6(36.0+4/7),Ei6(36.0+4/7)-1.02897740410580800863378435059],_
+[39+5/13,1.02678968370902852450984510823,_
+  Ei6(39.0+5/13),Ei6(39.0+5/13)-1.02678968370902852450984510823],_
+[42+2/3,1.02462161468107839101187804247,_
+  Ei6(42.0+2/3),Ei6(42.0+2/3)-1.02462161468107839101187804247],_
+[46+6/11,1.02247277840542059591275364791,_
+  Ei6(46.0+6/11),Ei6(46.0+6/11)-1.02247277840542059591275364791],_
+[51+1/5,1.02034277293078377487217829808,_
+  Ei6(51.0+1/5),Ei6(51.0+1/5)-1.02034277293078377487217829808],_
+[56+8/9,1.01823121188483269682337017143,_
+  Ei6(56.0+8/9),Ei6(56.0+8/9)-1.01823121188483269682337017143],_
+[64,1.01613772349432532170357100831,_
+  Ei6(64.0),Ei6(64.0)-1.01613772349432532170357100831],_
+[73+1/7,1.01406194969697133145942329335,_
+  Ei6(73.0+1/7),Ei6(73.0+1/7)-1.01406194969697133145942329335],_
+[85+1/3,1.01200354533298848201864466702,_
+  Ei6(85.0+1/3),Ei6(85.0+1/3)-1.01200354533298848201864466702],_
+[102+2/5,1.00996217740644975574367545570,_
+  Ei6(102.0+2/5),Ei6(102.0+2/5)-1.00996217740644975574367545570],_
+[128,1.00793752440814018281776821694,_
+  Ei6(128.0),Ei6(128.0)-1.00793752440814018281776821694],_
+[170+2/3,1.00592927569292911294663030932,_
+  Ei6(170.0+2/3),Ei6(170.0+2/3)-1.00592927569292911294663030932],_
+[256,1.00393713090569862788009078297,_
+  Ei6(256.0),Ei6(256.0)-1.00393713090569862788009078297],_
+[512,1.00196079945071192531337468473,_
+  Ei6(512.0),Ei6(512.0)-1.00196079945071192531337468473],_
+[infinity(),1.00000000000000000000000000001,_
+  Ei6(infinity()),Ei6(infinity())-1.00000000000000000000000000001]]
+--R 
+--R
+--R   (14)
+--R   [[32.,1.033413564216241,1.0334135642162412,2.2204460492503131E-16],
+--R
+--R      512
+--R     [---, 1.0311852123 6465926355 875784663, 1.0311852123646588,
+--R       15
+--R      - 4.4408920985006262E-16]
+--R     ,
+--R     256
+--R    [---,1.0289774041 0580800863 378435059,1.028977404105808,0.],
+--R      7
+--R     512
+--R    [---,1.0267896837 0902852450 984510823,1.0267896837090285,0.],
+--R      13
+--R
+--R      128
+--R     [---, 1.0246216146 8107839101 187804247, 1.0246216146810787,
+--R       3
+--R      2.2204460492503131E-16]
+--R     ,
+--R     512
+--R    [---,1.0224727784 0542059591 275364791,1.0224727784054206,0.],
+--R      11
+--R     256
+--R    [---,1.0203427729 3078377487 217829808,1.0203427729307837,0.],
+--R      5
+--R
+--R      512
+--R     [---, 1.0182312118 8483269682 337017143, 1.0182312118848329,
+--R       9
+--R      2.2204460492503131E-16]
+--R     ,
+--R    [64.,1.0161377234943254,1.0161377234943252,- 2.2204460492503131E-16],
+--R
+--R      512
+--R     [---, 1.0140619496 9697133145 942329335, 1.0140619496969712,
+--R       7
+--R      - 2.2204460492503131E-16]
+--R     ,
+--R     256
+--R    [---,1.0120035453 3298848201 864466702,1.0120035453329885,0.],
+--R      3
+--R
+--R      512
+--R     [---, 1.0099621774 0644975574 36754557, 1.0099621774064493,
+--R       5
+--R      - 4.4408920985006262E-16]
+--R     ,
+--R    [128.,1.0079375244081401,1.0079375244081401,0.],
+--R
+--R      512
+--R     [---, 1.0059292756 9292911294 663030932, 1.0059292756929286,
+--R       3
+--R      - 4.4408920985006262E-16]
+--R     ,
+--R    [256.,1.0039371309056986,1.0039371309056981,- 4.4408920985006262E-16],
+--R    [512.,1.001960799450712,1.0019607994507116,- 4.4408920985006262E-16],
+--R    [infinity,1.,1.,0.]]
+--R                                                          Type: List List Any
+--E 13
+
+@
+In the following table we show values returned by 
+$(Ei(x)-\log x-\gamma)/x$ where gamma is as shown above.
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. p 238
+
+<<*>>=
+--S 14 of 20
+h(x:DFLOAT):DFLOAT==
+  x=0.0::DFLOAT => 1.0 
+  y:DFLOAT:=retract(Ei(x))
+  (y-log(x)-gamma)/x
+--R 
+--R   Function declaration h : DoubleFloat -> DoubleFloat has been added 
+--R      to workspace.
+--R                                                                   Type: Void
+--E 14
+
+--S 15 of 20
+[[0.00,1.000000000,h(0.00),h(0.00)-1.000000000],_
+ [0.01,1.002505566,h(0.01),h(0.01)-1.002505566],_
+ [0.02,1.005022306,h(0.02),h(0.02)-1.005022306],_
+ [0.03,1.007550283,h(0.03),h(0.03)-1.007550283],_
+ [0.04,1.010089560,h(0.04),h(0.04)-1.010089560],_
+ [0.05,1.012640202,h(0.05),h(0.05)-1.012640202],_
+ [0.06,1.015202272,h(0.06),h(0.06)-1.015202272],_
+ [0.07,1.017775836,h(0.07),h(0.07)-1.017775836],_
+ [0.08,1.020360958,h(0.08),h(0.08)-1.020360958],_
+ [0.09,1.022957705,h(0.09),h(0.09)-1.022957705],_
+ [0.10,1.025566141,h(0.10),h(0.10)-1.025566141],_
+ [0.11,1.028186335,h(0.11),h(0.11)-1.028186335],_
+ [0.12,1.030818352,h(0.12),h(0.12)-1.030818352],_
+ [0.13,1.033462259,h(0.13),h(0.13)-1.033462259],_
+ [0.14,1.036118125,h(0.14),h(0.14)-1.036118125],_
+ [0.15,1.038786018,h(0.15),h(0.15)-1.038786018],_
+ [0.16,1.041466006,h(0.16),h(0.16)-1.041466006],_
+ [0.17,1.044158158,h(0.17),h(0.17)-1.044158158],_
+ [0.18,1.046862544,h(0.18),h(0.18)-1.046862544],_
+ [0.19,1.049579234,h(0.19),h(0.19)-1.049579234],_
+ [0.20,1.052308298,h(0.20),h(0.20)-1.052308298],_
+ [0.21,1.055049807,h(0.21),h(0.21)-1.055049807],_
+ [0.22,1.057803833,h(0.22),h(0.22)-1.057803833],_
+ [0.23,1.060570446,h(0.23),h(0.23)-1.060570446],_
+ [0.24,1.063349719,h(0.24),h(0.24)-1.063349719],_
+ [0.25,1.066141726,h(0.25),h(0.25)-1.066141726],_
+ [0.26,1.068946539,h(0.26),h(0.26)-1.068946539],_
+ [0.27,1.071764232,h(0.27),h(0.27)-1.071764232],_
+ [0.28,1.074594879,h(0.28),h(0.28)-1.074594879],_
+ [0.29,1.077438555,h(0.29),h(0.29)-1.077438555],_
+ [0.30,1.080295334,h(0.30),h(0.30)-1.080295334],_
+ [0.31,1.083165293,h(0.31),h(0.31)-1.083165293],_
+ [0.32,1.086048507,h(0.32),h(0.32)-1.086048507],_
+ [0.33,1.088945053,h(0.33),h(0.33)-1.088945053],_
+ [0.34,1.091855008,h(0.34),h(0.34)-1.091855008],_
+ [0.35,1.094778451,h(0.35),h(0.35)-1.094778451],_
+ [0.36,1.097715458,h(0.36),h(0.36)-1.097715458],_
+ [0.37,1.100666108,h(0.37),h(0.37)-1.100666108],_
+ [0.38,1.103630481,h(0.38),h(0.38)-1.103630481],_
+ [0.39,1.106608656,h(0.39),h(0.39)-1.106608656],_
+ [0.40,1.109600714,h(0.40),h(0.40)-1.109600714],_
+ [0.41,1.112606735,h(0.41),h(0.41)-1.112606735],_
+ [0.42,1.115626800,h(0.42),h(0.42)-1.115626800],_
+ [0.43,1.118660991,h(0.43),h(0.43)-1.118660991],_
+ [0.44,1.121709391,h(0.44),h(0.44)-1.121709391],_
+ [0.45,1.124772082,h(0.45),h(0.45)-1.124772082],_
+ [0.46,1.127849147,h(0.46),h(0.46)-1.127849147],_
+ [0.47,1.130940671,h(0.47),h(0.47)-1.130940671],_
+ [0.48,1.134046738,h(0.48),h(0.48)-1.134046738],_
+ [0.49,1.137167432,h(0.49),h(0.49)-1.137167432],_
+ [0.50,1.140302841,h(0.50),h(0.50)-1.140302841]]
+--R 
+--R   Compiling function h with type DoubleFloat -> DoubleFloat 
+--R
+--R   (16)
+--R   [[0.,1.,1.,0.],
+--R    [1.0E-2,1.002505566,1.002505565988876,- 1.1123990617534218E-11],
+--R    [2.0E-2,1.0050223060000001,1.0050223058229502,- 1.7704993027223281E-10],
+--R
+--R     [2.9999999999999999E-2, 1.007550283, 1.0075502826056368,
+--R      - 3.9436320875552155E-10]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 1.0100895599999999, 1.0100895598460362,
+--R      - 1.5396373065357238E-10]
+--R     ,
+--R
+--R     [5.0000000000000003E-2, 1.012640202, 1.0126402014616676,
+--R      - 5.3833248969681335E-10]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 1.015202272, 1.0152022717813329,
+--R      - 2.1866708443951666E-10]
+--R     ,
+--R
+--R     [7.0000000000000007E-2, 1.017775836, 1.0177758355479642,
+--R      - 4.5203574217111964E-10]
+--R     ,
+--R
+--R     [8.0000000000000002E-2, 1.0203609579999999, 1.0203609579215664,
+--R      - 7.8433481931483584E-11]
+--R     ,
+--R
+--R     [8.9999999999999997E-2, 1.0229577050000001, 1.0229577044820872,
+--R      - 5.1791282373869763E-10]
+--R     ,
+--R
+--R     [0.10000000000000001, 1.0255661410000001, 1.0255661412323602,
+--R      2.3236013113603349E-10]
+--R     ,
+--R    [0.11,1.028186335,1.0281863346010778,- 3.989222285838423E-10],
+--R    [0.12,1.030818352,1.0308183514457605,- 5.5423954314903767E-10],
+--R    [0.13,1.033462259,1.0334622590557541,5.5754068029045811E-11],
+--R    [0.14000000000000001,1.036118125,1.0361181251552536,1.5525358776358189E-10],
+--R
+--R     [0.14999999999999999, 1.0387860179999999, 1.0387860179063644,
+--R      - 9.3635543763070928E-11]
+--R     ,
+--R    [0.16,1.0414660060000001,1.0414660059121499,- 8.7850171581749237E-11],
+--R
+--R     [0.17000000000000001, 1.0441581579999999, 1.0441581582197257,
+--R      2.1972579311579921E-10]
+--R     ,
+--R
+--R     [0.17999999999999999, 1.0468625439999999, 1.0468625443233892,
+--R      3.233893153264944E-10]
+--R     ,
+--R    [0.19,1.0495792340000001,1.0495792341677359,1.6773582522944253E-10],
+--R    [0.20000000000000001,1.052308298,1.0523082981508358,1.5083578830399347E-10],
+--R
+--R     [0.20999999999999999, 1.0550498070000001, 1.055049807127405,
+--R      1.2740497545848939E-10]
+--R     ,
+--R    [0.22,1.0578038329999999,1.0578038324120198,- 5.8798010904581588E-10],
+--R
+--R     [0.23000000000000001, 1.0605704460000001, 1.0605704457823433,
+--R      - 2.1765678148710776E-10]
+--R     ,
+--R
+--R     [0.23999999999999999, 1.0633497190000001, 1.0633497194823853,
+--R      4.8238524286148277E-10]
+--R     ,
+--R    [0.25,1.0661417259999999,1.0661417262257755,2.2577562042158661E-10],
+--R
+--R     [0.26000000000000001, 1.0689465389999999, 1.0689465391990731,
+--R      1.9907320236711712E-10]
+--R     ,
+--R    [0.27000000000000002,1.071764232,1.0717642320650853,6.5085270506415327E-11],
+--R
+--R     [0.28000000000000003, 1.0745948789999999, 1.0745948789662336,
+--R      - 3.3766323070949511E-11]
+--R     ,
+--R
+--R     [0.28999999999999998, 1.0774385550000001, 1.0774385545279166,
+--R      - 4.7208348341598594E-10]
+--R     ,
+--R
+--R     [0.29999999999999999, 1.0802953340000001, 1.0802953338619241,
+--R      - 1.3807599508197654E-10]
+--R     ,
+--R    [0.31,1.083165293,1.0831652925698594,- 4.3014058981327707E-10],
+--R
+--R     [0.32000000000000001, 1.0860485070000001, 1.0860485067465939,
+--R      - 2.5340618492464273E-10]
+--R     ,
+--R
+--R     [0.33000000000000002, 1.088945053, 1.0889450529837443,
+--R      - 1.6255663481956617E-11]
+--R     ,
+--R    [0.34000000000000002,1.091855008,1.0918550083731842,3.7318415024856222E-10],
+--R
+--R     [0.34999999999999998, 1.094778451, 1.0947784505105673,
+--R      - 4.8943271657719833E-10]
+--R     ,
+--R
+--R     [0.35999999999999999, 1.0977154579999999, 1.0977154574988892,
+--R      - 5.0111070848402051E-10]
+--R     ,
+--R    [0.37,1.100666108,1.1006661079520708,- 4.7929216151487708E-11],
+--R    [0.38,1.1036304809999999,1.1036304809985678,- 1.4321877017664519E-12],
+--R
+--R     [0.39000000000000001, 1.1066086559999999, 1.1066086562850108,
+--R      2.8501090376664706E-10]
+--R     ,
+--R
+--R     [0.40000000000000002, 1.1096007139999999, 1.1096007139798676,
+--R      - 2.0132340239342739E-11]
+--R     ,
+--R    [0.40999999999999998,1.112606735,1.1126067347771349,- 2.228650597402293E-10]
+--R     ,
+--R    [0.41999999999999998,1.1156268,1.1156267999000615,- 9.9938501918472866E-11],
+--R    [0.42999999999999999,1.118660991,1.1186609911048895,1.0488943047448629E-10],
+--R    [0.44,1.121709391,1.1217093906846374,- 3.1536262490305944E-10],
+--R
+--R     [0.45000000000000001, 1.124772082, 1.1247720814728976,
+--R      - 5.2710236175812497E-10]
+--R     ,
+--R
+--R     [0.46000000000000002, 1.1278491470000001, 1.1278491468476701,
+--R      - 1.52329926450534E-10]
+--R     ,
+--R
+--R     [0.46999999999999997, 1.1309406710000001, 1.1309406707352239,
+--R      - 2.6477620096443388E-10]
+--R     ,
+--R
+--R     [0.47999999999999998, 1.1340467380000001, 1.134046737613986,
+--R      - 3.8601410956573545E-10]
+--R     ,
+--R    [0.48999999999999999,1.137167432,1.1371674325184589,5.1845883142220828E-10],
+--R    [0.5,1.140302841,1.1403028410431715,4.3171466401759062E-11]]
+--R                                                  Type: List List DoubleFloat
+--E 15
+
+@
+In the following table we show values returned by Ei(x).
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp 239-241
+
+<<*>>=
+--S 16 of 20
+[[0.50,0.454219905,Ei(0.50),Ei(0.50)-0.454219905],_
+ [0.51,0.487032167,Ei(0.51),Ei(0.51)-0.487032167],_
+ [0.52,0.519530633,Ei(0.52),Ei(0.52)-0.519530633],_
+ [0.53,0.551730445,Ei(0.53),Ei(0.53)-0.551730445],_
+ [0.54,0.583645931,Ei(0.54),Ei(0.54)-0.583645931],_
+ [0.55,0.615290657,Ei(0.55),Ei(0.55)-0.615290657],_
+ [0.56,0.646677490,Ei(0.56),Ei(0.56)-0.646677490],_
+ [0.57,0.677818642,Ei(0.57),Ei(0.57)-0.677818642],_
+ [0.58,0.708725720,Ei(0.58),Ei(0.58)-0.708725720],_
+ [0.59,0.739409764,Ei(0.59),Ei(0.59)-0.739409764],_
+ [0.60,0.769881290,Ei(0.60),Ei(0.60)-0.769881290],_
+ [0.61,0.800150320,Ei(0.61),Ei(0.61)-0.800150320],_
+ [0.62,0.830226417,Ei(0.62),Ei(0.62)-0.830226417],_
+ [0.63,0.860118716,Ei(0.63),Ei(0.63)-0.860118716],_
+ [0.64,0.889835949,Ei(0.64),Ei(0.64)-0.889835949],_
+ [0.65,0.919386468,Ei(0.65),Ei(0.65)-0.919386468],_
+ [0.66,0.948778277,Ei(0.66),Ei(0.66)-0.948778277],_
+ [0.67,0.978019042,Ei(0.67),Ei(0.67)-0.978019042],_
+ [0.68,1.007116121,Ei(0.68),Ei(0.68)-1.007116121],_
+ [0.69,1.036076576,Ei(0.69),Ei(0.69)-1.036076576],_
+ [0.70,1.064907195,Ei(0.70),Ei(0.70)-1.064907195],_
+ [0.71,1.093614501,Ei(0.71),Ei(0.71)-1.093614501],_
+ [0.72,1.122204777,Ei(0.72),Ei(0.72)-1.122204777],_
+ [0.73,1.150684069,Ei(0.73),Ei(0.73)-1.150684069],_
+ [0.74,1.179058208,Ei(0.74),Ei(0.74)-1.179058208],_
+ [0.75,1.207332816,Ei(0.75),Ei(0.75)-1.207332816],_
+ [0.76,1.235513319,Ei(0.76),Ei(0.76)-1.235513319],_
+ [0.77,1.263604960,Ei(0.77),Ei(0.77)-1.263604960],_
+ [0.78,1.291612805,Ei(0.78),Ei(0.78)-1.291612805],_
+ [0.79,1.319541753,Ei(0.79),Ei(0.79)-1.319541753],_
+ [0.80,1.347396548,Ei(0.80),Ei(0.80)-1.347396548],_
+ [0.81,1.375181783,Ei(0.81),Ei(0.81)-1.375181783],_
+ [0.82,1.402901910,Ei(0.82),Ei(0.82)-1.402901910],_
+ [0.83,1.430561245,Ei(0.83),Ei(0.83)-1.430561245],_
+ [0.84,1.458163978,Ei(0.84),Ei(0.84)-1.458163978],_
+ [0.85,1.485714176,Ei(0.85),Ei(0.85)-1.485714176],_
+ [0.86,1.513215791,Ei(0.86),Ei(0.86)-1.513215791],_
+ [0.87,1.540672664,Ei(0.87),Ei(0.87)-1.540672664],_
+ [0.88,1.568088534,Ei(0.88),Ei(0.88)-1.568088534],_
+ [0.89,1.595467036,Ei(0.89),Ei(0.89)-1.595467036],_
+ [0.90,1.622811714,Ei(0.90),Ei(0.90)-1.622811714],_
+ [0.91,1.650126019,Ei(0.91),Ei(0.91)-1.650126019],_
+ [0.92,1.677413317,Ei(0.92),Ei(0.92)-1.677413317],_
+ [0.93,1.704676891,Ei(0.93),Ei(0.93)-1.704676891],_
+ [0.94,1.731919946,Ei(0.94),Ei(0.94)-1.731919946],_
+ [0.95,1.759145612,Ei(0.95),Ei(0.95)-1.759145612],_
+ [0.96,1.786356947,Ei(0.96),Ei(0.96)-1.786356947],_
+ [0.97,1.813556941,Ei(0.97),Ei(0.97)-1.813556941],_
+ [0.98,1.840748519,Ei(0.98),Ei(0.98)-1.840748519],_
+ [0.99,1.867934543,Ei(0.99),Ei(0.99)-1.867934543],_
+ [1.00,1.895117816,Ei(1.00),Ei(1.00)-1.895117816],_
+ [1.01,1.922301085,Ei(1.01),Ei(1.01)-1.922301085],_
+ [1.02,1.949487042,Ei(1.02),Ei(1.02)-1.949487042],_
+ [1.03,1.976678325,Ei(1.03),Ei(1.03)-1.976678325],_
+ [1.04,2.003877525,Ei(1.04),Ei(1.04)-2.003877525],_
+ [1.05,2.031087184,Ei(1.05),Ei(1.05)-2.031087184],_
+ [1.06,2.058309800,Ei(1.06),Ei(1.06)-2.058309800],_
+ [1.07,2.085547825,Ei(1.07),Ei(1.07)-2.085547825],_
+ [1.08,2.112803672,Ei(1.08),Ei(1.08)-2.112803672],_
+ [1.09,2.140079712,Ei(1.09),Ei(1.09)-2.140079712],_
+ [1.10,2.167378280,Ei(1.10),Ei(1.10)-2.167378280],_
+ [1.11,2.194701672,Ei(1.11),Ei(1.11)-2.194701672],_
+ [1.12,2.222052152,Ei(1.12),Ei(1.12)-2.222052152],_
+ [1.13,2.249431949,Ei(1.13),Ei(1.13)-2.249431949],_
+ [1.14,2.276843260,Ei(1.14),Ei(1.14)-2.276843260],_
+ [1.15,2.304288252,Ei(1.15),Ei(1.15)-2.304288252],_
+ [1.16,2.331769062,Ei(1.16),Ei(1.16)-2.331769062],_
+ [1.17,2.359287800,Ei(1.17),Ei(1.17)-2.359287800],_
+ [1.18,2.386846549,Ei(1.18),Ei(1.18)-2.386846549],_
+ [1.19,2.414447367,Ei(1.19),Ei(1.19)-2.414447367],_
+ [1.20,2.442092285,Ei(1.20),Ei(1.20)-2.442092285],_
+ [1.21,2.469783315,Ei(1.21),Ei(1.21)-2.469783315],_
+ [1.22,2.497522442,Ei(1.22),Ei(1.22)-2.497522442],_
+ [1.23,2.525311634,Ei(1.23),Ei(1.23)-2.525311634],_
+ [1.24,2.553152836,Ei(1.24),Ei(1.24)-2.553152836],_
+ [1.25,2.581047974,Ei(1.25),Ei(1.25)-2.581047974],_
+ [1.26,2.608998956,Ei(1.26),Ei(1.26)-2.608998956],_
+ [1.27,2.637007673,Ei(1.27),Ei(1.27)-2.637007673],_
+ [1.28,2.665075997,Ei(1.28),Ei(1.28)-2.665075997],_
+ [1.29,2.693205785,Ei(1.29),Ei(1.29)-2.693205785],_
+ [1.30,2.721398880,Ei(1.30),Ei(1.30)-2.721398880],_
+ [1.31,2.749657110,Ei(1.31),Ei(1.31)-2.749657110],_
+ [1.32,2.777982287,Ei(1.32),Ei(1.32)-2.777982287],_
+ [1.33,2.806376214,Ei(1.33),Ei(1.33)-2.806376214],_
+ [1.34,2.834840677,Ei(1.34),Ei(1.34)-2.834840677],_
+ [1.35,2.863377453,Ei(1.35),Ei(1.35)-2.863377453],_
+ [1.36,2.891988308,Ei(1.36),Ei(1.36)-2.891988308],_
+ [1.37,2.920674997,Ei(1.37),Ei(1.37)-2.920674997],_
+ [1.38,2.949439263,Ei(1.38),Ei(1.38)-2.949439263],_
+ [1.39,2.978282844,Ei(1.39),Ei(1.39)-2.978282844],_
+ [1.40,3.007207464,Ei(1.40),Ei(1.40)-3.007207464],_
+ [1.41,3.036214843,Ei(1.41),Ei(1.41)-3.036214843],_
+ [1.42,3.065306691,Ei(1.42),Ei(1.42)-3.065306691],_
+ [1.43,3.094484712,Ei(1.43),Ei(1.43)-3.094484712],_
+ [1.44,3.123750601,Ei(1.44),Ei(1.44)-3.123750601],_
+ [1.45,3.153106049,Ei(1.45),Ei(1.45)-3.153106049],_
+ [1.46,3.182552741,Ei(1.46),Ei(1.46)-3.182552741],_
+ [1.47,3.212092355,Ei(1.47),Ei(1.47)-3.212092355],_
+ [1.48,3.241726566,Ei(1.48),Ei(1.48)-3.241726566],_
+ [1.49,3.271457042,Ei(1.49),Ei(1.49)-3.271457042],_
+ [1.50,3.301285449,Ei(1.50),Ei(1.50)-3.301285449],_
+ [1.51,3.331213449,Ei(1.51),Ei(1.51)-3.331213449],_
+ [1.52,3.361242701,Ei(1.52),Ei(1.52)-3.361242701],_
+ [1.53,3.391374858,Ei(1.53),Ei(1.53)-3.391374858],_
+ [1.54,3.421611576,Ei(1.54),Ei(1.54)-3.421611576],_
+ [1.55,3.451954503,Ei(1.55),Ei(1.55)-3.451954503],_
+ [1.56,3.482405289,Ei(1.56),Ei(1.56)-3.482405289],_
+ [1.57,3.512965580,Ei(1.57),Ei(1.57)-3.512965580],_
+ [1.58,3.543637024,Ei(1.58),Ei(1.58)-3.543637024],_
+ [1.59,3.574421266,Ei(1.59),Ei(1.59)-3.574421266],_
+ [1.60,3.605319949,Ei(1.60),Ei(1.60)-3.605319949],_
+ [1.61,3.636334719,Ei(1.61),Ei(1.61)-3.636334719],_
+ [1.62,3.667467221,Ei(1.62),Ei(1.62)-3.667467221],_
+ [1.63,3.698719099,Ei(1.63),Ei(1.63)-3.698719099],_
+ [1.64,3.730091999,Ei(1.64),Ei(1.64)-3.730091999],_
+ [1.65,3.761587569,Ei(1.65),Ei(1.65)-3.761587569],_
+ [1.66,3.793207456,Ei(1.66),Ei(1.66)-3.793207456],_
+ [1.67,3.824953310,Ei(1.67),Ei(1.67)-3.824953310],_
+ [1.68,3.856826783,Ei(1.68),Ei(1.68)-3.856826783],_
+ [1.69,3.888829528,Ei(1.69),Ei(1.69)-3.888829528],_
+ [1.70,3.920963201,Ei(1.70),Ei(1.70)-3.920963201],_
+ [1.71,3.953229462,Ei(1.71),Ei(1.71)-3.953229462],_
+ [1.72,3.985629972,Ei(1.72),Ei(1.72)-3.985629972],_
+ [1.73,4.018166395,Ei(1.73),Ei(1.73)-4.018166395],_
+ [1.74,4.050840400,Ei(1.74),Ei(1.74)-4.050840400],_
+ [1.75,4.083653659,Ei(1.75),Ei(1.75)-4.083653659],_
+ [1.76,4.116607847,Ei(1.76),Ei(1.76)-4.116607847],_
+ [1.77,4.149704645,Ei(1.77),Ei(1.77)-4.149704645],_
+ [1.78,4.182945736,Ei(1.78),Ei(1.78)-4.182945736],_
+ [1.79,4.216332809,Ei(1.79),Ei(1.79)-4.216332809],_
+ [1.80,4.249867557,Ei(1.80),Ei(1.80)-4.249867557],_
+ [1.81,4.283551681,Ei(1.81),Ei(1.81)-4.283551681],_
+ [1.82,4.317386883,Ei(1.82),Ei(1.82)-4.317386883],_
+ [1.83,4.351374872,Ei(1.83),Ei(1.83)-4.351374872],_
+ [1.84,4.385517364,Ei(1.84),Ei(1.84)-4.385517364],_
+ [1.85,4.419816080,Ei(1.85),Ei(1.85)-4.419816080],_
+ [1.86,4.454272746,Ei(1.86),Ei(1.86)-4.454272746],_
+ [1.87,4.488889097,Ei(1.87),Ei(1.87)-4.488889097],_
+ [1.88,4.523666872,Ei(1.88),Ei(1.88)-4.523666872],_
+ [1.89,4.558607817,Ei(1.89),Ei(1.89)-4.558607817],_
+ [1.90,4.593713687,Ei(1.90),Ei(1.90)-4.593713687],_
+ [1.91,4.628986242,Ei(1.91),Ei(1.91)-4.628986242],_
+ [1.92,4.664427249,Ei(1.92),Ei(1.92)-4.664427249],_
+ [1.93,4.700038485,Ei(1.93),Ei(1.93)-4.700038485],_
+ [1.94,4.735821734,Ei(1.94),Ei(1.94)-4.735821734],_
+ [1.95,4.771778785,Ei(1.95),Ei(1.95)-4.771778785],_
+ [1.96,4.807911438,Ei(1.96),Ei(1.96)-4.807911438],_
+ [1.97,4.844221501,Ei(1.97),Ei(1.97)-4.844221501],_
+ [1.98,4.880710791,Ei(1.98),Ei(1.98)-4.880710791],_
+ [1.99,4.917381131,Ei(1.99),Ei(1.99)-4.917381131],_
+ [2.00,4.954234356,Ei(2.00),Ei(2.00)-4.954234356]]
+--R 
+--R
+--R   (17)
+--R   [[0.5,0.45421990499999998,0.45421990486317332,- 1.3682666111236585E-10],
+--R
+--R     [0.51000000000000001, 0.48703216700000002, 0.48703216680456007,
+--R      - 1.9543994200788006E-10]
+--R     ,
+--R
+--R     [0.52000000000000002, 0.51953063300000002, 0.51953063245569719,
+--R      - 5.443028250340376E-10]
+--R     ,
+--R
+--R     [0.53000000000000003, 0.55173044500000001, 0.55173044523266401,
+--R      2.3266399917787339E-10]
+--R     ,
+--R
+--R     [0.54000000000000004, 0.58364593099999995, 0.58364593072977955,
+--R      - 2.7022040161028826E-10]
+--R     ,
+--R
+--R     [0.55000000000000004, 0.61529065699999996, 0.61529065706218644,
+--R      6.2186478189119043E-11]
+--R     ,
+--R
+--R     [0.56000000000000005, 0.64667748999999997, 0.64667748977430584,
+--R      - 2.2569413005157912E-10]
+--R     ,
+--R
+--R     [0.56999999999999995, 0.67781864199999997, 0.67781864189137597,
+--R      - 1.0862399868472039E-10]
+--R     ,
+--R
+--R     [0.57999999999999996, 0.70872572, 0.70872571962101083,
+--R      - 3.7898917337741977E-10]
+--R     ,
+--R
+--R     [0.58999999999999997, 0.73940976400000002, 0.73940976415103654,
+--R      1.510365166268457E-10]
+--R     ,
+--R
+--R     [0.59999999999999998, 0.76988129000000005, 0.76988128993735938,
+--R      - 6.2640670428493195E-11]
+--R     ,
+--R
+--R     [0.60999999999999999, 0.80015031999999997, 0.80015031983004981,
+--R      - 1.699501650520574E-10]
+--R     ,
+--R    [0.62,0.83022641699999999,0.83022641734618519,3.4618519162421535E-10],
+--R    [0.63,0.86011871600000001,0.86011871636343917,3.6343916764991491E-10],
+--R
+--R     [0.64000000000000001, 0.88983594899999996, 0.88983594847818637,
+--R      - 5.2181359233571811E-10]
+--R     ,
+--R
+--R     [0.65000000000000002, 0.91938646800000001, 0.91938646824544334,
+--R      2.4544333232512372E-10]
+--R     ,
+--R
+--R     [0.66000000000000003, 0.94877827699999995, 0.94877827649472835,
+--R      - 5.0527160233571067E-10]
+--R     ,
+--R
+--R     [0.67000000000000004, 0.97801904200000001, 0.97801904189549682,
+--R      - 1.045031838842192E-10]
+--R     ,
+--R
+--R     [0.68000000000000005, 1.0071161209999999, 1.0071161209277915,
+--R      - 7.2208461432410331E-11]
+--R     ,
+--R
+--R     [0.68999999999999995, 1.0360765759999999, 1.0360765763978435,
+--R      3.978435358931165E-10]
+--R     ,
+--R    [0.69999999999999996,1.064907195,1.0649071946242905,- 3.757094635403746E-10]
+--R     ,
+--R    [0.70999999999999996,1.093614501,1.0936145014081782,4.0817815794014223E-10],
+--R
+--R     [0.71999999999999997, 1.1222047770000001, 1.1222047768888612,
+--R      - 1.111388758801013E-10]
+--R     ,
+--R    [0.72999999999999998,1.150684069,1.1506840693780345,3.780344925985446E-10],
+--R
+--R     [0.73999999999999999, 1.1790582080000001, 1.1790582082553465,
+--R      2.5534641068247765E-10]
+--R     ,
+--R    [0.75,1.2073328160000001,1.2073328160012218,1.2216894162975223E-12],
+--R
+--R     [0.76000000000000001, 1.2355133190000001, 1.2355133194354742,
+--R      4.3547410122357633E-10]
+--R     ,
+--R
+--R     [0.77000000000000002, 1.2636049600000001, 1.2636049602240513,
+--R      2.2405122201973882E-10]
+--R     ,
+--R
+--R     [0.78000000000000003, 1.291612805, 1.2916128047105979,
+--R      - 2.8940205787364448E-10]
+--R     ,
+--R    [0.79000000000000004,1.319541753,1.3195417531244753,1.2447531894110853E-10],
+--R
+--R     [0.80000000000000004, 1.3473965480000001, 1.3473965482123258,
+--R      2.1232571256746269E-10]
+--R     ,
+--R
+--R     [0.81000000000000005, 1.3751817829999999, 1.3751817833361941,
+--R      3.361941836033111E-10]
+--R     ,
+--R    [0.81999999999999995,1.40290191,1.4029019100774811,7.7481132620960125E-11],
+--R    [0.82999999999999996,1.430561245,1.4305612453827297,3.8272962576968439E-10],
+--R    [0.83999999999999997,1.458163978,1.4581639782841678,2.8416780040174672E-10],
+--R
+--R     [0.84999999999999998, 1.4857141760000001, 1.4857141762252541,
+--R      2.2525403764461771E-10]
+--R     ,
+--R
+--R     [0.85999999999999999, 1.5132157909999999, 1.5132157910189581,
+--R      1.8958168368499173E-11]
+--R     ,
+--R    [0.87,1.5406726639999999,1.5406726644642923,4.6429238231837644E-10],
+--R    [0.88,1.5680885339999999,1.5680885336445423,- 3.5545766330358219E-10],
+--R
+--R     [0.89000000000000001, 1.5954670360000001, 1.5954670359288246,
+--R      - 7.1175509930299086E-11]
+--R     ,
+--R
+--R     [0.90000000000000002, 1.622811714, 1.6228117136968674,
+--R      - 3.0313263010839364E-10]
+--R     ,
+--R
+--R     [0.91000000000000003, 1.650126019, 1.6501260188054063,
+--R      - 1.9459367450735954E-10]
+--R     ,
+--R
+--R     [0.92000000000000004, 1.6774133170000001, 1.677413316813162,
+--R      - 1.8683810054653804E-10]
+--R     ,
+--R
+--R     [0.93000000000000005, 1.7046768910000001, 1.7046768909800791,
+--R      - 1.9920953775454109E-11]
+--R     ,
+--R
+--R     [0.93999999999999995, 1.7319199460000001, 1.7319199460553549,
+--R      5.5354831829390605E-11]
+--R     ,
+--R
+--R     [0.94999999999999996, 1.759145612, 1.7591456118676905,
+--R      - 1.3230949669207348E-10]
+--R     ,
+--R
+--R     [0.95999999999999996, 1.786356947, 1.7863569467301943,
+--R      - 2.6980573331059077E-10]
+--R     ,
+--R
+--R     [0.96999999999999997, 1.8135569410000001, 1.8135569406715355,
+--R      - 3.2846458886126584E-10]
+--R     ,
+--R
+--R     [0.97999999999999998, 1.8407485189999999, 1.8407485185040211,
+--R      - 4.9597881357499318E-10]
+--R     ,
+--R
+--R     [0.98999999999999999, 1.8679345430000001, 1.8679345427385856,
+--R      - 2.6141444564586891E-10]
+--R     ,
+--R    [1.,1.895117816,1.8951178163559361,3.5593616942719564E-10],
+--R    [1.01,1.922301085,1.9223010854424856,4.4248560371329404E-10],
+--R    [1.02,1.9494870419999999,1.9494870416990668,- 3.0093305625200628E-10],
+--R    [1.03,1.976678325,1.976678324829928,- 1.7007195651785878E-10],
+--R    [1.04,2.003877525,2.0038775248189595,- 1.8104051591194548E-10],
+--R    [1.05,2.031087184,2.0310871840996643,9.9664276831390453E-11],
+--R    [1.0600000000000001,2.0583098,2.0583097996249284,- 3.7507152939042498E-10],
+--R
+--R     [1.0700000000000001, 2.0855478249999999, 2.085547824842283,
+--R      - 1.5771695061062019E-10]
+--R     ,
+--R
+--R     [1.0800000000000001, 2.1128036720000001, 2.1128036715799325,
+--R      - 4.2006753631085303E-10]
+--R     ,
+--R
+--R     [1.0900000000000001, 2.1400797119999999, 2.1400797118485424,
+--R      - 1.5145751319778356E-10]
+--R     ,
+--R
+--R     [1.1000000000000001, 2.1673782799999999, 2.1673782795634038,
+--R      - 4.3659609261226251E-10]
+--R     ,
+--R
+--R     [1.1100000000000001, 2.1947016719999999, 2.1947016721913277,
+--R      1.9132784245812218E-10]
+--R     ,
+--R
+--R     [1.1200000000000001, 2.2220521519999998, 2.2220521523263717,
+--R      3.2637181845984742E-10]
+--R     ,
+--R
+--R     [1.1299999999999999, 2.2494319489999999, 2.2494319491981756,
+--R      1.9817569807401014E-10]
+--R     ,
+--R
+--R     [1.1399999999999999, 2.2768432600000001, 2.2768432601165496,
+--R      1.1654943676830953E-10]
+--R     ,
+--R
+--R     [1.1499999999999999, 2.3042882520000001, 2.304288251855628,
+--R      - 1.4437206985462581E-10]
+--R     ,
+--R
+--R     [1.1599999999999999, 2.3317690619999998, 2.3317690619808027,
+--R      - 1.9197088363398507E-11]
+--R     ,
+--R
+--R     [1.1699999999999999, 2.3592878000000002, 2.3592878001213737,
+--R      1.2137357785491076E-10]
+--R     ,
+--R
+--R     [1.1799999999999999, 2.3868465489999999, 2.3868465491917359,
+--R      1.9173596044197438E-10]
+--R     ,
+--R
+--R     [1.1899999999999999, 2.4144473670000002, 2.4144473665637345,
+--R      - 4.3626569024013406E-10]
+--R     ,
+--R    [1.2,2.4420922850000002,2.4420922851926514,1.9265122830347536E-10],
+--R    [1.21,2.4697833149999999,2.4697833146991774,- 3.0082247803875362E-10],
+--R    [1.22,2.4975224420000002,2.497522442409561,4.095608296950104E-10],
+--R    [1.23,2.5253116339999999,2.5253116343560089,3.5600900005761105E-10],
+--R    [1.24,2.5531528360000002,2.5531528362393039,2.3930368797664414E-10],
+--R    [1.25,2.5810479740000001,2.5810479743554762,3.5547609300579097E-10],
+--R    [1.26,2.6089989560000002,2.6089989564882825,4.8828230347908175E-10],
+--R    [1.27,2.6370076729999998,2.6370076727691485,- 2.308513380455679E-10],
+--R    [1.28,2.6650759970000002,2.6650759965061086,- 4.9389159428869789E-10],
+--R    [1.29,2.693205785,2.6932057849832494,- 1.6750600906334512E-11],
+--R    [1.3,2.7213988800000002,2.7213988802320226,2.3202240129194251E-10],
+--R
+--R     [1.3100000000000001, 2.7496571099999998, 2.7496571097757787,
+--R      - 2.2422108614250646E-10]
+--R     ,
+--R
+--R     [1.3200000000000001, 2.7779822869999999, 2.777982287348725,
+--R      3.4872504883765032E-10]
+--R     ,
+--R
+--R     [1.3300000000000001, 2.8063762140000001, 2.8063762135905539,
+--R      - 4.0944625467886908E-10]
+--R     ,
+--R
+--R     [1.3400000000000001, 2.8348406769999999, 2.8348406767178056,
+--R      - 2.8219426795317304E-10]
+--R     ,
+--R    [1.3500000000000001,2.863377453,2.8633774531730753,1.7307533184407475E-10],
+--R
+--R     [1.3600000000000001, 2.8919883080000002, 2.8919883082530298,
+--R      2.5302959727468988E-10]
+--R     ,
+--R
+--R     [1.3700000000000001, 2.9206749969999999, 2.9206749967162473,
+--R      - 2.8375257699053691E-10]
+--R     ,
+--R
+--R     [1.3799999999999999, 2.9494392629999999, 2.9494392633717355,
+--R      3.7173553124603131E-10]
+--R     ,
+--R
+--R     [1.3899999999999999, 2.9782828440000002, 2.9782828436490232,
+--R      - 3.5097702522079999E-10]
+--R     ,
+--R
+--R     [1.3999999999999999, 3.0072074639999999, 3.0072074641506457,
+--R      1.5064571812217764E-10]
+--R     ,
+--R
+--R     [1.4099999999999999, 3.0362148430000002, 3.0362148431877847,
+--R      1.8778445465272853E-10]
+--R     ,
+--R    [1.4199999999999999,3.065306691,3.065306691299837,2.9983704408209633E-10],
+--R
+--R     [1.4299999999999999, 3.0944847119999999, 3.0944847117585681,
+--R      - 2.4143176347024564E-10]
+--R     ,
+--R
+--R     [1.4399999999999999, 3.1237506009999998, 3.1237506010575933,
+--R      5.7593485536244771E-11]
+--R     ,
+--R    [1.45,3.1531060489999998,3.1531060493877443,3.8774450317191622E-10],
+--R    [1.46,3.1825527409999999,3.1825527410990038,9.9003916176343409E-11],
+--R    [1.47,3.2120923549999998,3.2120923551495331,1.4953327465150323E-10],
+--R    [1.48,3.2417265660000001,3.2417265655423857,- 4.5761439082525612E-10],
+--R    [1.49,3.2714570420000002,3.2714570417503985,- 2.4960167266385724E-10],
+--R    [1.5,3.3012854489999999,3.3012854491297974,1.297975060765566E-10],
+--R    [1.51,3.3312134489999998,3.3312134493229739,3.2297409191528459E-10],
+--R    [1.52,3.3612427010000001,3.3612427006508958,- 3.4910430102286227E-10],
+--R    [1.53,3.3913748579999998,3.3913748584955847,4.9558490644585618E-10],
+--R    [1.54,3.4216115760000001,3.4216115756731122,- 3.2688785012169319E-10],
+--R    [1.55,3.4519545030000001,3.4519545027974381,- 2.0256196719969921E-10],
+--R
+--R     [1.5600000000000001, 3.4824052889999999, 3.4824052886355643,
+--R      - 3.6443559281451599E-10]
+--R     ,
+--R
+--R     [1.5700000000000001, 3.5129655799999999, 3.5129655804542947,
+--R      4.5429482398162691E-10]
+--R     ,
+--R
+--R     [1.5800000000000001, 3.5436370240000001, 3.5436370243589819,
+--R      3.5898173322834737E-10]
+--R     ,
+--R
+--R     [1.5900000000000001, 3.5744212659999999, 3.5744212656246064,
+--R      - 3.7539349406756628E-10]
+--R     ,
+--R
+--R     [1.6000000000000001, 3.6053199490000001, 3.6053199490194707,
+--R      1.9470647316666145E-11]
+--R     ,
+--R
+--R     [1.6100000000000001, 3.6363347190000002, 3.6363347191218383,
+--R      1.2183809516841393E-10]
+--R     ,
+--R
+--R     [1.6200000000000001, 3.6674672209999999, 3.6674672206298222,
+--R      - 3.7017766629787729E-10]
+--R     ,
+--R
+--R     [1.6299999999999999, 3.6987190989999998, 3.6987190986647667,
+--R      - 3.3523317455319557E-10]
+--R     ,
+--R
+--R     [1.6399999999999999, 3.7300919989999999, 3.7300919990684158,
+--R      6.8415939580290797E-11]
+--R     ,
+--R    [1.6499999999999999,3.761587569,3.7615875686941349,- 3.0586511101660108E-10]
+--R     ,
+--R
+--R     [1.6599999999999999, 3.7932074560000002, 3.7932074556923925,
+--R      - 3.0760771707605272E-10]
+--R     ,
+--R
+--R     [1.6699999999999999, 3.8249533100000002, 3.824953309790788,
+--R      - 2.092122031172039E-10]
+--R     ,
+--R
+--R     [1.6799999999999999, 3.8568267829999998, 3.8568267825688243,
+--R      - 4.3117553971683265E-10]
+--R     ,
+--R    [1.6899999999999999,3.888829528,3.8888295277276339,- 2.723661296499813E-10],
+--R    [1.7,3.9209632010000002,3.9209632013549038,3.5490366201429424E-10],
+--R    [1.71,3.9532294619999999,3.953229462185158,1.8515811106567526E-10],
+--R    [1.72,3.9856299719999999,3.985629971855627,- 1.4437295803304551E-10],
+--R    [1.73,4.0181663949999997,4.0181663951578672,1.5786749685275936E-10],
+--R    [1.74,4.0508404000000002,4.0508404002853169,2.8531665918762883E-10],
+--R    [1.75,4.0836536590000003,4.0836536590769557,7.6955330996497651E-11],
+--R    [1.76,4.116607847,4.1166078472572494,2.5724933294668517E-10],
+--R    [1.77,4.1497046449999999,4.1497046446724992,- 3.2750069323128628E-10],
+--R    [1.78,4.1829457359999997,4.1829457355238073,- 4.7619241883012364E-10],
+--R    [1.79,4.2163328089999998,4.2163328085967509,- 4.0324898975541146E-10],
+--R    [1.8,4.249867557,4.2498675574879341,4.879341375385593E-10],
+--R
+--R     [1.8100000000000001, 4.2835516809999996, 4.2835516808285554,
+--R      - 1.7144419217629547E-10]
+--R     ,
+--R
+--R     [1.8200000000000001, 4.3173868830000002, 4.3173868825051116,
+--R      - 4.9488857456481128E-10]
+--R     ,
+--R
+--R     [1.8300000000000001, 4.3513748720000001, 4.3513748718773684,
+--R      - 1.2263168258641599E-10]
+--R     ,
+--R    [1.8400000000000001,4.385517364,4.3855173639937215,- 6.2785332488601853E-12]
+--R     ,
+--R
+--R     [1.8500000000000001, 4.4198160800000004, 4.4198160798040753,
+--R      - 1.9592505395849003E-10]
+--R     ,
+--R    [1.8600000000000001,4.454272746,4.4542727463703349,3.7033487387816422E-10],
+--R
+--R     [1.8700000000000001, 4.4888890970000004, 4.4888890970746314,
+--R      7.4630968072142423E-11]
+--R     ,
+--R
+--R     [1.8799999999999999, 4.5236668719999997, 4.523666871825391,
+--R      - 1.7460877188568702E-10]
+--R     ,
+--R
+--R     [1.8899999999999999, 4.5586078170000004, 4.5586078172613478,
+--R      2.6134738817518155E-10]
+--R     ,
+--R
+--R     [1.8999999999999999, 4.5937136870000002, 4.5937136869535857,
+--R      - 4.6414427856689144E-11]
+--R     ,
+--R
+--R     [1.9099999999999999, 4.6289862419999999, 4.6289862416057304,
+--R      - 3.9426950593224319E-10]
+--R     ,
+--R
+--R     [1.9199999999999999, 4.6644272490000001, 4.6644272492523706,
+--R      2.5237056888727238E-10]
+--R     ,
+--R
+--R     [1.9299999999999999, 4.7000384850000003, 4.7000384854557851,
+--R      4.5578474328067387E-10]
+--R     ,
+--R
+--R     [1.9399999999999999, 4.7358217339999999, 4.7358217335010897,
+--R      - 4.9891024644921345E-10]
+--R     ,
+--R    [1.95,4.7717787850000004,4.7717787845898787,- 4.1012171436705103E-10],
+--R    [1.96,4.8079114379999996,4.8079114380324146,3.241495960537577E-11],
+--R    [1.97,4.8442215009999998,4.8442215014384944,4.3849457398437153E-10],
+--R    [1.98,4.8807107910000003,4.8807107909070337,- 9.2966523368431808E-11],
+--R    [1.99,4.917381131,4.9173811312144435,2.1444357400923764E-10],
+--R    [2.,4.9542343559999997,4.9542343560018924,1.8927082123809669E-12]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 16
+
+@
+In the following table we show values returned by
+$xe^{-x}Ei(x)$, chosen to keep the values in a reasonable range.
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp 242-243
+
+<<*>>=
+--S 17 of 20
+f(x)==x/10.0*exp(-x/10.0)*Ei(x/10.0)
+--R 
+--R                                                                   Type: Void
+--E 17
+
+--S 18 of 20
+[[2.0,1.340965420,f(2.0),f(2.0)-1.340965420],_
+ [2.1,1.371486802,f(2.1),f(2.1)-1.371486802],_
+ [2.2,1.397421992,f(2.2),f(2.2)-1.397421992],_
+ [2.3,1.419171534,f(2.3),f(2.3)-1.419171534],_
+ [2.4,1.437118315,f(2.4),f(2.4)-1.437118315],_
+ [2.5,1.451625159,f(2.5),f(2.5)-1.451625159],_
+ [2.6,1.463033397,f(2.6),f(2.6)-1.463033397],_
+ [2.7,1.471662153,f(2.7),f(2.7)-1.471662153],_
+ [2.8,1.477808187,f(2.8),f(2.8)-1.477808187],_
+ [2.9,1.481746162,f(2.9),f(2.9)-1.481746162],_
+ [3.0,1.483729204,f(3.0),f(3.0)-1.483729204],_
+ [3.1,1.483989691,f(3.1),f(3.1)-1.483989691],_
+ [3.2,1.482740191,f(3.2),f(3.2)-1.482740191],_
+ [3.3,1.480174491,f(3.3),f(3.3)-1.480174491],_
+ [3.4,1.476468706,f(3.4),f(3.4)-1.476468706],_
+ [3.5,1.471782389,f(3.5),f(3.5)-1.471782389],_
+ [3.6,1.466259659,f(3.6),f(3.6)-1.466259659],_
+ [3.7,1.460030313,f(3.7),f(3.7)-1.460030313],_
+ [3.8,1.453210902,f(3.8),f(3.8)-1.453210902],_
+ [3.9,1.445905765,f(3.9),f(3.9)-1.445905765],_
+ [4.0,1.438208032,f(4.0),f(4.0)-1.438208032],_
+ [4.1,1.430200557,f(4.1),f(4.1)-1.430200557],_
+ [4.2,1.421956813,f(4.2),f(4.2)-1.421956813],_
+ [4.3,1.413541719,f(4.3),f(4.3)-1.413541719],_
+ [4.4,1.405012424,f(4.4),f(4.4)-1.405012424],_
+ [4.5,1.396419030,f(4.5),f(4.5)-1.396419030],_
+ [4.6,1.387805263,f(4.6),f(4.6)-1.387805263],_
+ [4.7,1.379209093,f(4.7),f(4.7)-1.379209093],_
+ [4.8,1.370663313,f(4.8),f(4.8)-1.370663313],_
+ [4.9,1.362196054,f(4.9),f(4.9)-1.362196054],_
+ [5.0,1.353831278,f(5.0),f(5.0)-1.353831278],_
+ [5.1,1.345589212,f(5.1),f(5.1)-1.345589212],_
+ [5.2,1.337486755,f(5.2),f(5.2)-1.337486755],_
+ [5.3,1.329537845,f(5.3),f(5.3)-1.329537845],_
+ [5.4,1.321753788,f(5.4),f(5.4)-1.321753788],_
+ [5.5,1.314143566,f(5.5),f(5.5)-1.314143566],_
+ [5.6,1.306714107,f(5.6),f(5.6)-1.306714107],_
+ [5.7,1.299470536,f(5.7),f(5.7)-1.299470536],_
+ [5.8,1.292416395,f(5.8),f(5.8)-1.292416395],_
+ [5.9,1.285553849,f(5.9),f(5.9)-1.285553849],_
+ [6.0,1.278883860,f(6.0),f(6.0)-1.278883860],_
+ [6.1,1.272406357,f(6.1),f(6.1)-1.272406357],_
+ [6.2,1.266120373,f(6.2),f(6.2)-1.266120373],_
+ [6.3,1.260024184,f(6.3),f(6.3)-1.260024184],_
+ [6.4,1.254115417,f(6.4),f(6.4)-1.254115417],_
+ [6.5,1.248391155,f(6.5),f(6.5)-1.248391155],_
+ [6.6,1.242848032,f(6.6),f(6.6)-1.242848032],_
+ [6.7,1.237482309,f(6.7),f(6.7)-1.237482309],_
+ [6.8,1.232289952,f(6.8),f(6.8)-1.232289952],_
+ [6.9,1.227266684,f(6.9),f(6.9)-1.227266684],_
+ [7.0,1.222408053,f(7.0),f(7.0)-1.222408053],_
+ [7.1,1.217709472,f(7.1),f(7.1)-1.217709472],_
+ [7.2,1.213166264,f(7.2),f(7.2)-1.213166264],_
+ [7.3,1.208773699,f(7.3),f(7.3)-1.208773699],_
+ [7.4,1.204527026,f(7.4),f(7.4)-1.204527026],_
+ [7.5,1.200421500,f(7.5),f(7.5)-1.200421500],_
+ [7.6,1.196452401,f(7.6),f(7.6)-1.196452401],_
+ [7.7,1.192615063,f(7.7),f(7.7)-1.192615063],_
+ [7.8,1.188904881,f(7.8),f(7.8)-1.188904881],_
+ [7.9,1.185317334,f(7.9),f(7.9)-1.185317334],_
+ [8.0,1.181847987,f(8.0),f(8.0)-1.181847987],_
+ [8.1,1.178492509,f(8.1),f(8.1)-1.178492509],_
+ [8.2,1.175246676,f(8.2),f(8.2)-1.175246676],_
+ [8.3,1.172106376,f(8.3),f(8.3)-1.172106376],_
+ [8.4,1.169067617,f(8.4),f(8.4)-1.169067617],_
+ [8.5,1.166126526,f(8.5),f(8.5)-1.166126526],_
+ [8.6,1.163279354,f(8.6),f(8.6)-1.163279354],_
+ [8.7,1.160522476,f(8.7),f(8.7)-1.160522476],_
+ [8.8,1.157852390,f(8.8),f(8.8)-1.157852390],_
+ [8.9,1.155265719,f(8.9),f(8.9)-1.155265719],_
+ [9.0,1.152759209,f(9.0),f(9.0)-1.152759209],_
+ [9.1,1.150329724,f(9.1),f(9.1)-1.150329724],_
+ [9.2,1.147974251,f(9.2),f(9.2)-1.147974251],_
+ [9.3,1.145689889,f(9.3),f(9.3)-1.145689889],_
+ [9.4,1.143473855,f(9.4),f(9.4)-1.143473855],_
+ [9.5,1.141323476,f(9.5),f(9.5)-1.141323476],_
+ [9.6,1.139236185,f(9.6),f(9.6)-1.139236185],_
+ [9.7,1.137209523,f(9.7),f(9.7)-1.137209523],_
+ [9.8,1.135241130,f(9.8),f(9.8)-1.135241130],_
+ [9.9,1.133328746,f(9.9),f(9.9)-1.133328746],_
+ [10.0,1.131470205,f(10.0),f(10.0)-1.131470205]]
+--R 
+--R   Compiling function f with type Float -> OnePointCompletion 
+--R      DoubleFloat 
+--R
+--R   (19)
+--R   [[2.,1.3409654200000001,- 0.13456013299662745,- 1.4755255529966276],
+--R
+--R     [2.1000000000000001, 1.3714868019999999, - 0.12968783850914051,
+--R      - 1.5011746405091404]
+--R     ,
+--R
+--R     [2.2000000000000002, 1.3974219919999999, - 0.12432857913849607,
+--R      - 1.521750571138496]
+--R     ,
+--R    [2.2999999999999998,1.419171534,- 0.11851397777493734,- 1.5376855117749373],
+--R    [2.3999999999999999,1.437118315,- 0.1122732093067646,- 1.5493915243067646],
+--R    [2.5,1.451625159,- 0.10563327984220373,- 1.5572584388422037],
+--R
+--R     [2.6000000000000001, 1.463033397, - 9.8619263183169451E-2,
+--R      - 1.5616526601831695]
+--R     ,
+--R
+--R     [2.7000000000000002, 1.471662153, - 9.1254502584207586E-2,
+--R      - 1.5629166555842076]
+--R     ,
+--R
+--R     [2.7999999999999998, 1.4778081869999999, - 8.3560784069182492E-2,
+--R      - 1.5613689710691825]
+--R     ,
+--R
+--R     [2.8999999999999999, 1.4817461620000001, - 7.5558486253840138E-2,
+--R      - 1.5573046482538402]
+--R     ,
+--R    [3.,1.4837292040000001,- 6.7266710614573164E-2,- 1.5509959146145733],
+--R
+--R     [3.1000000000000001, 1.4839896910000001, - 5.8703395368669309E-2,
+--R      - 1.5426930863686694]
+--R     ,
+--R
+--R     [3.2000000000000002, 1.482740191, - 4.9885415529372513E-2,
+--R      - 1.5326256065293724]
+--R     ,
+--R
+--R     [3.2999999999999998, 1.4801744910000001, - 4.0828671227296824E-2,
+--R      - 1.5210031622272968]
+--R     ,
+--R
+--R     [3.3999999999999999, 1.4764687059999999, - 3.1548166016793916E-2,
+--R      - 1.5080168720167939]
+--R     ,
+--R    [3.5,1.4717823889999999,- 2.2058076588733416E-2,- 1.4938404655887334],
+--R
+--R     [3.6000000000000001, 1.4662596590000001, - 1.2371815072632724E-2,
+--R      - 1.4786314740726327]
+--R     ,
+--R
+--R     [3.7000000000000002, 1.4600303130000001, - 2.5020849182828334E-3,
+--R      - 1.4625323979182829]
+--R     ,
+--R
+--R     [3.7999999999999998, 1.4532109019999999, 7.5390688098497787E-3,
+--R      - 1.4456718331901501]
+--R     ,
+--R    [3.8999999999999999,1.445905765,1.774021402057336E-2,- 1.4281655509794267],
+--R    [4.,1.4382080319999999,2.8090490467135878E-2,- 1.4101175415328639],
+--R    [4.0999999999999996,1.430200557,3.8579572390008463E-2,- 1.3916209846099916],
+--R    [4.2000000000000002,1.421956813,4.9197634492545148E-2,- 1.3727591785074549],
+--R
+--R     [4.2999999999999998, 1.4135417189999999, 5.9935320871702981E-2,
+--R      - 1.3536063981282969]
+--R     ,
+--R
+--R     [4.4000000000000004, 1.4050124239999999, 7.0783716577210318E-2,
+--R      - 1.3342287074227897]
+--R     ,
+--R    [4.5,1.3964190299999999,8.1734321515770605E-2,- 1.3146847084842292],
+--R    [4.5999999999999996,1.387805263,9.2779026453518668E-2,- 1.2950262365464813],
+--R
+--R     [4.7000000000000002, 1.3792090930000001, 0.10391009090110491,
+--R      - 1.2752990020988952]
+--R     ,
+--R
+--R     [4.7999999999999998, 1.3706633130000001, 0.11512012269240564,
+--R      - 1.2555431903075944]
+--R     ,
+--R    [4.9000000000000004,1.362196054,0.12640205909068003,- 1.23579399490932],
+--R    [5.,1.3538312779999999,0.13774914927563506,- 1.2160821287243648],
+--R
+--R     [5.0999999999999996, 1.3455892119999999, 0.14915493808180313,
+--R      - 1.1964342739181968]
+--R     ,
+--R    [5.2000000000000002,1.337486755,0.16061325087332862,- 1.1768735041266714],
+--R
+--R     [5.2999999999999998, 1.3295378449999999, 0.17211817945300276,
+--R      - 1.1574196655469973]
+--R     ,
+--R
+--R     [5.4000000000000004, 1.3217537880000001, 0.1836640689145036,
+--R      - 1.1380897190854964]
+--R     ,
+--R    [5.5,1.314143566,0.19524550535650245,- 1.1188980606434975],
+--R
+--R     [5.5999999999999996, 1.3067141069999999, 0.20685730438580638,
+--R      - 1.0998568026141935]
+--R     ,
+--R
+--R     [5.7000000000000002, 1.2994705360000001, 0.21849450034417656,
+--R      - 1.0809760356558236]
+--R     ,
+--R
+--R     [5.7999999999999998, 1.2924163950000001, 0.23015233620004197,
+--R      - 1.0622640587999581]
+--R     ,
+--R    [5.9000000000000004,1.285553849,0.24182625405213551,- 1.0437275949478646],
+--R    [6.,1.2788838600000001,0.25351188619722104,- 1.0253719738027791],
+--R
+--R     [6.0999999999999996, 1.2724063569999999, 0.26520504671863687,
+--R      - 1.0072013102813631]
+--R     ,
+--R
+--R     [6.2000000000000002, 1.2661203729999999, 0.27690172355643178,
+--R      - 0.98921864944356819]
+--R     ,
+--R
+--R     [6.2999999999999998, 1.2600241839999999, 0.28859807102347912,
+--R      - 0.97142611297652082]
+--R     ,
+--R    [6.4000000000000004,1.254115417,0.30029040273517321,- 0.9538250142648268],
+--R    [6.5,1.248391155,0.31197518492319382,- 0.93641597007680621],
+--R
+--R     [6.5999999999999996, 1.2428480319999999, 0.32364903010640295,
+--R      - 0.91919900189359693]
+--R     ,
+--R    [6.7000000000000002,1.237482309,0.33530869109425609,- 0.90217361790574391],
+--R
+--R     [6.7999999999999998, 1.2322899519999999, 0.34695105530018927,
+--R      - 0.88533889669981058]
+--R     ,
+--R
+--R     [6.9000000000000004, 1.2272666839999999, 0.3585731393443225,
+--R      - 0.86869354465567739]
+--R     ,
+--R    [7.,1.2224080530000001,0.37017208392651269,- 0.85223596907348742],
+--R
+--R     [7.0999999999999996, 1.2177094719999999, 0.38174514895231304,
+--R      - 0.83596432304768686]
+--R     ,
+--R    [7.2000000000000002,1.213166264,0.39328970889579112,- 0.81987655510420887],
+--R    [7.2999999999999998,1.208773699,0.40480324838440268,- 0.80397045061559735],
+--R
+--R     [7.4000000000000004, 1.2045270260000001, 0.4162833579922634,
+--R      - 0.78824366800773671]
+--R     ,
+--R    [7.5,1.2004215,0.42772773022919919,- 0.77269376977080084],
+--R
+--R     [7.5999999999999996, 1.1964524009999999, 0.43913415571389103,
+--R      - 0.75731824528610892]
+--R     ,
+--R
+--R     [7.7000000000000002, 1.1926150630000001, 0.45050051952030151,
+--R      - 0.74211454347969852]
+--R     ,
+--R    [7.7999999999999998,1.188904881,0.46182479768734747,- 0.7270800833126525],
+--R
+--R     [7.9000000000000004, 1.1853173340000001, 0.47310505388250573,
+--R      - 0.71221228011749438]
+--R     ,
+--R    [8.,1.181847987,0.48433943621069148,- 0.69750855078930862],
+--R    [8.0999999999999996,1.178492509,0.49552617416036354,- 0.68296633483963642],
+--R    [8.1999999999999993,1.175246676,0.50666357567934228,- 0.66858310032065771],
+--R
+--R     [8.3000000000000007, 1.1721063759999999, 0.51775002437336082,
+--R      - 0.65435635162663908]
+--R     ,
+--R
+--R     [8.4000000000000004, 1.1690676170000001, 0.52878397682080924,
+--R      - 0.64028364017919082]
+--R     ,
+--R    [8.5,1.166126526,0.53976395999758919,- 0.6263625660024108],
+--R
+--R     [8.5999999999999996, 1.1632793539999999, 0.5506885688063663,
+--R      - 0.61259078519363364]
+--R     ,
+--R
+--R     [8.6999999999999993, 1.1605224759999999, 0.56155646370489876,
+--R      - 0.59896601229510116]
+--R     ,
+--R    [8.8000000000000007,1.15785239,0.57236636842843447,- 0.58548602157156548],
+--R    [8.9000000000000004,1.155265719,0.58311706780150541,- 0.57214865119849456],
+--R    [9.,1.1527592090000001,0.59380740563471446,- 0.5589518033652856],
+--R
+--R     [9.0999999999999996, 1.1503297240000001, 0.60443628270239691,
+--R      - 0.5458934412976032]
+--R     ,
+--R
+--R     [9.1999999999999993, 1.1479742509999999, 0.61500265479727367,
+--R      - 0.53297159620272627]
+--R     ,
+--R    [9.3000000000000007,1.145689889,0.62550553085845151,- 0.52018435814154851],
+--R
+--R     [9.4000000000000004, 1.1434738550000001, 0.63594397116933887,
+--R      - 0.50752988383066122]
+--R     ,
+--R    [9.5,1.1413234759999999,0.6463170856222451,- 0.49500639037775485],
+--R
+--R     [9.5999999999999996, 1.1392361849999999, 0.65662403204660502,
+--R      - 0.48261215295339488]
+--R     ,
+--R
+--R     [9.6999999999999993, 1.1372095230000001, 0.66686401459797295,
+--R      - 0.47034550840202716]
+--R     ,
+--R    [9.8000000000000007,1.13524113,0.6770362822050533,- 0.45820484779494675],
+--R
+--R     [9.9000000000000004, 1.1333287460000001, 0.68714012707221583,
+--R      - 0.44618861892778428]
+--R     ,
+--R    [10.,1.1314702050000001,0.69717488323506582,- 0.43429532176493424]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 18
+
+@
+In the following table we show the values returned for large
+arguments to the Ei function. See 
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. p 243
+
+<<*>>=
+--S 19 of 20
+g(y)==(y=0 => 1 ; (x:DFLOAT:=y^-1) ; x*exp(-x)*Ei(x))
+--R 
+--R                                                                   Type: Void
+--E 19
+
+--S 20 of 20
+[[0.100,1.13147021,g(0.100),g(0.100)-1.13147021],_
+ [0.095,1.12249671,g(0.095),g(0.095)-1.12249671],_
+ [0.090,1.11389377,g(0.090),g(0.090)-1.11389377],_
+ [0.085,1.10564739,g(0.085),g(0.085)-1.10564739],_
+ [0.080,1.09773775,g(0.080),g(0.080)-1.09773775],_
+ [0.075,1.09014087,g(0.075),g(0.075)-1.09014087],_
+ [0.070,1.08283054,g(0.070),g(0.070)-1.08283054],_
+ [0.065,1.07578038,g(0.065),g(0.065)-1.07578038],_
+ [0.060,1.06896548,g(0.060),g(0.060)-1.06896548],_
+ [0.055,1.06236365,g(0.055),g(0.055)-1.06236365],_
+ [0.050,1.05595591,g(0.050),g(0.050)-1.05595591],_
+ [0.045,1.04972640,g(0.045),g(0.045)-1.04972640],_
+ [0.040,1.04366194,g(0.040),g(0.040)-1.04366194],_
+ [0.035,1.03775135,g(0.035),g(0.035)-1.03775135],_
+ [0.030,1.03198503,g(0.030),g(0.030)-1.03198503],_
+ [0.025,1.02635451,g(0.025),g(0.025)-1.02635451],_
+ [0.020,1.02085228,g(0.020),g(0.020)-1.02085228],_
+ [0.015,1.01547157,g(0.015),g(0.015)-1.01547157],_
+ [0.010,1.01020625,g(0.010),g(0.010)-1.01020625],_
+ [0.005,1.00505077,g(0.005),g(0.005)-1.00505077],_
+ [0.000,1.00000000,g(0.000),g(0.000)-1.00000000]]
+--R 
+--R   Compiling function g with type Float -> OnePointCompletion 
+--R      DoubleFloat 
+--R
+--R   (21)
+--R   [[0.10000000000000001,1.13147021,1.1314702047341079,- 5.2658921667614322E-9],
+--R
+--R     [9.5000000000000001E-2, 1.1224967100000001, 1.1224967463528539,
+--R      3.6352853838295118E-8]
+--R     ,
+--R    [8.9999999999999997E-2,1.11389377,1.1138937808537757,1.0853775656016751E-8],
+--R
+--R     [8.5000000000000006E-2, 1.1056473899999999, 1.1056473901733923,
+--R      1.733924115399077E-10]
+--R     ,
+--R
+--R     [8.0000000000000002E-2, 1.0977377500000001, 1.0977377526473173,
+--R      2.647317254300674E-9]
+--R     ,
+--R
+--R     [7.4999999999999997E-2, 1.0901408699999999, 1.0901408684282585,
+--R      - 1.5717414036942046E-9]
+--R     ,
+--R    [7.0000000000000007E-2,1.08283054,1.0828305423224371,2.3224371314967129E-9],
+--R
+--R     [6.5000000000000002E-2, 1.0757803800000001, 1.0757803749062493,
+--R      - 5.0937507545256722E-9]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 1.0689654799999999, 1.0689654755715123,
+--R      - 4.4284875766464893E-9]
+--R     ,
+--R    [5.5E-2,1.06236365,1.0623636462639567,- 3.7360432525446186E-9],
+--R
+--R     [5.0000000000000003E-2, 1.05595591, 1.0559559055929626,
+--R      - 4.4070374016769165E-9]
+--R     ,
+--R
+--R     [4.4999999999999998E-2, 1.0497263999999999, 1.0497264028491122,
+--R      2.8491122794349621E-9]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 1.04366194, 1.0436619362666135,
+--R      - 3.7333864888466906E-9]
+--R     ,
+--R    [3.5000000000000003E-2,1.03775135,1.0377513519241477,1.924147730036907E-9],
+--R
+--R     [2.9999999999999999E-2, 1.03198503, 1.0319850279857541,
+--R      - 2.0142458811989172E-9]
+--R     ,
+--R    [2.5000000000000001E-2,1.02635451,1.026354511439006,1.4390060254498849E-9],
+--R    [2.0E-2,1.0208522799999999,1.0208522777971993,- 2.2028006085861307E-9],
+--R
+--R     [1.4999999999999999E-2, 1.0154715700000001, 1.0154715653071829,
+--R      - 4.6928172459104189E-9]
+--R     ,
+--R    [1.0E-2,1.01020625,1.0102062527748354,2.7748354725076751E-9],
+--R
+--R     [5.0000000000000001E-3, 1.00505077, 1.0050507653866605,
+--R      - 4.6133394882019729E-9]
+--R     ,
+--R    [0.,1.,1.,0.]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 20
+
+)spool 
+)lisp (bye)
+ 
+@
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} Lee, K.L.,``High-precision Chebyshev series approximation
+to the exponential integral'', NASA-TN-D-5953, A-3571, No Copyright
+Doc. ID=19700026648, Accession ID=70N35964, Aug 1970
+\bibitem{2} Abramowitz and Stegun,``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp238-243
+\end{thebibliography}
+\end{document}
+
